(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    437199,       8576]
NotebookOptionsPosition[    420695,       8327]
NotebookOutlinePosition[    421207,       8345]
CellTagsIndexPosition[    421164,       8342]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Solving an Elliptic Partial Differential Equation by the Method of Finite \
Differences\
\>", "Subtitle",
 CellChangeTimes->{{3.4373215988289104`*^9, 
  3.4373216289751244`*^9}},ExpressionUUID->"cfd44fc4-5473-440b-b4d1-\
bf8fb2e9bdd6"],

Cell[TextData[{
 "In these notes I am going to apply the method of finite differences to \
solve an elliptic partial differential equation. The equation we are going to \
work with is the Poisson equation\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"x", ",", "x"}]], 
      RowBox[{"u", "(", 
       RowBox[{"x", ",", "y"}], ")"}]}], " ", "+", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"y", ",", "y"}]], 
      RowBox[{"u", "(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}], " ", "=", " ", 
    RowBox[{"f", "(", 
     RowBox[{"x", ",", "y"}], ")"}]}], TraditionalForm]],ExpressionUUID->
  "1380ae14-2b91-43ad-b91f-356c5adb42fe"],
 "\n\non a rectangular region ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
    "a", " ", "\[LessEqual]", " ", "x", " ", "\[LessEqual]", " ", "b"}], " ", 
    ",", " ", 
    RowBox[{
    "c", " ", "\[LessEqual]", " ", "y", " ", "\[LessEqual]", " ", "d"}]}], 
   TraditionalForm]],ExpressionUUID->"858ca506-89d5-4b42-bbcf-4c2c7bd44e1c"],
 " with appropriate boundary conditions. "
}], "Text",
 CellChangeTimes->{{3.4373216538887053`*^9, 3.437321732378605*^9}, {
  3.437321767767189*^9, 
  3.437321851002264*^9}},ExpressionUUID->"7f2cf978-c2db-4aec-9fae-\
de1b202f8fd9"],

Cell[CellGroupData[{

Cell[TextData[{
 "Running the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " code in this notebook"
}], "Subsubsection",
 CellChangeTimes->{{3.4373270733612194`*^9, 
  3.4373270842763147`*^9}},ExpressionUUID->"24c99261-41d7-46cc-82b3-\
adbab2ec2bd9"],

Cell["\<\
This notebook is divided into three sections. The code in these three \
sections is designed to be run independently. If you would like to run the \
commands in this notebook, I recommend that you quit and restart the kernel \
after each section to reset the definitions of the variables used here. If \
you don't do this, the definitions set up in one section may clash with those \
in a subsequent section.\
\>", "Text",
 CellChangeTimes->{{3.437327089351287*^9, 
  3.437327191631502*^9}},ExpressionUUID->"f9a4a037-d135-4c17-a766-\
e333493e18eb"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Introducing the Basic Method", "Section",
 CellChangeTimes->{{3.437149755518485*^9, 3.43714976906489*^9}, {
  3.4373218850934753`*^9, 
  3.437321893643632*^9}},ExpressionUUID->"1f22566d-313e-4d80-a65d-\
b6c58c4ec79d"],

Cell["\<\
In this section of the notes I will be demonstrating how the finite \
difference method works. I will make absolutely no attempt to do anything \
efficiently; instead, the emphasis in the first pass will be do things in the \
clearest and most straight-forward way.\
\>", "Text",
 CellChangeTimes->{{3.437321956683455*^9, 
  3.437322017438219*^9}},ExpressionUUID->"df58755b-b90a-4368-8af9-\
f0d1e7783709"],

Cell["\<\
To make the discussion more concrete, I will be working through a specific \
example from the text, example 2 in section 12.1.\
\>", "Text",
 CellChangeTimes->{{3.437322023582735*^9, 
  3.4373220571508656`*^9}},ExpressionUUID->"ca8eba02-810b-4a83-95f8-\
26ff01e71861"],

Cell[CellGroupData[{

Cell["Setting up the difference equations", "Subsubsection",
 CellChangeTimes->{{3.4371498221354012`*^9, 
  3.437149828903754*^9}},ExpressionUUID->"9623d71c-2001-4861-9ac1-\
6e6fce578b8a"],

Cell["\<\
The method of finite differences works by subdividing the region in question \
into a grid of sample points. We typically associate a simple numbering \
system with the grid of points. In this example, each sample point is \
identified by a pair of indices (i,j) with i being the index in the \
x-direction and j the index in the y-direction. The lower left hand corner of \
the region, (a,c) is numbered sample point (0,0), while the upper right hand \
corner of the region, (c,d) is numbered (n,m).\
\>", "Text",
 CellChangeTimes->{{3.4371497728973026`*^9, 3.437149810142095*^9}, {
  3.4373219047572727`*^9, 3.437321929626194*^9}, {3.4373220737238593`*^9, 
  3.437322178024277*^9}},ExpressionUUID->"ae339142-39c5-4701-88d8-\
99d83df2f516"],

Cell[TextData[{
 "The first step in the calculation is to convert the PDE into a difference \
equation. There will be a different difference equation associated with each \
of the sample points, so I set this up as a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function that maps the indices of a sample point to a difference equation \
for that sample point."
}], "Text",
 CellChangeTimes->{{3.4371498392204123`*^9, 3.4371499034650555`*^9}, {
  3.437322189641008*^9, 
  3.437322194175129*^9}},ExpressionUUID->"71b99190-7679-45fb-96d0-\
f38269a4d612"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eqn", "[", 
   RowBox[{"i_", ",", "j_"}], "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{
         RowBox[{"i", "+", "1"}], ",", "j"}], "]"}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"u", "[", 
         RowBox[{"i", ",", "j"}], "]"}]}], " ", "+", " ", 
       RowBox[{"u", "[", 
        RowBox[{
         RowBox[{"i", "-", "1"}], ",", "j"}], "]"}]}], ")"}], "/", 
     RowBox[{"h", "^", "2"}]}], " ", "+", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"i", ",", 
         RowBox[{"j", "+", "1"}]}], "]"}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"u", "[", 
         RowBox[{"i", ",", "j"}], "]"}]}], " ", "+", " ", 
       RowBox[{"u", "[", 
        RowBox[{"i", ",", 
         RowBox[{"j", "-", "1"}]}], "]"}]}], ")"}], "/", 
     RowBox[{"k", "^", "2"}]}]}], " ", "\[Equal]", " ", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"x", "[", "i", "]"}], ",", 
     RowBox[{"y", "[", "j", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.436891360518648*^9, 3.4368913697346478`*^9}, {
  3.436891431488648*^9, 3.4368915189766483`*^9}, {3.436891619419648*^9, 
  3.436891638435648*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"42cd25d8-e0fe-4c10-ac76-2b59d2945d1e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"i", ",", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "j"}]}], "]"}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"u", "[", 
       RowBox[{"i", ",", "j"}], "]"}]}], "+", 
     RowBox[{"u", "[", 
      RowBox[{"i", ",", 
       RowBox[{"1", "+", "j"}]}], "]"}]}], 
    SuperscriptBox["k", "2"]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "+", "i"}], ",", "j"}], "]"}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"u", "[", 
       RowBox[{"i", ",", "j"}], "]"}]}], "+", 
     RowBox[{"u", "[", 
      RowBox[{
       RowBox[{"1", "+", "i"}], ",", "j"}], "]"}]}], 
    SuperscriptBox["h", "2"]]}], "\[Equal]", 
  RowBox[{"f", "[", 
   RowBox[{
    RowBox[{"x", "[", "i", "]"}], ",", 
    RowBox[{"y", "[", "j", "]"}]}], "]"}]}]], "Output",
 CellChangeTimes->{3.436891528119648*^9, 3.436891639810648*^9, 
  3.436892712585648*^9, 3.4368928203586483`*^9, 3.436896198390648*^9, 
  3.4372208636320534`*^9, 3.4372238949099627`*^9, 3.6981476449105625`*^9, 
  3.887111584384782*^9, 3.88711190256048*^9},
 CellLabel->"Out[1]=",ExpressionUUID->"3ac9b3b2-7b8c-4d56-86c1-a10e1bbb0c3a"]
}, Open  ]],

Cell["\<\
The next set of definitions set up the sample point grid and put in the \
specifics we need to do this example.\
\>", "Text",
 CellChangeTimes->{{3.437149910530403*^9, 3.4371499544230933`*^9}, {
  3.4373222074960637`*^9, 
  3.437322243268715*^9}},ExpressionUUID->"51fdbabe-7331-41dc-9d3d-\
1b3b4502e7bf"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
   RowBox[{"x", " ", 
    RowBox[{"Exp", "[", "y", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a", " ", "=", " ", "0."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"b", "=", "2."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c", " ", "=", " ", "0."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d", " ", "=", " ", "1."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m", "=", "5"}], ";"}]}], "Input",
 CellChangeTimes->{{3.4368917657856483`*^9, 3.436891808088648*^9}, {
  3.4368927886486483`*^9, 3.436892792744648*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"cded0a30-2376-452f-9b8e-52ac619da642"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"h", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"b", "-", "a"}], ")"}], "/", "n"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"k", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"d", "-", "c"}], ")"}], "/", "m"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"x", "[", "i_", "]"}], " ", "=", " ", 
   RowBox[{"a", " ", "+", " ", 
    RowBox[{"i", " ", "h"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"y", "[", "j_", "]"}], " ", "=", " ", 
   RowBox[{"c", " ", "+", " ", 
    RowBox[{"j", " ", "k"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.436891572527648*^9, 3.436891610783648*^9}, {
  3.436891645838648*^9, 3.436891653088648*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"45a17f6c-4d54-45f0-8b18-07be456b1740"],

Cell["\<\
Note in particular that the number of subdivisions in both the x and y \
directions are fairly modest. This will limit the number of sample points and \
thus the number of equations we have to solve.\
\>", "Text",
 CellChangeTimes->{{3.437150839441638*^9, 
  3.4371508760938993`*^9}},ExpressionUUID->"fa71dcdf-4d39-4d97-a18b-\
637f263b6eab"],

Cell["\<\
In a minute we are going to generate a list of equations, with one equation \
for each sample point in the interior of our region. Before we do that, I \
need to identify which variables are associated with the interior points and \
which are boundary point variables. The following two list definitions do \
this.\
\>", "Text",
 CellChangeTimes->{{3.437149962129324*^9, 3.4371500323294926`*^9}, {
  3.4371508846554675`*^9, 
  3.437150885202283*^9}},ExpressionUUID->"0cb219a2-1069-4228-a402-\
6b8f1506dbef"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"innerVars", " ", "=", " ", 
  RowBox[{"Flatten", "[", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"i", ",", "j"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"m", "-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.436891696496648*^9, 3.4368917375906477`*^9}, {
  3.436891821119648*^9, 3.4368918252076483`*^9}, {3.4372208298515177`*^9, 
  3.4372208400278845`*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"6c1304fc-76a2-441c-bbb6-c6cf90aa484e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"1", ",", "1"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"2", ",", "1"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"3", ",", "1"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"4", ",", "1"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"5", ",", "1"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"1", ",", "2"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"2", ",", "2"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"3", ",", "2"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"4", ",", "2"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"5", ",", "2"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"1", ",", "3"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"2", ",", "3"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"3", ",", "3"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"4", ",", "3"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"5", ",", "3"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"1", ",", "4"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"2", ",", "4"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"3", ",", "4"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"4", ",", "4"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"5", ",", "4"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.4368918263406477`*^9, 3.4368927288586483`*^9, {3.436892825283648*^9, 
   3.436892831802648*^9}, 3.436896203940648*^9, 3.4372208469215527`*^9, 
   3.4372239087069254`*^9, 3.6981476449730654`*^9, 3.887111584536558*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"af048a41-8257-4c5e-96cc-23ceb70b9e02"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"leftVars", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"0", ",", "j"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", "m"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rightVars", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"n", ",", "j"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", "m"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bottomVars", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"i", ",", "0"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"topVars", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"i", ",", "m"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"edgeVars", " ", "=", " ", 
  RowBox[{"Flatten", "[", 
   RowBox[{"{", 
    RowBox[{"leftVars", ",", "rightVars", ",", "bottomVars", ",", "topVars"}],
     "}"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.436891834312648*^9, 3.436891889488648*^9}, {
  3.4368919368806477`*^9, 3.4368920057926483`*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"ffb0656c-9eb2-4dd6-a42f-4241505b23f3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"0", ",", "0"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"0", ",", "1"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"0", ",", "2"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"0", ",", "3"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"0", ",", "4"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"0", ",", "5"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"6", ",", "0"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"6", ",", "1"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"6", ",", "2"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"6", ",", "3"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"6", ",", "4"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"6", ",", "5"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"1", ",", "0"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"2", ",", "0"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"3", ",", "0"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"4", ",", "0"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"5", ",", "0"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"1", ",", "5"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"2", ",", "5"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"3", ",", "5"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"4", ",", "5"}], "]"}], ",", 
   RowBox[{"u", "[", 
    RowBox[{"5", ",", "5"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.436892007282648*^9, 3.4368927307076483`*^9, 
  3.436892838390648*^9, 3.436896205713648*^9, 3.437220854018435*^9, 
  3.4372239113319426`*^9, 3.6981476449886894`*^9, 3.8871115845558157`*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"8cc5435f-58c0-427c-8a9f-566c95c37823"]
}, Open  ]],

Cell["\<\
Now we are ready to generate the list of equations to solve. Note that these \
equations involve both the inner sample point variables (such as u[1,1]) and \
the boundary sample point variables (such as u[0,1] and u[1,0]).\
\>", "Text",
 CellChangeTimes->{{3.437150048257787*^9, 
  3.437150124473834*^9}},ExpressionUUID->"1550220f-5404-4571-af29-\
07a426b6d245"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allEqns", " ", "=", " ", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{"eqn", "[", 
       RowBox[{"i", ",", "j"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"m", "-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4368920232156477`*^9, 3.436892059944648*^9}, {
  3.436896187459648*^9, 3.436896191993648*^9}, {3.4372209195629916`*^9, 
  3.437220926003334*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"a68c9c59-f41f-49fd-bffa-fdf788172405"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"0", ",", "1"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"1", ",", "0"}], "]"}]}], "-", 
     RowBox[{"68.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"1", ",", "1"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"1", ",", "2"}], "]"}]}], "+", 
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"2", ",", "1"}], "]"}]}]}], "\[Equal]", 
    "0.4071342527200566`"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"1", ",", "1"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"2", ",", "0"}], "]"}]}], "-", 
     RowBox[{"68.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"2", ",", "1"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"2", ",", "2"}], "]"}]}], "+", 
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"3", ",", "1"}], "]"}]}]}], "\[Equal]", 
    "0.8142685054401132`"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"2", ",", "1"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"3", ",", "0"}], "]"}]}], "-", 
     RowBox[{"68.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"3", ",", "1"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"3", ",", "2"}], "]"}]}], "+", 
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"4", ",", "1"}], "]"}]}]}], "\[Equal]", 
    "1.2214027581601699`"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"3", ",", "1"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"4", ",", "0"}], "]"}]}], "-", 
     RowBox[{"68.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"4", ",", "1"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"4", ",", "2"}], "]"}]}], "+", 
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"5", ",", "1"}], "]"}]}]}], "\[Equal]", 
    "1.6285370108802264`"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"4", ",", "1"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"5", ",", "0"}], "]"}]}], "-", 
     RowBox[{"68.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"5", ",", "1"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"5", ",", "2"}], "]"}]}], "+", 
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"6", ",", "1"}], "]"}]}]}], "\[Equal]", 
    "2.0356712636002827`"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"0", ",", "2"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"1", ",", "1"}], "]"}]}], "-", 
     RowBox[{"68.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"1", ",", "2"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"1", ",", "3"}], "]"}]}], "+", 
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"2", ",", "2"}], "]"}]}]}], "\[Equal]", 
    "0.4972748992137568`"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"1", ",", "2"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"2", ",", "1"}], "]"}]}], "-", 
     RowBox[{"68.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"2", ",", "2"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"2", ",", "3"}], "]"}]}], "+", 
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"3", ",", "2"}], "]"}]}]}], "\[Equal]", 
    "0.9945497984275136`"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"2", ",", "2"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"3", ",", "1"}], "]"}]}], "-", 
     RowBox[{"68.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"3", ",", "2"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"3", ",", "3"}], "]"}]}], "+", 
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"4", ",", "2"}], "]"}]}]}], "\[Equal]", 
    "1.4918246976412703`"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"3", ",", "2"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"4", ",", "1"}], "]"}]}], "-", 
     RowBox[{"68.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"4", ",", "2"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"4", ",", "3"}], "]"}]}], "+", 
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"5", ",", "2"}], "]"}]}]}], "\[Equal]", 
    "1.9890995968550271`"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"4", ",", "2"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"5", ",", "1"}], "]"}]}], "-", 
     RowBox[{"68.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"5", ",", "2"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"5", ",", "3"}], "]"}]}], "+", 
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"6", ",", "2"}], "]"}]}]}], "\[Equal]", "2.486374496068784`"}],
    ",", 
   RowBox[{
    RowBox[{
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"0", ",", "3"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"1", ",", "2"}], "]"}]}], "-", 
     RowBox[{"68.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"1", ",", "3"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"1", ",", "4"}], "]"}]}], "+", 
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"2", ",", "3"}], "]"}]}]}], "\[Equal]", "0.607372933463503`"}],
    ",", 
   RowBox[{
    RowBox[{
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"1", ",", "3"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"2", ",", "2"}], "]"}]}], "-", 
     RowBox[{"68.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"2", ",", "3"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"2", ",", "4"}], "]"}]}], "+", 
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"3", ",", "3"}], "]"}]}]}], "\[Equal]", "1.214745866927006`"}],
    ",", 
   RowBox[{
    RowBox[{
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"2", ",", "3"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"3", ",", "2"}], "]"}]}], "-", 
     RowBox[{"68.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"3", ",", "3"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"3", ",", "4"}], "]"}]}], "+", 
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"4", ",", "3"}], "]"}]}]}], "\[Equal]", "1.822118800390509`"}],
    ",", 
   RowBox[{
    RowBox[{
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"3", ",", "3"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"4", ",", "2"}], "]"}]}], "-", 
     RowBox[{"68.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"4", ",", "3"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"4", ",", "4"}], "]"}]}], "+", 
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"5", ",", "3"}], "]"}]}]}], "\[Equal]", "2.429491733854012`"}],
    ",", 
   RowBox[{
    RowBox[{
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"4", ",", "3"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"5", ",", "2"}], "]"}]}], "-", 
     RowBox[{"68.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"5", ",", "3"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"5", ",", "4"}], "]"}]}], "+", 
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"6", ",", "3"}], "]"}]}]}], "\[Equal]", "3.036864667317515`"}],
    ",", 
   RowBox[{
    RowBox[{
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"0", ",", "4"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"1", ",", "3"}], "]"}]}], "-", 
     RowBox[{"68.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"1", ",", "4"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"1", ",", "5"}], "]"}]}], "+", 
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"2", ",", "4"}], "]"}]}]}], "\[Equal]", "0.741846976164156`"}],
    ",", 
   RowBox[{
    RowBox[{
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"1", ",", "4"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"2", ",", "3"}], "]"}]}], "-", 
     RowBox[{"68.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"2", ",", "4"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"2", ",", "5"}], "]"}]}], "+", 
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"3", ",", "4"}], "]"}]}]}], "\[Equal]", "1.483693952328312`"}],
    ",", 
   RowBox[{
    RowBox[{
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"2", ",", "4"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"3", ",", "3"}], "]"}]}], "-", 
     RowBox[{"68.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"3", ",", "4"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"3", ",", "5"}], "]"}]}], "+", 
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"4", ",", "4"}], "]"}]}]}], "\[Equal]", "2.225540928492468`"}],
    ",", 
   RowBox[{
    RowBox[{
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"3", ",", "4"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"4", ",", "3"}], "]"}]}], "-", 
     RowBox[{"68.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"4", ",", "4"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"4", ",", "5"}], "]"}]}], "+", 
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"5", ",", "4"}], "]"}]}]}], "\[Equal]", "2.967387904656624`"}],
    ",", 
   RowBox[{
    RowBox[{
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"4", ",", "4"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"5", ",", "3"}], "]"}]}], "-", 
     RowBox[{"68.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"5", ",", "4"}], "]"}]}], "+", 
     RowBox[{"24.999999999999996`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"5", ",", "5"}], "]"}]}], "+", 
     RowBox[{"9.`", " ", 
      RowBox[{"u", "[", 
       RowBox[{"6", ",", "4"}], "]"}]}]}], "\[Equal]", 
    "3.7092348808207793`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.436892062026648*^9, 3.436892732753648*^9, 3.436892842586648*^9, 
   3.436896207335648*^9, {3.437220856675858*^9, 3.437220879451536*^9}, 
   3.4372209285044384`*^9, 3.4372239175194817`*^9, 3.6981476450043154`*^9, 
   3.8871115845689*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"ac296a9d-c380-4518-9f94-f13d8dc15149"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solving the difference equations", "Subsubsection",
 CellChangeTimes->{{3.4371501399448605`*^9, 
  3.4371501452581425`*^9}},ExpressionUUID->"5d254b8c-749c-4664-8f61-\
4c8229031bb3"],

Cell["\<\
Since the PDE we are working with in this example is linear, the difference \
equations we have to solve are likewise linear.

This suggests that we should try to rewrite our problem as a matrix equation \
A z = B and solve for z.\
\>", "Text",
 CellChangeTimes->{{3.4371501483679757`*^9, 
  3.437150215987303*^9}},ExpressionUUID->"dc2e939e-69c1-49f2-bcdb-\
d1d30bbcf4ac"],

Cell["\<\
The next set of commands construct the matrix A. They do this by going into \
the equations and asking for the coefficients connected to each of the \
interior sample point variables.\
\>", "Text",
 CellChangeTimes->{{3.437150228707925*^9, 3.4371502812937894`*^9}, 
   3.4371509447895494`*^9},ExpressionUUID->"7bb4b568-b7de-4c35-b09b-\
f68ee4a33af6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"allEqns", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{"innerVars", "[", 
        RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "allEqns", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "innerVars", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.436892076904648*^9, 3.436892184561648*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"7c465d99-2338-4302-a5c0-29324584dbb3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "A", "]"}]], "Input",
 CellChangeTimes->{{3.4368921891416483`*^9, 3.436892192088648*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"900c92f6-08a7-4f76-91c3-696c552010d0"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "68.`"}], "9.`", "0", "0", "0", "24.999999999999996`", "0",
       "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"9.`", 
      RowBox[{"-", "68.`"}], "9.`", "0", "0", "0", "24.999999999999996`", "0",
       "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "9.`", 
      RowBox[{"-", "68.`"}], "9.`", "0", "0", "0", "24.999999999999996`", "0",
       "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "9.`", 
      RowBox[{"-", "68.`"}], "9.`", "0", "0", "0", "24.999999999999996`", "0",
       "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "9.`", 
      RowBox[{"-", "68.`"}], "0", "0", "0", "0", "24.999999999999996`", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"24.999999999999996`", "0", "0", "0", "0", 
      RowBox[{"-", "68.`"}], "9.`", "0", "0", "0", "24.999999999999996`", "0",
       "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "24.999999999999996`", "0", "0", "0", "9.`", 
      RowBox[{"-", "68.`"}], "9.`", "0", "0", "0", "24.999999999999996`", "0",
       "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "24.999999999999996`", "0", "0", "0", "9.`", 
      RowBox[{"-", "68.`"}], "9.`", "0", "0", "0", "24.999999999999996`", "0",
       "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "24.999999999999996`", "0", "0", "0", "9.`", 
      RowBox[{"-", "68.`"}], "9.`", "0", "0", "0", "24.999999999999996`", "0",
       "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "24.999999999999996`", "0", "0", "0", "9.`", 
      RowBox[{"-", "68.`"}], "0", "0", "0", "0", "24.999999999999996`", "0", 
      "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "24.999999999999996`", "0", "0", "0", "0", 
      RowBox[{"-", "68.`"}], "9.`", "0", "0", "0", "24.999999999999996`", "0",
       "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "24.999999999999996`", "0", "0", "0", 
      "9.`", 
      RowBox[{"-", "68.`"}], "9.`", "0", "0", "0", "24.999999999999996`", "0",
       "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "24.999999999999996`", "0", "0", "0",
       "9.`", 
      RowBox[{"-", "68.`"}], "9.`", "0", "0", "0", "24.999999999999996`", "0",
       "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "24.999999999999996`", "0", "0",
       "0", "9.`", 
      RowBox[{"-", "68.`"}], "9.`", "0", "0", "0", "24.999999999999996`", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "24.999999999999996`", "0",
       "0", "0", "9.`", 
      RowBox[{"-", "68.`"}], "0", "0", "0", "0", "24.999999999999996`"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "24.999999999999996`",
       "0", "0", "0", "0", 
      RowBox[{"-", "68.`"}], "9.`", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "24.999999999999996`", "0", "0", "0", "9.`", 
      RowBox[{"-", "68.`"}], "9.`", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "24.999999999999996`", "0", "0", "0", "9.`", 
      RowBox[{"-", "68.`"}], "9.`", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "24.999999999999996`", "0", "0", "0", "9.`", 
      RowBox[{"-", "68.`"}], "9.`"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "24.999999999999996`", "0", "0", "0", "9.`", 
      RowBox[{"-", "68.`"}]}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.436892193121648*^9, 3.436892738804648*^9, 
  3.436892849646648*^9, 3.436896215610648*^9, 3.437220891378676*^9, 
  3.437220936210965*^9, 3.4372239269726677`*^9, 3.698147645051195*^9, 
  3.8871115845983477`*^9},
 CellLabel->
  "Out[21]//MatrixForm=",ExpressionUUID->"26bdabf5-0a0d-4df1-adb6-\
1b6948dbc17b"]
}, Open  ]],

Cell["\<\
The left hand sides of many of our equations also contain factors involving \
the edge variables. Since the edge variables are determined by the boundary \
conditions, those terms have to be moved over to the right hand side of the \
equations and ultimately incorporated into B. The following code isolates the \
terms that involve the edge variables and moves them into B.\
\>", "Text",
 CellChangeTimes->{{3.4371502983744287`*^9, 
  3.4371503776673484`*^9}},ExpressionUUID->"737cf6e4-e619-4a24-b6d4-\
5e15e49b63da"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"allEqns", "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", "2"}], "]"}], "]"}], "-", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{
          RowBox[{"allEqns", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"edgeVars", "[", 
           RowBox[{"[", "j", "]"}], "]"}]}], "]"}], " ", 
        RowBox[{"edgeVars", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", 
         RowBox[{"Length", "[", "edgeVars", "]"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", "allEqns", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4368922053926477`*^9, 3.4368923496156483`*^9}, {
  3.4368926820756483`*^9, 3.4368926828666477`*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"c07fd730-b785-4b0f-bb92-99fd8fbf5a47"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.4071342527200566`", "\[VeryThinSpace]", "-", 
    RowBox[{"9.`", " ", 
     RowBox[{"u", "[", 
      RowBox[{"0", ",", "1"}], "]"}]}], "-", 
    RowBox[{"24.999999999999996`", " ", 
     RowBox[{"u", "[", 
      RowBox[{"1", ",", "0"}], "]"}]}]}], ",", 
   RowBox[{"0.8142685054401132`", "\[VeryThinSpace]", "-", 
    RowBox[{"24.999999999999996`", " ", 
     RowBox[{"u", "[", 
      RowBox[{"2", ",", "0"}], "]"}]}]}], ",", 
   RowBox[{"1.2214027581601699`", "\[VeryThinSpace]", "-", 
    RowBox[{"24.999999999999996`", " ", 
     RowBox[{"u", "[", 
      RowBox[{"3", ",", "0"}], "]"}]}]}], ",", 
   RowBox[{"1.6285370108802264`", "\[VeryThinSpace]", "-", 
    RowBox[{"24.999999999999996`", " ", 
     RowBox[{"u", "[", 
      RowBox[{"4", ",", "0"}], "]"}]}]}], ",", 
   RowBox[{"2.0356712636002827`", "\[VeryThinSpace]", "-", 
    RowBox[{"24.999999999999996`", " ", 
     RowBox[{"u", "[", 
      RowBox[{"5", ",", "0"}], "]"}]}], "-", 
    RowBox[{"9.`", " ", 
     RowBox[{"u", "[", 
      RowBox[{"6", ",", "1"}], "]"}]}]}], ",", 
   RowBox[{"0.4972748992137568`", "\[VeryThinSpace]", "-", 
    RowBox[{"9.`", " ", 
     RowBox[{"u", "[", 
      RowBox[{"0", ",", "2"}], "]"}]}]}], ",", "0.9945497984275136`", ",", 
   "1.4918246976412703`", ",", "1.9890995968550271`", ",", 
   RowBox[{"2.486374496068784`", "\[VeryThinSpace]", "-", 
    RowBox[{"9.`", " ", 
     RowBox[{"u", "[", 
      RowBox[{"6", ",", "2"}], "]"}]}]}], ",", 
   RowBox[{"0.607372933463503`", "\[VeryThinSpace]", "-", 
    RowBox[{"9.`", " ", 
     RowBox[{"u", "[", 
      RowBox[{"0", ",", "3"}], "]"}]}]}], ",", "1.214745866927006`", ",", 
   "1.822118800390509`", ",", "2.429491733854012`", ",", 
   RowBox[{"3.036864667317515`", "\[VeryThinSpace]", "-", 
    RowBox[{"9.`", " ", 
     RowBox[{"u", "[", 
      RowBox[{"6", ",", "3"}], "]"}]}]}], ",", 
   RowBox[{"0.741846976164156`", "\[VeryThinSpace]", "-", 
    RowBox[{"9.`", " ", 
     RowBox[{"u", "[", 
      RowBox[{"0", ",", "4"}], "]"}]}], "-", 
    RowBox[{"24.999999999999996`", " ", 
     RowBox[{"u", "[", 
      RowBox[{"1", ",", "5"}], "]"}]}]}], ",", 
   RowBox[{"1.483693952328312`", "\[VeryThinSpace]", "-", 
    RowBox[{"24.999999999999996`", " ", 
     RowBox[{"u", "[", 
      RowBox[{"2", ",", "5"}], "]"}]}]}], ",", 
   RowBox[{"2.225540928492468`", "\[VeryThinSpace]", "-", 
    RowBox[{"24.999999999999996`", " ", 
     RowBox[{"u", "[", 
      RowBox[{"3", ",", "5"}], "]"}]}]}], ",", 
   RowBox[{"2.967387904656624`", "\[VeryThinSpace]", "-", 
    RowBox[{"24.999999999999996`", " ", 
     RowBox[{"u", "[", 
      RowBox[{"4", ",", "5"}], "]"}]}]}], ",", 
   RowBox[{"3.7092348808207793`", "\[VeryThinSpace]", "-", 
    RowBox[{"24.999999999999996`", " ", 
     RowBox[{"u", "[", 
      RowBox[{"5", ",", "5"}], "]"}]}], "-", 
    RowBox[{"9.`", " ", 
     RowBox[{"u", "[", 
      RowBox[{"6", ",", "4"}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.436892351117648*^9, 3.436892694885648*^9, 
  3.436892741433648*^9, 3.436892856403648*^9, 3.4368962217666483`*^9, 
  3.437220980886935*^9, 3.437223934519591*^9, 3.6981476450824533`*^9, 
  3.887111584612255*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"3506e5c5-4180-4cd7-8003-b6e945b3a05b"]
}, Open  ]],

Cell["\<\
The last step needed to construct our system A z = B is to introduce the \
boundary conditions. These conditions tell us what values the edge variables \
should take.\
\>", "Text",
 CellChangeTimes->{{3.437150388325167*^9, 
  3.4371504257672434`*^9}},ExpressionUUID->"9def6ef1-a5de-4c61-b870-\
155d78bb9d08"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"0", ",", "j_"}], "]"}], " ", "=", " ", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"n", ",", "j_"}], "]"}], " ", "=", " ", 
   RowBox[{"2", " ", 
    RowBox[{"Exp", "[", 
     RowBox[{"y", "[", "j", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"i_", ",", "0"}], "]"}], " ", "=", " ", 
   RowBox[{"x", "[", "i", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"i_", ",", "m"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "i", "]"}], " ", "E"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4368923878806477`*^9, 3.436892506631648*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"9e1e0cdf-66ae-4c35-ab6b-ca0b8f16acd7"],

Cell["\<\
With the boundary conditions now set, B reduces to a vector of numbers, and \
our system A z = B is complete and ready to solve.\
\>", "Text",
 CellChangeTimes->{{3.4371504334863887`*^9, 
  3.437150471332076*^9}},ExpressionUUID->"653febfe-8139-4dd4-b319-\
6de8c6bea24e"],

Cell[CellGroupData[{

Cell[BoxData["B"], "Input",
 CellChangeTimes->{3.436896246720648*^9},
 CellLabel->"In[27]:=",ExpressionUUID->"1a80dcd8-687b-4fd9-b89e-1dc59bac7cf9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "7.926199080613276`"}], ",", 
   RowBox[{"-", "15.852398161226551`"}], ",", 
   RowBox[{"-", "23.778597241839826`"}], ",", 
   RowBox[{"-", "31.704796322453102`"}], ",", 
   RowBox[{"-", "61.61624504994943`"}], ",", "0.4972748992137568`", ",", 
   "0.9945497984275136`", ",", "1.4918246976412703`", ",", 
   "1.9890995968550271`", ",", 
   RowBox[{"-", "24.366470061474082`"}], ",", "0.607372933463503`", ",", 
   "1.214745866927006`", ",", "1.822118800390509`", ",", "2.429491733854012`",
    ",", 
   RowBox[{"-", "29.761273739711648`"}], ",", 
   RowBox[{"-", "21.910501594327883`"}], ",", 
   RowBox[{"-", "43.821003188655766`"}], ",", 
   RowBox[{"-", "65.73150478298365`"}], ",", 
   RowBox[{"-", "87.64200637731153`"}], ",", 
   RowBox[{"-", "149.61224468450382`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.436896247912648*^9, 3.437220990031597*^9, 
  3.437223942316516*^9, 3.6981476450824533`*^9, 3.887111584639429*^9},
 CellLabel->"Out[27]=",ExpressionUUID->"0f2a578b-2e34-4a66-9b94-30b38c328c0b"]
}, Open  ]],

Cell["\<\
Because this system is fairly modest in size, we can solve in a fairly crude \
way.\
\>", "Text",
 CellChangeTimes->{{3.437150487536031*^9, 
  3.4371505081620865`*^9}},ExpressionUUID->"d39e6ff5-d76b-4b12-b7f2-\
f779d05111d6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"z", " ", "=", " ", 
  RowBox[{"LinearSolve", "[", 
   RowBox[{"A", ",", "B"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.436892912034648*^9, 3.436892918223648*^9}, {
  3.5153260067325277`*^9, 3.515326011396928*^9}},
 CellLabel->"In[28]:=",ExpressionUUID->"62e4217a-5bc7-40d0-b569-b6ac56d7a0a0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.407264617297602`", ",", "0.8145237500231615`", ",", 
   "1.2217662104032783`", ",", "1.6289636868786277`", ",", 
   "2.036042322763833`", ",", "0.4974832458166084`", ",", 
   "0.9949575756416204`", ",", "1.4924047253386803`", ",", 
   "1.989778303471583`", ",", "2.4869583886433437`", ",", "0.60759608006114`",
    ",", "1.215183178043243`", ",", "1.822742713942831`", ",", 
   "2.4302265614047514`", ",", "3.0375055026373277`", ",", 
   "0.7420070651926652`", ",", "1.484008537471651`", ",", 
   "2.2259927024001627`", ",", "2.9679282549346446`", ",", 
   "3.709724066836012`"}], "}"}]], "Output",
 CellChangeTimes->{3.4368929202856483`*^9, 3.436896251828648*^9, 
  3.437220993908308*^9, 3.437223945722788*^9, 3.69814764509807*^9, 
  3.887111584658496*^9},
 CellLabel->"Out[28]=",ExpressionUUID->"f97b73bc-c404-4ca8-b073-d6f302ac83e6"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructing the solution", "Subsubsection",
 CellChangeTimes->{{3.437150526131757*^9, 
  3.437150531913303*^9}},ExpressionUUID->"b745e42a-7dcd-41c7-9e0d-\
80fd56fe1450"],

Cell[TextData[{
 "The last list we generated is a list of numerical values we want to apply \
to our inner sample point variables. The next ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " command goes down the list of inner sample point variables and sets each \
one equal to the corresponding number in z."
}], "Text",
 CellChangeTimes->{{3.4371505371010685`*^9, 
  3.43715060095349*^9}},ExpressionUUID->"b183ceff-b8d5-48fc-97b1-\
2383f1fa1193"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MapThread", "[", 
  RowBox[{"Set", ",", 
   RowBox[{"{", 
    RowBox[{"innerVars", ",", "z"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.436892968673648*^9, 3.436892988902648*^9}, {
  3.4368930936746483`*^9, 3.436893102640648*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"e61583de-8f83-45a7-a7a8-f78935ad224a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.407264617297602`", ",", "0.8145237500231615`", ",", 
   "1.2217662104032783`", ",", "1.6289636868786277`", ",", 
   "2.036042322763833`", ",", "0.4974832458166084`", ",", 
   "0.9949575756416204`", ",", "1.4924047253386803`", ",", 
   "1.989778303471583`", ",", "2.4869583886433437`", ",", "0.60759608006114`",
    ",", "1.215183178043243`", ",", "1.822742713942831`", ",", 
   "2.4302265614047514`", ",", "3.0375055026373277`", ",", 
   "0.7420070651926652`", ",", "1.484008537471651`", ",", 
   "2.2259927024001627`", ",", "2.9679282549346446`", ",", 
   "3.709724066836012`"}], "}"}]], "Output",
 CellChangeTimes->{3.436892990650648*^9, 3.436893108782648*^9, 
  3.437220999410737*^9, 3.4372239739885936`*^9, 3.698147645113696*^9, 
  3.887111584668714*^9},
 CellLabel->"Out[29]=",ExpressionUUID->"9ae6bca5-2870-4f54-8380-804d5bff9acd"]
}, Open  ]],

Cell["\<\
We now have a complete set of values. We have values for both the edge and \
inner sample points. Here is a table of x, y, and u values for all of our \
sample points.\
\>", "Text",
 CellChangeTimes->{{3.4371506088119593`*^9, 
  3.4371506490729456`*^9}},ExpressionUUID->"21f2185e-d8a2-460f-ab17-\
1a3c6db1c66a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pts", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "[", "i", "]"}], ",", 
      RowBox[{"y", "[", "j", "]"}], ",", 
      RowBox[{"u", "[", 
       RowBox[{"i", ",", "j"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "0", ",", "n"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", "m"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4368931177556477`*^9, 3.436893188289648*^9}, {
  3.436893242585648*^9, 3.436893246073648*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"6d28c828-c349-4de8-898b-90f68fd9fad3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.`", ",", "0.`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "0.2`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "0.4`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "0.6000000000000001`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "0.8`", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "1.`", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.3333333333333333`", ",", "0.`", ",", "0.3333333333333333`"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3333333333333333`", ",", "0.2`", ",", "0.407264617297602`"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.3333333333333333`", ",", "0.4`", ",", "0.4974832458166084`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
      "0.3333333333333333`", ",", "0.6000000000000001`", ",", 
       "0.60759608006114`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.3333333333333333`", ",", "0.8`", ",", "0.7420070651926652`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"0.3333333333333333`", ",", "1.`", ",", "0.9060939428196817`"}],
       "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.6666666666666666`", ",", "0.`", ",", "0.6666666666666666`"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.6666666666666666`", ",", "0.2`", ",", "0.8145237500231615`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
      "0.6666666666666666`", ",", "0.4`", ",", "0.9949575756416204`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
      "0.6666666666666666`", ",", "0.6000000000000001`", ",", 
       "1.215183178043243`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.6666666666666666`", ",", "0.8`", ",", "1.484008537471651`"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.6666666666666666`", ",", "1.`", ",", "1.8121878856393634`"}],
       "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0.`", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0.2`", ",", "1.2217662104032783`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0.4`", ",", "1.4924047253386803`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0.6000000000000001`", ",", "1.822742713942831`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0.8`", ",", "2.2259927024001627`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "1.`", ",", "2.718281828459045`"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.3333333333333333`", ",", "0.`", ",", "1.3333333333333333`"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1.3333333333333333`", ",", "0.2`", ",", "1.6289636868786277`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"1.3333333333333333`", ",", "0.4`", ",", "1.989778303471583`"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1.3333333333333333`", ",", "0.6000000000000001`", ",", 
       "2.4302265614047514`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1.3333333333333333`", ",", "0.8`", ",", "2.9679282549346446`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"1.3333333333333333`", ",", "1.`", ",", "3.624375771278727`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.6666666666666665`", ",", "0.`", ",", "1.6666666666666665`"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.6666666666666665`", ",", "0.2`", ",", "2.036042322763833`"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1.6666666666666665`", ",", "0.4`", ",", "2.4869583886433437`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
      "1.6666666666666665`", ",", "0.6000000000000001`", ",", 
       "3.0375055026373277`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.6666666666666665`", ",", "0.8`", ",", "3.709724066836012`"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.6666666666666665`", ",", "1.`", ",", "4.530469714098408`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2.`", ",", "0.`", ",", "2.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.`", ",", "0.2`", ",", "2.4428055163203397`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.`", ",", "0.4`", ",", "2.9836493952825407`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.`", ",", "0.6000000000000001`", ",", "3.644237600781018`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.`", ",", "0.8`", ",", "4.451081856984936`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.`", ",", "1.`", ",", "5.43656365691809`"}], "}"}]}], "}"}]}],
   "}"}]], "Output",
 CellChangeTimes->{3.436893189960648*^9, 3.4368932504316483`*^9, 
  3.43722100206816*^9, 3.437223979988632*^9, 3.698147645113696*^9, 
  3.8871115846885357`*^9},
 CellLabel->"Out[30]=",ExpressionUUID->"3ab35d81-9f95-43cc-877c-307f99029123"]
}, Open  ]],

Cell["Here is a plot of those points in space.", "Text",
 CellChangeTimes->{{3.437150658540605*^9, 
  3.437150664102464*^9}},ExpressionUUID->"6ee13c61-7029-439e-939d-\
57f8f7a1ca71"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plot2", " ", "=", " ", 
  RowBox[{"ListPointPlot3D", "[", 
   RowBox[{
    RowBox[{"ArrayFlatten", "[", 
     RowBox[{"pts", ",", "1"}], "]"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.436893252598648*^9, 3.4368932583996477`*^9}, {
  3.436893631566648*^9, 3.436893642415648*^9}, {3.436893701360648*^9, 
  3.436893704654648*^9}, {3.436893814104648*^9, 3.436893818520648*^9}, {
  3.4368938979136477`*^9, 3.436893910232648*^9}, {3.436894110060648*^9, 
  3.436894114816648*^9}, {3.4368941523216476`*^9, 3.436894156808648*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"9e59e552-fa3b-4ed0-a2f5-b0a8b4702d79"],

Cell[BoxData[
 Graphics3DBox[{{
    {RGBColor[1, 0, 0], PointSize[
      NCache[
       Rational[7, 360], 0.019444444444444445`]], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGDQAmJmBsJg1kwQOGmPXfwmhriJMQg8xqH+JYY4BHyAi4eC
wVUMPoyGucdAln3ufIFbaOI37W8dO/r98LX7cHGYe154LQzNLXyMpv6l/dcX
Z2a27ntuj2rvB/uekoKdO/69gYo/RXPPU7g4zD2bXFtlpgi8QhO/af/bgtN1
47X3cHGYe3JaW18lF35GU//S/te5sj31+76j2Qtzzx979PBC5X+Au2fy4gs7
o3o+o4nftF8w+/exxw++w8Vh7mFpmub8RfMvmnpgfPXwO189x+iAbk9muEg3
135WB4g7v6KFz1d7GA1zz0I7CSsbgV9o4jft282sjyle+w8Xh7nnwZUZ86UK
mR1Q1b+0n9Fjpx24jx3NXlj48DisAoNfcPfA+DAa5h758DV9FzwZHFDFb9rH
Pe4t8HrKDBeHuWfWr8j153040NS/tA/5evB881peNHs/2F/3eFZsLC8EDTcG
GM2AxneAuad3TcS8u13MaOI37R/s/z2p+R47XBzmng8rBbnT1HnR1L+0f+n2
L+3FWUE0e2HxJeoAAMKrZPU=
      "]]}, {}, {}}, {}},
  Axes->True,
  AxesLabel->{None, None, None},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGrids->None,
  FaceGridsStyle->Automatic,
  Lighting->{{"Ambient", 
     GrayLevel[0.5]}, {"Directional", 
     GrayLevel[0.5], 
     ImageScaled[{0, 2, 2}]}, {"Directional", 
     GrayLevel[0.5], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.5], 
     ImageScaled[{2, 0, 2}]}},
  PlotRange->{{0., 2.}, {0., 1.}, Automatic},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.436893260975648*^9, 3.436893644607648*^9, 3.436893705849648*^9, 
   3.4368938199836483`*^9, {3.436893902305648*^9, 3.436893911883648*^9}, 
   3.436894116389648*^9, 3.436894158188648*^9, 3.437221009727791*^9, 
   3.437223983316778*^9, 3.698147646301258*^9, 3.887111584903062*^9},
 CellLabel->"Out[31]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>", "ImageResolution" -> \
72.],ExpressionUUID->"d2bd05c6-6a9a-4ace-bb15-c31b6e9aed8a"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Judging the quality of the solution", "Subsubsection",
 CellChangeTimes->{{3.437150671632847*^9, 
  3.437150680022505*^9}},ExpressionUUID->"8aad6dc8-ce1e-4918-95ec-\
f8c1b065c96f"],

Cell["\<\
Since this is a textbook example, we have the exact solution at our disposal.\
\>", "Text",
 CellChangeTimes->{{3.43715068414703*^9, 
  3.4371507094097443`*^9}},ExpressionUUID->"9a1bb71e-4fa5-452a-9683-\
07acea783837"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"w", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
  RowBox[{"x", " ", 
   RowBox[{"Exp", "[", "y", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.436893654901648*^9, 3.4368936857526484`*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"06eb8fda-ee41-4952-9ef6-5d5051df81a3"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", "y"], " ", "x"}]], "Output",
 CellChangeTimes->{3.436893687143648*^9, 3.437221016418244*^9, 
  3.4372239886918125`*^9, 3.698147646410636*^9, 3.887111584923781*^9},
 CellLabel->"Out[32]=",ExpressionUUID->"7039f7f6-0a1a-4300-8928-7639d1983b61"]
}, Open  ]],

Cell["Here is a plot of the exact solution.", "Text",
 CellChangeTimes->{{3.437150718830534*^9, 
  3.4371507242830305`*^9}},ExpressionUUID->"80a2a318-9934-4497-bfdd-\
45b85349cf16"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plot1", " ", "=", " ", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"w", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "a", ",", "b"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "c", ",", "d"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.436893688010648*^9, 3.436893721304648*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"f3c2b958-1e63-4258-a23b-737deed0b4a4"],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJx1nHc81f/7/8859h4h7YwolVLa5XVkFA2lNIhoL7QITZWmEakoKSMpDaUk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    "], {{
      {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
        GrayLevel[1], 3], 
       StyleBox[GraphicsGroup3DBox[
         TagBox[{Polygon3DBox[CompressedData["
1:eJw1mXngTVX3xu89e59QCiHzTIY0GKIUMqUyhaIXjYQyJ2k0ZMicprdoLg2S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            "]], Polygon3DBox[CompressedData["
1:eJw1mnfgz1UfxT/33o+RJMloyMompfGkTVMKpaVCGS0aGkakjJKUStEwCiEq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            "]], Polygon3DBox[CompressedData["
1:eJwt13ncjWUaAODvO+dIliRLRpFBGEKTtawjW9nK3tgauylLZclkKWPf96US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            "]]},
          Annotation[#, "Charting`Private`Tag$8309#1"]& ]],
        Lighting->{{"Ambient", 
           RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
          "Directional", 
           RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
           ImageScaled[{0, 2, 2}]}, {"Directional", 
           RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
           ImageScaled[{2, 2, 2}]}, {"Directional", 
           RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
           ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
      {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0rsvpFEYwOGPcRsMK6Jd0RAFpSgoN4pViSjoiGK3WIlsQakQOh1/AS0R
+k3o3MfMuM2ystkIu2Tjfg3PSRS/eU7mO5nznsxX0zvQ8S0niqJR3SqsL/Vb
87lR9IE/WM0NNvKQrTxnO5/Zw9JYFCX01bqew2zmONs4xS7OsJ+L/M5l/ucJ
77Wta/3TioFSXGWaa8xwnTthJu5yk3vcYlL74Xd4wBSzTPMnMzzkDo+4y1+c
dY9TPuhYN+GOmjBbkiNc4iAX2MdpdnKSnzjGJg6xjrX6Yh1nNx+d8Zl/2cIs
G8K9+JEX9v3hncp1FfaqyoxlrGSCFSwNe1jCBItZwng4j0UsYL4KrWMsCP9x
+I6vytNLeKYnGSOa83H2/j68Acy/Svc=
        "]]}, 
      {GrayLevel[0.2], 
       Line3DBox[{690, 1004, 473, 689, 1113, 912, 691, 1114, 913, 692, 1115, 
        914, 693, 1116, 915, 694, 1117, 916, 695, 1118, 1010, 1217, 696, 1119,
         917, 697, 1120, 918, 698, 1121, 919, 699, 1122, 920, 700, 1123, 921, 
        701, 1124, 922, 702, 1322, 1005, 923, 1006}], 
       Line3DBox[{704, 1011, 1218, 703, 488, 705, 1125, 924, 706, 1126, 925, 
        707, 1127, 926, 708, 1128, 927, 709, 1129, 1012, 1219, 710, 1013, 
        1220, 711, 1130, 928, 712, 1131, 929, 713, 1132, 930, 714, 1133, 931, 
        715, 1134, 932, 716, 1135, 933, 717}], 
       Line3DBox[{719, 1014, 1221, 718, 1015, 1222, 720, 504, 721, 1136, 934, 
        722, 1137, 935, 723, 1138, 936, 724, 1139, 1016, 1223, 725, 1017, 
        1224, 726, 1018, 1225, 727, 1140, 937, 728, 1141, 938, 729, 1142, 939,
         730, 1143, 940, 731, 1144, 941, 732}], 
       Line3DBox[{734, 1019, 1226, 733, 1020, 1227, 735, 1021, 1228, 736, 520,
         737, 1145, 942, 738, 1146, 943, 739, 1147, 1022, 1229, 740, 1023, 
        1230, 741, 1024, 1231, 742, 1025, 1232, 743, 1148, 944, 744, 1149, 
        945, 745, 1150, 946, 746, 1151, 947, 747}], 
       Line3DBox[{749, 1026, 1233, 748, 1027, 1234, 750, 1028, 1235, 751, 
        1029, 1236, 752, 536, 753, 1152, 948, 754, 1153, 1030, 1237, 755, 
        1031, 1238, 756, 1032, 1239, 757, 1033, 1240, 758, 1034, 1241, 759, 
        1154, 949, 760, 1155, 950, 761, 1156, 951, 762}], 
       Line3DBox[{764, 1035, 1242, 763, 1036, 1243, 765, 1037, 1244, 766, 
        1038, 1245, 767, 1039, 1246, 768, 552, 769, 1157, 1040, 1247, 770, 
        1041, 1248, 771, 1042, 1249, 772, 1043, 1250, 773, 1044, 1251, 774, 
        1045, 1252, 775, 1158, 952, 776, 1159, 953, 777}], 
       Line3DBox[{781, 1160, 954, 779, 1161, 955, 783, 1162, 956, 785, 1163, 
        957, 787, 1164, 958, 789, 1165, 959, 791, 1166, 569, 793, 1167, 960, 
        795, 1168, 961, 797, 1169, 962, 799, 1170, 963, 801, 1171, 964, 803, 
        1172, 965, 805, 1174, 967, 807}], 
       Line3DBox[{806, 966, 1173, 804, 1265, 1057, 802, 1264, 1056, 800, 1263,
         1055, 798, 1262, 1054, 796, 1261, 1053, 794, 1260, 1052, 792, 1259, 
        568, 790, 1258, 1051, 788, 1257, 1050, 786, 1256, 1049, 784, 1255, 
        1048, 782, 1254, 1047, 778, 1253, 1046, 780}], 
       Line3DBox[{809, 1058, 1266, 808, 1175, 968, 810, 1176, 969, 811, 1177, 
        970, 812, 1178, 971, 813, 1179, 972, 814, 1180, 1059, 1267, 815, 585, 
        816, 1181, 973, 817, 1182, 974, 818, 1183, 975, 819, 1184, 976, 820, 
        1185, 977, 821, 1186, 978, 822}], 
       Line3DBox[{824, 1060, 1268, 823, 1061, 1269, 825, 1187, 979, 826, 1188,
         980, 827, 1189, 981, 828, 1190, 982, 829, 1191, 1062, 1270, 830, 
        1063, 1271, 831, 601, 832, 1192, 983, 833, 1193, 984, 834, 1194, 985, 
        835, 1195, 986, 836, 1196, 987, 837}], 
       Line3DBox[{839, 1064, 1272, 838, 1065, 1273, 840, 1066, 1274, 841, 
        1197, 988, 842, 1198, 989, 843, 1199, 990, 844, 1200, 1067, 1275, 845,
         1068, 1276, 846, 1069, 1277, 847, 617, 848, 1201, 991, 849, 1202, 
        992, 850, 1203, 993, 851, 1204, 994, 852}], 
       Line3DBox[{854, 1070, 1278, 853, 1071, 1279, 855, 1072, 1280, 856, 
        1073, 1281, 857, 1205, 995, 858, 1206, 996, 859, 1207, 1074, 1282, 
        860, 1075, 1283, 861, 1076, 1284, 862, 1077, 1285, 863, 633, 864, 
        1208, 997, 865, 1209, 998, 866, 1210, 999, 867}], 
       Line3DBox[{869, 1078, 1286, 868, 1079, 1287, 870, 1080, 1288, 871, 
        1081, 1289, 872, 1082, 1290, 873, 1211, 1000, 874, 1212, 1083, 1291, 
        875, 1084, 1292, 876, 1085, 1293, 877, 1086, 1294, 878, 1087, 1295, 
        879, 649, 880, 1213, 1001, 881, 1214, 1002, 882}], 
       Line3DBox[{884, 1088, 1296, 883, 1089, 1297, 885, 1090, 1298, 886, 
        1091, 1299, 887, 1092, 1300, 888, 1093, 1301, 889, 1215, 1094, 1302, 
        890, 1095, 1303, 891, 1096, 1304, 892, 1097, 1305, 893, 1098, 1306, 
        894, 1099, 1307, 895, 665, 896, 1216, 1003, 897}], 
       Line3DBox[{911, 1009, 685, 910, 1321, 1111, 909, 1320, 1110, 908, 1319,
         1109, 907, 1318, 1108, 906, 1317, 1107, 905, 1316, 1106, 904, 1315, 
        1314, 1105, 903, 1313, 1104, 902, 1312, 1103, 901, 1311, 1102, 900, 
        1310, 1101, 899, 1309, 1100, 898, 1112, 1308, 1007, 1008}]}, 
      {GrayLevel[0.2], 
       Line3DBox[{251, 474, 1113, 252, 488, 280, 1222, 503, 295, 1227, 518, 
        310, 1234, 533, 325, 1243, 548, 340, 1254, 563, 1161, 355, 578, 1175, 
        370, 1269, 593, 385, 1273, 608, 400, 1279, 623, 415, 1287, 638, 430, 
        1297, 653, 445, 1309, 668, 460}], 
       Line3DBox[{253, 475, 1114, 254, 489, 1125, 281, 504, 296, 1228, 519, 
        311, 1235, 534, 326, 1244, 549, 341, 1255, 564, 1162, 356, 579, 1176, 
        371, 594, 1187, 386, 1274, 609, 401, 1280, 624, 416, 1288, 639, 431, 
        1298, 654, 446, 1310, 669, 461}], 
       Line3DBox[{255, 476, 1115, 256, 490, 1126, 282, 505, 1136, 297, 520, 
        312, 1236, 535, 327, 1245, 550, 342, 1256, 565, 1163, 357, 580, 1177, 
        372, 595, 1188, 387, 610, 1197, 402, 1281, 625, 417, 1289, 640, 432, 
        1299, 655, 447, 1311, 670, 462}], 
       Line3DBox[{257, 477, 1116, 258, 491, 1127, 283, 506, 1137, 298, 521, 
        1145, 313, 536, 328, 1246, 551, 343, 1257, 566, 1164, 358, 581, 1178, 
        373, 596, 1189, 388, 611, 1198, 403, 626, 1205, 418, 1290, 641, 433, 
        1300, 656, 448, 1312, 671, 463}], 
       Line3DBox[{259, 478, 1117, 260, 492, 1128, 284, 507, 1138, 299, 522, 
        1146, 314, 537, 1152, 329, 552, 344, 1258, 567, 1165, 359, 582, 1179, 
        374, 597, 1190, 389, 612, 1199, 404, 627, 1206, 419, 642, 1211, 434, 
        1301, 657, 449, 1313, 672, 464}], 
       Line3DBox[{261, 479, 1118, 263, 493, 1129, 285, 508, 1139, 300, 523, 
        1147, 315, 538, 1153, 330, 553, 1157, 345, 568, 1166, 360, 583, 1180, 
        375, 598, 1191, 390, 613, 1200, 405, 628, 1207, 420, 643, 1212, 435, 
        658, 1215, 450, 1314, 673, 465}], 
       Line3DBox[{265, 481, 1119, 266, 1220, 495, 287, 1224, 510, 302, 1230, 
        525, 317, 1238, 540, 332, 1248, 555, 347, 1260, 570, 1167, 362, 585, 
        377, 1271, 600, 392, 1276, 615, 407, 1283, 630, 422, 1292, 645, 437, 
        1303, 660, 452, 1316, 675, 467}], 
       Line3DBox[{267, 482, 1120, 268, 496, 1130, 288, 1225, 511, 303, 1231, 
        526, 318, 1239, 541, 333, 1249, 556, 348, 1261, 571, 1168, 363, 586, 
        1181, 378, 601, 393, 1277, 616, 408, 1284, 631, 423, 1293, 646, 438, 
        1304, 661, 453, 1317, 676, 468}], 
       Line3DBox[{269, 483, 1121, 270, 497, 1131, 289, 512, 1140, 304, 1232, 
        527, 319, 1240, 542, 334, 1250, 557, 349, 1262, 572, 1169, 364, 587, 
        1182, 379, 602, 1192, 394, 617, 409, 1285, 632, 424, 1294, 647, 439, 
        1305, 662, 454, 1318, 677, 469}], 
       Line3DBox[{271, 484, 1122, 272, 498, 1132, 290, 513, 1141, 305, 528, 
        1148, 320, 1241, 543, 335, 1251, 558, 350, 1263, 573, 1170, 365, 588, 
        1183, 380, 603, 1193, 395, 618, 1201, 410, 633, 425, 1295, 648, 440, 
        1306, 663, 455, 1319, 678, 470}], 
       Line3DBox[{273, 485, 1123, 274, 499, 1133, 291, 514, 1142, 306, 529, 
        1149, 321, 544, 1154, 336, 1252, 559, 351, 1264, 574, 1171, 366, 589, 
        1184, 381, 604, 1194, 396, 619, 1202, 411, 634, 1208, 426, 649, 441, 
        1307, 664, 456, 1320, 679, 471}], 
       Line3DBox[{275, 486, 1124, 276, 500, 1134, 292, 515, 1143, 307, 530, 
        1150, 322, 545, 1155, 337, 560, 1158, 352, 1265, 575, 1172, 367, 590, 
        1185, 382, 605, 1195, 397, 620, 1203, 412, 635, 1209, 427, 650, 1213, 
        442, 665, 457, 1321, 680, 472}], 
       Line3DBox[{277, 682, 1322, 683, 278, 501, 1135, 293, 516, 1144, 308, 
        531, 1151, 323, 546, 1156, 338, 561, 1159, 353, 576, 1173, 1174, 368, 
        591, 1186, 383, 606, 1196, 398, 621, 1204, 413, 636, 1210, 428, 651, 
        1214, 443, 666, 1216, 458, 685, 686, 687}], 
       Line3DBox[{459, 667, 684, 1308, 444, 652, 1296, 429, 637, 1286, 414, 
        622, 1278, 399, 607, 1272, 384, 592, 1268, 369, 577, 1266, 354, 1160, 
        562, 1253, 339, 547, 1242, 324, 532, 1233, 309, 517, 1226, 294, 502, 
        1221, 279, 487, 1218, 250, 473, 681, 688}], 
       Line3DBox[{466, 674, 1315, 451, 659, 1302, 436, 644, 1291, 421, 629, 
        1282, 406, 614, 1275, 391, 599, 1270, 376, 584, 1267, 361, 569, 1259, 
        346, 554, 1247, 331, 539, 1237, 316, 524, 1229, 301, 509, 1223, 286, 
        494, 1219, 264, 480, 1217, 262}]}, {}, {}}},
    VertexNormals->CompressedData["
1:eJxkm3c41mEb92U0aFDJSLIlq5SQuFIkUiRUQkmyaQ8yIjMjhcxoUtk0ECdF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     "]], {}},
  Axes->True,
  AxesLabel->{None, None, None},
  AxesOrigin->{Automatic, Automatic, Automatic},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGrids->None,
  FaceGridsStyle->Automatic,
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]], 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "RotationControl" -> 
    "Globe"},
  PlotRange->{{0., 2.}, {0., 1.}, {0., 5.436562880266182}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.436893722636648*^9, 3.4372210193570414`*^9, 
  3.4372239912699537`*^9, 3.698147647301308*^9, 3.8871115849563007`*^9},
 CellLabel->"Out[33]=",ExpressionUUID->"4c4083a7-61b3-40c2-b25b-f663f8e5a360"]
}, Open  ]],

Cell["\<\
Finally, here are the estimate and the exact solution plotted side by side. \
This demonstrates visually that the estimated values for u[x,y] are not too \
bad.\
\>", "Text",
 CellChangeTimes->{{3.4371507345943427`*^9, 
  3.4371507827606683`*^9}},ExpressionUUID->"b9c81518-007c-47ba-b8ca-\
d8f931d62937"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"plot1", ",", "plot2"}], "]"}]], "Input",
 CellChangeTimes->{{3.436893727625648*^9, 3.436893732655648*^9}},
 CellLabel->"In[34]:=",ExpressionUUID->"8e49c870-ff7a-4b90-83ca-e05d95664849"],

Cell[BoxData[
 Graphics3DBox[{{GraphicsComplex3DBox[CompressedData["
1:eJx1nHc81f/7/8859h4h7YwolVLa5XVkFA2lNIhoL7QITZWmEakoKSMpDaUk
WqSpYRdHtuy95/lWntf1fP/8bp/PP27n/nm+z7nOnZ7nvB6v53WpbHA038xh
sVhaQiyWwJ+fIWuinp2ZcEKv/+c+vdWBt779fbxDWy9wjEkSA/xkg+bDv4/v
VeTw1U3SkUvffas45s9j9XiFqc/sech5Vs0r/j7+9k4zRt2kGHnmKblPfx+f
0373xZ73G3nC+nEVfx8bX9nwO9a+GnnITH2RZ38es1l//9eAPPnMhEF/H69/
8s1T3aQJ+QynuNC/j19uuz7ExK8FeZSd4ZS/j4eN2BVhz2tDPnJpauLfx65p
s6f6qXci9529bvnfxz88xN7E2ncjF9SsKPz7eNrsn4t5sb3IXQbt3/33sW9d
RA6fz0deyf/3PwY893t9zOjX2Kp0XDmJnoG/tlbtfBX2Fj0DjwnasPJVWAZ6
Bn5GXHfCdadf6Bn4pBcczquwEvQMfMi+avv7nhXoGbigVmZOkFMtegZ+YHe+
qvGkRvQMvCYl/efLsGb0DHyD5gfvacpt6Bn4j+MJhvc9O9Az8MX5D7vU2d3o
GXjirPDoIKde9Ax8xqWALQpVfPQM3MLFWNp4EpsLnvv9JTHRxpdnLBt5Cj0D
/xASWM5WfoeegYuNvj2drZyFnoFPdnR3ZYcXoGfgEwom5rOUy9Az8NfC1/gs
myr0DHyFtqgKO7wePQNvvjs7hOXUhJ6Bv9RrfMRSbkXPwE+n305iJbSjZ+DL
tthksGy60DPwoV0KpSx2L3oGXuqV0sIK56Nn4D9kE48fU2NzwTPwBMvh51lO
HPTc7ymFaf0pNcon8TR6Bp711aM88/Z79Aw8b6XruMzb2egZ+NaiK/X5vYXo
Gbid8r7PGbd/o2fglmZLb31cXoOegWu9VXiT39uAnoFH2ByfmJPejJ6Bq3XV
X8243Yaegd+8ZC367VAnegY+XCfF6ePyHvQMPPDLzJIkDT56Bi6huyIyv5fF
Bc/AP7HFC6y2cdAz8FPf3yjmpAug534f6cxPRYc7P0+cRc/A71kVbp9v8RE9
A19/OfG6vsVP9Azc6aiJQCNTjJ6Bx099PEPfogI9A2dVDN3lu6MOPQNX+6af
2sA0oWfgRmOdqwJMW9Ez8G3H7wrqW3SgZ+Dn8/JHVq7vRs/A708fNMt3Rx96
xuf5GHYnKJ7FBc/AXVtfxjYwHPSMz6/6863hOwH0DPyaWVNqgKkQeu5/39nM
jKXSM123nkfPwHnPl3gfVP2MnoEPbZCLcVPNRc/Aw92PfOcFlqBn4LMl9hu5
qVahZ+DbPz+x9rRoQM/AdX0eBvACm9EzcP6Kuxla+W3oGXiK8i1pN9Uu9Az8
8q8bJp+29KJn4DrLl8z3tGBxwTPwKzGfC2La2egZeI/iwsO8QAH0DHyDy7uh
AnOF0DPw97nz47TyhdFz//vjMcsdP72ocPBCz8C7HM1ZPLkv6Bm4vBZPIVcu
Dz0DV/R+v3KjVBl6Bj769KgbOXI16Bm4EvdFi+b5RvQMPOhFxZCNUq3oGbjq
LEUm2KcDPQO//VR/U45cD3oGPnGKw1kFfz56Br529ZIfmufZ6Blf91LJdqPF
AugZeEGGa88GKSH0jPXIy/oc+yaMnoFvXBahEuwjip7730cho3/kZfPXIB/0
DNytOk28Ysw39Aycd7BaqnxMPnoG3seaIWEf9Bs9A5c2dPH5PaYOPQP3eZsn
Fv2jCT0DH7y5N2VXUBt6Bn5DeKT3OLsu9AxcM1Jv2e8xfegZ+I/wSWeXt7K4
4Bn4tVam6uEPDnoGvt542SLpeEH0DFztiu29XUHC6Bl4efluqZQjougZ+N2Z
7g7j7MTRc3+9xUzQlsG1rK4L6Bl4Q1dt073JqegZ+OnmETvvTS5Ez8CvVCav
45hUoGfgGfXTNO9NbkDPwHk7xEb/mNuCnoGXlOUpc0w60DPwattouYkWPegZ
eGetvtC9ySwueAZ+OCrKPXE6Bz0DZ29X7MueK4iegXtoHHWrmS+MnoGLlVa0
sU1E0TNwrxDzfYPNxNEzcJn1L+onWEii5/66SpnVZediPs3xQ8/Ar3K8Qrw2
pqFn4L1PHsh4bSxCz8AfVFxeukKxCj0Dn+T9+r3nxkb0DFw0cupvxxet6Bl4
YeJtoRWKXegZ+HPesDHTHfrQM/BPXQtCPTey0TPwpyKcKX0+AugZeIjCi0TH
F0LoGbiXivPyogoR9AzcTXtykbmiOHoGvmVO1e5kfUn0DHzZwnDWdAdp9Nz/
+r+ZXZJD322+dBE9A5eLfS2teT8dPQOvOK2wV+N+MXoG/lH307rnAjXoGXhm
wys1jftN6Bm44YIhgY5r2tEz8CfX90k/F+hBz8Dlu37ru69mccEzcNMx/j1j
7nPQM/Djy/SffeYIoWfg8Qfr9jiuEUHPwJsirk1QeCCGnoFrpS8sjxOQRM/A
N/S2hlivlUbPwBf7L9d2Xy2Lnvtfp5KRKN6fECB6CT0DX3fnWoWmTCZ6Bn60
ZBVXU6YUPQM3b1rvGa9Uh56B+x3TrdGQaUHPwHtEZvk1yHeiZ+CbfebNjFfq
Q8/At0qo1Ot7sdEz8OFmakkaMoLoGXiq35hLEr7C6Bm4R7bmtgZ5MfQMfPZQ
rTlZ/hLoGXid9QTpeCVp9Aw8fdmV3WaLZdEz8Ki9yrn6XnLouf/5/lwfTJt6
c8GVy+gZuECJ/xub81noGTgrIlfC5nwZegbOtX9qdWpsA3oGfuz04UfW51vR
M/A3IUYi0+q60DM+f/4p7VNjWVzwDHx09Y6cxhwOesbX7Vh60vq8EHoGbis0
ddKnuaLoGeuRH5yrWyeOnoHfHNV98uYNKfSMz3O5fvCpsbLoGXhDkF3tHHc5
9Az8aFhGUmOOPHru/+9qGe7s4C0HDQLQM/CfC6q3vlD7gZ6Bh+36fitBrRw9
A79/NfP8F8tG9Axc7GiiYYJaO3oGvnnjg947NT3oGXhh2BKrL5Zs9AxcWin5
mQEjiJ6Bzz0zWyFBTQQ9A9/RFb17iqg4egYesEvz650aSfQM/H3+9XEqaTLo
GbjbWHGDL5Zy6Bm4r51Ro8hXefQM/PbVYzcMGAX03P//1zOb12713yhzFT0D
3/70p8uq3J/oGfi7AOtIi9wK9Ax8505N8TdhTegZ+H7x0VyL3A70DPzwHWXn
Klk+egZuEC6a/TqMg56Bf2gW3CP+Wgg9A19swJa0yBVFz8BT/XojbrRKoGfg
FsWd+lWyMugZeK3yQYehSnLoGfhDbmfC6zB59Ax8z7YDYpt1FNAz8CkXWleJ
v1bklj0X/qJh8pjp/xnKVDbl2Vs1P8YcDzg/yCKHXXBCb6M/c9Ge14fr37oq
cyO6aE4F/IZqUHmtPwufv/+/q2PWLFsaOLr7Az4/cLZN8YaVYwLx+YG/dvdp
LpyjwAUO9S8/ND16RocCPj/kkI6HG4ro6/UhjxabHUfrfozPE133bcia3I9Y
P7xu/g3dgufdCtzc1Cs64/68n/6ffszg+ZEK7tdDGTf9fbGx9nzk0/u23rjf
B4/h/69nhM2v7XuzPQ7XA884yunlddG/c3ge02OrrDtPntCD9VD/V8ERefT1
QrH+uXYJVla5cVg/PP/1oBllx9cpYv3wPAZX3BfQ/57W/z7C/c0XExbWA89j
OX7zkWWBgVgPvO584csCIVaKXEk3R0k26w3mk6YcbYMFkxKZpboS+1isVHzd
ay9nnPr7GDis19N3CDaelMZcjspfz2L9xPUTXUMO/X0MHNavdje6Vvk+h3GU
W6vx9/oE1tte9Zj19zFwWB9nK73YeFIRM+hr0nAWqxTXj3OJ1/37GDisf8dy
+zz4YBnz7F/uXoHrmyzqJ/19DBzWp98sW1j5vpKxMrwsxmLV0Jx/qvr4v4/7
Y/F65Ekkz4f18DwF3OUf4uXrcD1wJ5JLp//S7ebzG/F5bre/l2WxmpDD+kNc
hWJti2YmPGF7G5/fjOs9t9hJs1gtyGH9CVnTkMEHWxnnwOBGPr8V1+/J6pZg
sdqQw/qzhUdtWSHtzMIDGTV8fjuuX/Xv/XQgh/U+0U9HVb7vZIZaiFbw+fS+
w+yYySIsVhdyWH/pWHV+Wk03UzNlXgmfT+9HjFRNEWSxepDD+qBlKsHx8n3M
K9m9+Xw+vU8h6Pv39g/lsH75hagHy4ez8O8W8t4+qZJstlMS/n0CZzwbxrCd
0vHvEPgxX0db94c8/HsDbrfowFeWUzH+XQFnf4ut4sqX498P8NBlbSLuD6vx
7wF4SOVVP1uNBvx7AN5I8nP4vQOfvyv34c239PcL/OJEt1dc+Xb8PQIvqRvy
tdC2E39fwKdGP+cde9iNvxfgJ/asrRrd14v+ge8IPHTIVoPFBc/A5d2+nIhe
wkbPkPeunaLslpv+Fj0Dt30u8SInPQM9A/dbKzHH+MUv9Ay85JCQdU56CXoG
3rPYI8jnA/13ClxphFCe0Yta9Aw8wDlJ6siaRvQMPJzk5+AZ+GPj+Ut0l7Sh
Z+CvtTn2Ph860DPwFKUkzyr9bvQM/Gef+z2jF73oGfi+5tFblg1jccEzcNdy
VtvhNWz0DPwor9Aj6hIHPUPee459z+yq6Tv0DHzuXK8TgaZZ6Bn4kwOGBWX1
BegZ+OWcwyMCTcvQM3DzA2sXMder0DNwGcVprmX19egZ+Ja1ZzKMQprQM3AD
kp+DZ+Cq7RvZNc3t6Bnz+ffLlZnrXegZeL4/M8nPuBc9A3+xcaJxWT0fPQNf
EuilHbSYjZ5x/THBeKMQDnoGPn7bQaP6VgH0DHmvXKv5ign579Ez8KXjB7uM
z89Gz8DFHeZvvKlRhJ6BOxi7io/P/42egaeNjH709FINegZ+9eC+CTc1GtEz
8C/l0sc2c1rQM/Bekp+DZ+CT3xhpNjzvRM/A7SYUuT291IOegV8MOPTNbQ8f
PQPfyJGUu6nB5oJn4AfjcuKP+3PQM3B/h9ubNnME0TPw++pO0gt3C6FnyHud
msfwbvh8RM/APe8/qA/2od8TgEdPLuuI3VmMnoEHije7BvtUoGfgx0tZ3R4x
degZ+PT1Iq9idzahZ+DjF3sfuXu4FT1jDk/yc/AMXEEjiO8b0o2egYsNUnvj
EdOHnoHz+SvfvChmccEzcFfngJuxOznoGXhzDe9YdIsAegbusHGU3d3DQugZ
eEXOBv1wYRH0DHlvs8mjhePtPqNn4CtyPy/SsstFz5hLnw52LfhYgp6Bnwxd
/XWcXRV6Bh5oc0Y2/lADegZeX71pdsHHZvQM3NhVf5OgYjt6Bh5E8nPwDLzl
Ytezpfd70TPwWxeqG54fYnHBM/BlP3I8vqhy0DPw7hEfhxZ8FEDPwG9vin3Y
6CCEnoGbR4UbCiqKoGfgvY1+OUoJougZ8t5cN9FabYsv6Bm48K5tvyZa5KFn
4MuWaKgWM2XoGfj1TQEWEy1q0DPw1nkehnOfNqJn4NdM9PKLmFb0DHy+RfuB
05870DPwCpKfg2fgPru2R6UX8NEz8GFzfVXnPmWjZ+B1ifb13m4C6Bl44gLT
F0WMEHoG7v9V46yukAh6Br5thcCq059F0TPwOTkFqrk+4ugZ8t511bfUZjp8
Q8/AVZdV8qc75KNn4KZZ/LbI9N/oGfhJjoTDdIc69Ay8YPD5piLBZvQM/NAD
2QeR6W3oGfgQo8vbHW92oWfgsSQ/B8/AtZ4v2903gs0Fz8BdTw76ViQogJ6B
fzDLHv+uWhA9A1ccFng2Ml0YPQPf9Nuq/PxzUfQMPObRSCPHm+LoGTj7cFGo
+WlJ9Ax5b+45+ZXHV9PrO+DR67Y+c19diJ6BN+97Zzj/RAV6Bn7tndx299UN
6Bn43LQ3D+3sW9Az8Pw8xzb9Ex3oGfjRipHzVAN70DNwWZKfg2fgxUf1Nu/Z
wEHPwB8LXT5jZy+InoGfOF8btdxFGD0DXyln9F3/hCh6Bj7mSlCTjrc4egbe
OrxFUTVQEj0Dfx+6aJZ8uDR6hrw3cnOgooFXGnoG/vnGSvv5XkXoGXiSZ55Z
yYoq9Aw8b+6UIfO9GtEz8DVTnc/5NbSiZ+CZ4+K7i1d0oWfgZqP7dk191oee
MVcn+Tl4Bh4u/Faz6pUAegZexN5s69cghJ6Bj+oVDpytKoqegVt3RKYVrxBH
z8CvNZuKn/eQRM/Ac+pq5k99Jo2egUs6fXhpv18WPUPeW5oVrdick46egRcG
tNk25RSjZ+Df3yvMqDauQc/A17sFCjflNKFn4Kt8I/c4XGhHz8CXRj7LqzLu
Qc/Aw9aXhMUcYXHBM/CRJD8Hz8CvOjdJT54mhJ6BK3HcDB0uiKBn4H5ebLd7
1WLoGbj0kLMPq4wl0TPws+GyZWNDpdEz3l9QXuwVc0QWPeN9gV8ykeb35NAz
5L1RWfsljJhM9AzcqWuNiSFTip6BK5xrl/xtU4eegedKLqowYFrQM/C7K4d+
VjDrRM/AXYMqo8ps+tAzcPW9ecZWz9joGbgkyc/BM/DW51FjJ3wQRs/Af1lf
DFQwE0PPwJPZB8V7syXQM/B7tzYcLLORRs/AP6uPaduyTxY9A3/VFqBt9UwO
PQN//FFyq1m3PHqGvK5sc94viddZ6Bk418ROSuJ1GXrGHHtSleJCswb0DLwu
Xu2W+OtW9Axc0dha96t2N3oGHrwtpWiBGYsLnjF/1t42bpyIAHrG3J7k5+AZ
uOXzkLhqZ1H0jHn4ET3WV20J9Azc3ZC34MFvKfQMXFzoxYcFZrLoGXjm1nM7
Z0bJoWes//MamXEig9Bn/89o5t6mS5Gzh9Cc0/K8Pj/OPoq53Kzt1CxA88xr
quFljrwIZu3vT2oNhjS3zCM5udS0vqzF9wvR5+zQ9E0J9teYXUyJsEtoKfqM
h3xY3j+8070C/26d+p73TDQ5zty+L/swbRHNG23+R37IIfV7CIwcbTyJ5oSG
pP4st7cr9qjTPPAEqX9j9reXH6Rp7pdM6tdR4tqY1HXg9bU4qZ+ZPXhaW1IX
5kXnSP2e81fO/+bZw4DPI957n/upJzLp1tkZ/83f+n++YV6FqXx0Mab529wn
C9bmxb5kuIWXFlWo0fztF9/lyzP7BGZGk1r81kqa9x5edJe5qP6cUfs5TOXK
uN/oc+QV3mMHXixTGvLY8rh5Ffp8VSypYer3hDlkVrFl3Caax0aQXKthQP7m
QupvKpW2rbxK87eFpP78C1NEJz+lOepkUn/Mg1uBmW9pXppG6nfS26bw4z3N
RfeQ+kdz3VxmvKL5pzyp/1kM713rHZpzPiH1X19s3CdqRHPO1vX3a9RNPjPn
nqQ5/zd/ey9kHOGn/onJnyq9ruAmzd/6f35kkjx6Rq3WoPnbluUHhjjw3jPd
5YEGVXNp/ja9XSaDF/uOmSOW+zHqK805ha9Hepr4JTMhEa9G7TaqQc/Z8/WN
n9m/ZQYXqoUPM6c550iSa4UNyN8aSP1zlj2f46pC87c3pP7So0mPr26k+dsF
Uv/N2ut+8wK70LMtqX934CKeXVIPep5M6l95IsVTpKAPPbNI/beyvFdcOUBz
zjRS/11RlUs7XWnO+Uy5xYcXm8Y4OWgu/m/+dmPnm11+6mnM8Sr9jGoFmr+d
fuVpYuKXyqitv5ORt5Tmb/0/Uxkf8VuDLtyh9ykefDQVduB9Y2YLy5fnXqhE
z0ccSl7zYr8yvqHDSpda16HnpQqHXE38vjAp9bZCzqdpzplCcq35A/K3J6T+
2sPvxFqSaf4WROqvUyt5WaJD87eTpH7Dod+Ft/n2oOddpP4m27Olx0r60HMk
qb+7+8z4wf4053Qh9Uc66k6Ke0hzThNS/zGJBYfDkmnOuc/d9466STbTHHPe
7L/5m1Wm9SlebBZz5ujZFSfDaf5moKm10U89i5lpbfBwTCq9TzTerY0x8ctk
Vr2zCZ+mQ/O3/p+ZzOgOJbG9TtXouXuUT2esfQaT0vXUwX4pvY9Tstcq256X
zuTlP5CNy6A552k4Rzogf9tN6o+bParq8Gmav60h9X84tWHmVlWav3FJ/RNn
7n/1+0Efeh5L6t+vqaV35DILP9dkSf2HN7NnrfxGc84OUv/k7NdmrX005ywk
9fu4bj5uN1YQPU+q0n5rz8tldikM/vHf/G3wvO4b6ia5zEclB3bMcpq/8X0+
HOLF5jBpTj5KWdI0fysvvrjWTz2HsRU0e5abVY6ev0+znW7i95ORf9a6oepw
LXru//mTaXmfKHn8BM05b/A66mPtfzCOhodqL86kOacBybVGDcjfJpD6HT9p
+23cSfM3BVJ/WnVC1f0ZNH/rIfWrLrMJ13Oj+VspqX/TPuXsilSac34h9T9c
73kuaxTN356Q+jmK8YmCW2nOGUTqt7kYctA5guac1eZf8mLtCxiPoxaG/83f
Mm4FPLfn5TMlVW53I0fS/C2hY9NldZN8xt2lWnzEZpq/hS3S2ceL/cXIbh/V
FB5YiZ7PB/ea+an/YoYvyBGvuVePnvc1fppg4pfHrDzrqeX6neac/T/zmJzN
jhW8ZzTn7P9Z8P/lbxWkfgO3IUtH7KP5Wyqpf2XTzhUzZ9P8LY7UXx464Yvv
YzZ6vknqz/m2VO6aKs3fzpD6xzunq648J4ied5P6fwU8Y72spDnnGlJ//fS+
u1lcmnNm/Ku3iJEaZFnx3/xtgci17bzYIua5lkjoaymavyVMZv+MtS9ips+6
8uVFZil6nmy51dhPvYhZtjvtXvGRavQcfuLrE3teIWMxIicukkPzN+X7U9VM
/AoZ1S9BXoK6LejZMzvQV92kkPFOjsk8uYLmnDYk1yofkL+lk/oNVdpnm4fQ
/M2Y1B9yaWH1V3uav8WT+h0ZpkmQQ/M3bVK/lPf6KUu9BNFzKKn/oPudqDsy
wuhZidT/fMgIm8Fnac55jtT/cVW8yZVOmnPq+AmcUTcpZQw/Bo/8b/5261+9
JcwMb/3MIyo0fxtS9n0TL7aE+fNx8tx/Pc3fvKWnZ8TalzAdHNVWqTO16Jkz
M0jfT72EKVPI8lY0akLPznacaHteMXOVtWdI22Oac1ad2zbSxO8PT950NVKq
Ez2/gPOoA/K3yaT+w+yhBfY9LLzuCCf1G7LTI8bFcdCzMqlfp/bp9qU7aP7m
Seo3fPdOM0+e5m8sUv/hs+yi9Ec059xP6s+btf3SlAVi6LmC1G+X3WPYnU5z
Th/jdAUTvz/fa83XL/9v/iawe+YJdZPfjL5w4tml2jR/O/Cv3jIm17DgdaQI
zd9qkgRtebFlzNjN4infn9WjZ9uaHd9i7cuYS1NDsuxu0JwzUzFtrp96GbP7
lsHk+Uvb0fNCZkaUPa+UGXNmV+uZCppzDv0f+Zs3qd/SZsWNTXo0f+OQ+uW6
OVO6h9L8zZnUPy21tdOwVgg9V5H63/8a367/VAQ925D6k9VujWvaK4ae00n9
k0LtfC00JOj9EVK/yFo77V3fac5Z23UzxJ5XwSTwH8v/N3+zUxeRNfGrYOxU
hphz7Gj+lrXE/oi6SQWz/e4Jjtr3SvRs+q/ecsbNa/FXd1Gav726OcuKF1vO
uD+fIGU+iOZvUz7f+BRrX86YrC3mckQ70XNEs9BMP/VyJmOX/Ta/3zTndPkf
+VsNqd81eZj8lACav9mS+nfNYE+SD6D5WyapX39TmlGxpwh6XkjqbzP1XBXq
LIaeX5D6Pat17MwtJNDzZFK/oHHS5qaxUug5nNRvZTlv0/FGmnMueuio7ade
zQx1uSj/3/zt9c+sIHteFRO1p91j512av03lzJUw8ati8q3f3l0VV42eI8eH
uqqbVDEr3mQftF5E87fh/+qtZNi1ltO/hLah5wtHHFbxYiuZLt26kweKac4p
GJmZHGtfycwNuLB1vTgfPWf/j/zNlNQfNvuO3FUJmr+9IvV/GVx/0VaH5m9T
SP3Xjs+1NVpE87cIUr/0QV/nhWsl0PNQUv9Ydl32disp9OxN6i9TMHe/s1wG
PXNI/WN4+fECwTTnvLNRLyHWvpYZ6TBc9L/52wiv8HF+6rVM7kQH/5mSNH/z
jRUPsOfVMJdfz2lOeleLnoULdwub+NUwas5zUkdHNKNnN7Ef+9VNapiWHJml
uWYd6LnuX73VzDyJYc1ShTTn3LAubDkvtppheTwosI6iOacuybUkBuRvkaT+
y/6FNe5Xaf42nNSf5xowrbdCFD1fIPUXvKv2fapF8zdBUv8Nl1x21Hop9OxC
6h/qt8nj12kZ9FxD6h8nZuQdkUZzTltSf/ihWyU9P2nOKawstZAX+2f/M/9S
qx5G8zc4X+d9zSBlxhmav9XtyFH3U69n2DIFO5S66tHzBnIu0ce8q+zCUJq/
/Xh5i23iV8c0ac9vvze8Cz0vKpfYrW5Sx9wdvmD7egE+en79r94/v18vwZEr
y2nOeYHkXckD8jdBUn/oddeiJmOav7mQ+semLj6ukSiOnmtJ/WvPH1lxayLN
3+xI/brfpS0cPWXQcxap/9fXIwZJdTTnNCX1O7nc2r9XluaZySTveuM35NEC
xTeYe2gQLjzRWv3bApqHjCZ5l6V3R97MOj7mTm+Ih1pmqJ2OZSauf0V4YOUP
nVdjB+HvV5R4SHboFRDUVUAOOeHWiZoxQzYqYJ1wDk1OMGgUPR+ZhPmhsmzJ
950ub/EcLPDdyjY+8dtP6sF5ZuA2r7wn7HShffHAH7eM33NTl/bFAz95qTR3
hwvtiwd+f/LUwx6raF888J8p7qNu6tK+eODuUytsrcVoXzxwRXeZxztcaF88
8Khv0wVcyluxHxA4d7jNSo9VtC8eeNZ2j1t+77qwjxj49mf32m7o0r544HzB
zAX3w/joE3LCd6nd4xvjk9EncIUG0SnxLzzQJ/CpfMUjDfGZ6BO4sJL2lm3K
tP8duL2SmmZDfCn6BJ6lMmnYvcpK9AmcmThHZpsy7X8HvjIojO2nRvvfgYuF
3umuj29Bn5h/3n7YusSc9r8D33v/aX1UZSf6BK4Rk1Ap5t6DPoHz4hJLtirT
/nfgCwtK6op/sPB8OHCV4t/VvmocLniGPHDZPK8PZXLv0TPwYRz9M6vVT6Nn
4FLuO6TL5Gj/O/DnOqeDdnrR/nfgtao5j0rlaP878NEK4z9YX65Gz8DvHtdz
2OlF+9+BGxws77htRvvfgf/ad+FEqRztfwfuvGuWtEpmB3oGLrO5OMD6cjd6
Bn7H+rza1TV96Bm4yvihq3d60f534A63HYLO1tE5A8Dj1d4W3TYTQM+Q+71R
iIk8f4Sekwe+pX1eaUzoGfQM/LrT9ZJzR36gZ+AO0bs7y4OL0DNwqQh593NH
ytEz8PvXnohOtKlFz8AjFo7/WB7ciJ6BOxn0SDz3bkHPwI30vpqdO9KOnoEr
zgq+aOXQhZ6Bl051/DHBphc9A7ccfFOKr0H734En+Z95WB7MRs/AteT3LE9V
ov3vwC/4rG2O8xZEz5Dv9dqc/TGD8wk9A+/WqsrXnXUOPQMXinstNIOTg56B
G9v+krmTSOcMAD9bmhs0nVOJnoF/2/ZzXPL8evSM69t28CIT6ZwB4HfjKkPq
i+icAeBf3bZtm87pRM/A6+aWax9W7UHPwGX5m1vfzuejZ+CBtk3WHjq0/x1f
N1EnMTKRzhkAnqC6R/3LckH0DDzlRPTp+iIh9Aw53obybztWBH9Gz8APK80b
YlF5Hj0Dv6J38rx5MJ0zAPzNydTol210zgDwqVX5w8yD6ZwB4Jm3nQ2aQ+mc
AeBeub0uL9vonAHgC6Q8Hpw2bUfPwNlcydLlwXTOAPCEvReHDG+icwaAx5t7
aTaH0jkDwJVrls3/uZiDnoHv91CwftlG5wwATxv580DoTTpnAPjEuGt+p01F
0DPkddvXh4asW/kFPx8hr3Ml/e/gH9ZrN97eeOuJlx5wWM8lffTwe4H1prq9
MVYr87DfCtbnDuijh/V7gvzPGzK0rxDW9w7or4f1L4O15lmtpP2zsF5qQN89
rD+5zLY97gntX4b13gP68WF91PLxywwZ2tcM65UG9OnD+jTztsjvn2hfOawP
HtC/D+vbViSyrVbSfnNYrzGgrx/WD7fwtPydz0cO67MH9PvDepWoqJy4J2zk
sP7qgDkAsP7JeLlTfa4CyGG9zYD5ALB+wT3nKYaMEHJYrzpgbgCsz52Ql39W
UAQ5rP89YJ4ArN95X//890+Uw/o7ZM4A/N1CzmliOS+rVTIV/26B31se/cAr
8wL+fQLPqAlY2ipJ5wwAPzHh4mPHQXTOAPAhscYSrZJ0zgDwxiyDeVNk6ZwB
4J9auY6Og+jfA/Cbinoh95To7x34i6vXK1sk6ZwB4JFaQccvStM5A8Avxl8d
NkWWzhkAftQ08EmqHJ0zAHxn7pUljoPonAHgq3dc/i2lSOcMANfv8j96T0kS
PUOe+ZBb5pSllIaegd8WqnNfXe2LnoHfOHnud6YSnTMAvHybqjwTWomegV/R
+BWcqUT/nQJ/oXznydl19N8j8EJxp896oZ3oGbhgL7ewubwXPQP3PyB8MFOJ
zhkAHrG7RujhLDpnAHjc9vQLZ9fROQPAP2+IG7bpKJ0zAPyXVXCEXqgYegZe
t/KkzpB3EugZeN+SHS+ay6XQM+SWbx9/8fDSSUfPyK1P6qUMuoiegX9fo13r
qUPnDACft8Z58ArTavQMPGt8wU1PHTpnALjneIHY+pdt6Bm4wXjNFHPTbvQM
vEtrUeHTbD56Br720jM3Tx06ZwC47iUToVcHBNEzcJlLPJ/6l8LoGXi1v/1Q
FUE6ZwD4e39+uLmpBHoGHurvO+nkBSn0DPygv1r802wZ9Az55NOH9w9q2mSg
Z+CzDyzg8pf6o2fgj59Oy9GwKUHPwM9f9G+ZJVWLnnF9XOdpDZtm9Aw8WPOO
YvS0DvSMz3N5TdgsqV70DDyBczLAronOcwA+Jd5qvYaNAHoGHrlnqkb1JzrP
AfjIcRK1D6eJomfg/oXFMftDxNEzcPGAeLdZUlLoGbi7mZ9+n4sMegbuJjDt
pF2TLHqGHLJzZKDri+uZ6Bn4VP25y4cGX0LPwB0WR35JuE7nOQC3Ezu5LrCG
znMArlUyyTnhOp3nADw8cYSe1js6zwH4iJsSwoE1dJ4D8EWve34LiNM5A8DP
PGg2TbhO5zkAT75e9WCvjgh6Bs72KpLXekfnOQDXO/TTuWiNJHoGfnDn99yA
GjrPAfi6iRtHjX1D5zmgz3CbNAFxefQMeeP0Qzu0nBuz0DPw7W1ffVdyrqBn
4Ld/rN7r1Ei/dwG/OvNl+WAnOs8BuK3HUiWnRjrPAbhmeoFhOs5pqkZ+wCfu
+WAnOs8BeO409nLjqQLoGfi8PJOK/Y10ngPwkON+R8Me0nkOwAXH8ZTS7SXQ
M/Ct39UesCZIo2fgZbNjQwc70XkOwAd7W9ZpZ9J5DsAXFPXNMp46CD1D7nem
VfSujyWd2wB8zBSV396WdG4D8Lctwd1VJ+jcBuD7l0086W1J5zYA17iXIDlF
pxd9Aq8WuPW56gSd24DPr1PjPdeRzm0AHrR+6gpvSzq3AbiTl9vgQiM6twH4
koREno6OFPoEfnG/YKq+tCz6BH5UYuzjqhN0bgPwnaGL/C920rkNwJuv2U+y
c1DgHv53Hi4N87oxHz+W/lyRTs6f5SJ37ds8Tlo2j5yXKkK+9Sr7mcrvYmbv
v/MxNLe8MG3Z2rnJ5Yz2v/McVcgTUoO7V4XWkPv6jchPk/ON/fehaT45YrnR
nhXBreS+Kc0nHwXvSrKV6iD3+TqQG9dcHORwqIvcl6L5JG9WwqaD1T3kPgrN
J/ecLn56xpJPcn8+cpfKZ+afilnc/vN2OZiz+cbPim4IyyPnw4qQP64Yu/jJ
sRJynqkM+bAWXe7uhxXk/E0V8pN8ru6E/FomguTzwIvI+UPBf/dTaX7of3km
x3txJ7l/2YHcJEivp7qkm9xv60LeF2LYZnKwj9wfovlhzooxHSvOsrgwHwB4
zKqxrZwsNrf/fFsh5l2KustuhQ8uJeexypAvHBMaPyKokpwfqkR+UKnl++XR
9YwLub8APIyc68v+d5+yA/m838Yj3Kx6Gd1/99W6kO+qb1/Bk2Zx/f7dB+pB
HrdzcWCnI5vbf9+F5nKCFTfzB6dxuP3nw0oxR5rEWnBtytkqcp6pEnm5237f
HboN5P5uO/JWcv6t/35kF/KSiRMV7lSyuP33z3qQm0YpxvracbgbyPwK4I/G
9q12yxHg9p+XqsC8ZYqeeAo/t4Hc16R5zlFy7qv/PlwPcp/33KADf75X9N83
6kN+U/MY/2qdILeO3H+BnEGQnF/qv5/Uh9zuweG8Sllhrs2AnGELyRkiBuQD
qSQfGDkgB+ggOUDKgOt9UXK9f3rAdb0nua43GHD9rkCu320GXHerkevuFwOu
r7PI9fXQAdfRgeQ62mXA9bI1uV7OHnBdrEKui3UHXP+Wkevf1+Q+EVz/NpLz
SBcGXP9GkutfV7J/wvVa3hmVuZ4z8plGsn8CHyEocZyrWk7OaxYhTzEQ+h0/
tp6cL6TXs68S+eFXrzST83BVyC8V9WT/uNpOzrvQ61Pv0W6xC9LZXG+yTwJ3
i3Yx+50hwK0h+yTwLdwDFSezhLimZJ8Ebp7q5K72Q4QbSfZJ4Hq2+4cm/RTj
CpJ9EvjYhr0xtrkS3ESyT8L11PqouEvjgsrJOdQi5OkLIgs/DWog5ybLkLfP
2t92ZG0LOedXhXzoBK6k7o0Ocr6EXg+u6nqmI8gT5NqS/RD4tubrL/J7hbmv
yH4I3K3mxILno8W4w8l+CNyzbHv6RYM/31vIfgj8er6ZtcMWKe4Jsh/C9cvo
0EFOMy40MAzZD4H/CJlx7upwOI9Yidw7xOpGb2QnOZ/RgVwu9fRJ56mi3Clk
3wNe832ITKSrOPcC2feAf/weFZjzWpJbS/Y9vM76Pk9dQliGq0n2Pfj+b9fT
bSlR2MqUkH0P+JKdURX+z7rIeYUu5Ls4m0ZsLZbgCpL9DXjJ8zml45dKc+3I
/gb8XtxZi451stwUsr/B92GnlIV9sz93k/vxPcg3NZTOVqmX4WaRfQx4Wr29
2S59Oa4p2a/g+57Vusqcl5Pluf33j/3wc3kXP0djY7MfuR9MP8fhfjF8zwFe
UXxNMFqUzdUgzwPff9iXgx6P676N38+Baxs8vNV4MEBPlPydA7dfebJlh54C
t+rfucl6fP6mp23fZr758/f8rx8jgX4fmKpxTCD8NTkPWofc2UNDYf+pRnJ+
sRH5+PMTpNNHtDBB//o3YvFzrVggQytl+QvSR/EVuU3YmtZNI9LJudI65D8E
wppOmzcxL/6dI2xEvqdn0eFkhVZm6L9zb83IxVtbRNg/2plcMmcJ778s6Swz
sIhj8v71OaQgD9VLEr2cmUb6CrKRF44TVuZd/EXOs9Yij3Uyypqj3kzOXzYi
P7VbaYiUQhs5L9iMfNXO8nX5Ap3kfFsr8jFb4m4+bO5mZvzrV4nCz0HvmSJ3
8gNjSN/IJ3ofJHtust/WNNLnkEU/fwtm5N+v+EXO5ecjz9s35FCpbhk5d1uL
fCXrrK9xdzM5J0rv7zgniazxGtZOzjU2Iw84eWpk5pwucg6vFXm8sVDZ0HW9
5NxYO3IHwaSsyXosbhyZ+wSf16Zaz9UK5e4xI/71jbxHPrnhYu6mtFTSp5GJ
fHBCdLTX6HzSV/ALOT9piwHvWRk5B1+CfN9YpweO62vIeeIa5Pc7F85f/KOF
nH+l91m2Tkg9oDS+g5zXpPdZVNavvl94pJucL2xFzvPNL76b3kfOw7XT91U8
xXP2IDa3//wWvc8SebAtYtRLDncf+XcKn7/nX66ubhkTTPp8kpHvPlb0yFMy
lfSlZCAX9pBSjJ+eT/oo8pB/Tx7+Yt/k3+TcP71/MfTDY/tzRrXknHo58phN
4T7LJjaR8770/gJr62z9rfM7yflUeh9hzDahq01fesh5Snq/4Jbuts5X41nc
/vN/7chnPv16S7CRze0/r0bz/5RpU81NYwW4/eeraM5vExvQ53NQiCtIzqvA
5y9fvv9cdDnZl4DvYneJKgZ3MwvJvgSfa3rn1bpWKn5mTMm5JuDa5Hzvd7Jf
4fqRkqqVpT3kvHIj8imiNcPMLrG4p8l+BZ9H5YPn3d+z5gOjS/Yr4KnntMe/
+/WL8SPnpoBnk3Otz8g+Btww5OgT22l95Dx0I/IjqWmlRbZsrjLZx4Bbpm50
HHRbgPuB7GPwOeUl1KQyTiaZySD7GHCXV7Ef4jf/YjaQfQy44rzZRxvsKpid
5BwXcCdy/vMG2d+Az8q1dB7pwyfnsxtpjqcuxFk5lcP1JPsb5nh5eR+Vbwhy
q8j+BvzYxSc+v8RFuNJkf4PPxzcBw56eGfuG2Uf2N+BGxkZu/Ed5jA7Z34Ar
2vYt/nW7gokg+xvw49L2DtYHGxkZcg4NeHdN/7nK02TfA96+clhJpguLG0r2
PeDTDOUXeEoKcFlk3wO+Z6pYlMFNIa4N2feAP1BlyXT/+Z7zgux7wKvk2vc+
/iDO9SL7Hnzuuz9dGP5G7Rnpl3uP3M12dcmmeB7DJvse8E8m377VZFUwB8i+
B/zuno5LK8obmXay7wHf/epscvTGdiaGnLvDvI6cb3Qk+yFw/vjsC9O02Vwl
sh8C35A+cuymGgHufrIfAn/nsvW1311hbjrZD/H84ajoVYnbxLiTyX4I3PNd
R229hiTXm+yHwOt36nuMLJPmPiH7HnwPaTQUMsp1yiX9bBnIc9femKpbUcGY
kn0PeLCoTehL0ybSL0TzLrNNNVp2Kh2kv6UcOeuNW4xgRy+zFvorCf9Jzh+e
I/sh8EcJi4pvpQtyK8h+CPxspV9E+0sRrjHZD4FvGJy7w+SOODec7IfAZxup
TLrmL8XlkP0Q+LlZT1zbGFmuLdkPgTun/rC68VSOO5zsh1g/t/98IJzbhO9p
O65+E7s+hPb5AueE7dl3+Rrt8wX+1eJc3Qdp2pcKfGiuVViyGZ03CHyLzcQ1
iRfoXEHgMcV9kq/SarFPAfipAf282Kf87pRbshnt5wWefro+c/5u2s8LvMNk
zaTEC3ReH/CRkolnmUd0Lh9ww2/jSl+m9aIH+P4ZtTv/9m5z2p8L/EvwVwPd
SXQ+HvD5QvemTn5K+3OBx+08pzZhDp2PB1w7fdugsYn1+H6BFwzotwU+JFmF
pd1B+22BW7TLdoyfQ+fdAffRYjWMO0Ln3QFPsa4v10zk43lR4CcW1tfLc9hc
eL/wfXja1xaxLRtonyzwM6urT9zUoXPqgOcVFfXmsuicOuDK02sSxCsa8H0B
DxnQ3wo8ZUrg91wWnS8HvO2Av6TLNj6+L+AX8j+Ei1fQ/lbg6u5GBjnDOFyo
H74/36p87n/mPe0/BZ7w8ZuiewntPwVembEnZS6rCesE3jygPxQ4U3HWry+O
9ocCFxr9/fFcFu1bBP55tUKG2wIBLtSD35/L7pY47aV9msBVzD4nTdFqxtcF
fmRAvyRw/aG+kVO0BPB1gQt/H60sd0oQ5xvA98/hO8J+CW5tQc/ABQb0A+J5
p99aWu9/0n5AyIUGzuMCbj5gHheeGxkwjwv4iQHzuIAHDJjHBbxuwDwu4EZk
HhfsP1jngLlbwMMHzN0CbjZg7hbwrgFzt4BHDJi7BXz5gLlb8P22geRswGF9
D5nHBT7h++36lGevnXVo3x/wIOMQofHD6dwt4Gdvb4m6OorO3QI+R/DyWA9f
2vcH/NETl+65g2g/GnDNzVbfWvw70Bvw/IoaYQ9f2seH51X0bRpszWkfH/CV
gd9z5g6ic7Qwx2vkvlXOpH18wD+bPL7X4k/naAEXClW7nGohzgUP8P28Jpz3
tcGD9uUBf3n8so5qN+3LA74gOvLzuDjalwd88qhTh5L20rlYwJW9N2pbTaR9
5XhOI+4N3+kS7acDPmH3wzVJe2k/HfAQzeBH0svoPCvgigWe4lYT6Twr4Ocu
H9x4W1wS9234/n/3QapnUCvtg8NzF5JFEz420j444BqJawclVdA+OODSzumd
CQV0/ifwO1pTahMraJ8a8JEeDoV6pbRPDbhfwd2MhALapwZceHb5+5k8Kdyf
8Xpk5xwNP4b2kQF3NtE6GupM+8iA79cc8vPxffp5Abz1ucAJLT/az4V87MGH
j+/Tfi7kV5p4sz/J4D4M3891PvoMKhzRja8LfENYckNzAP08wusUhzPvmgNo
HxPwiQ5yuXrVsrjfwvfbBOsFtyLS6OcX8JmtKpucOfLY5wLfW46SvgbYb+Fz
fLmTiLOrMdzPqEduTs7tw74HPFCpWtBuVws+D3xunrqTHVvmQOds4Ln02pje
UocMfH7g+uS8Ojw/8A0hru4nX7bi/gD8+AcJcbvxHfi68Dlo6Go0x/dOMr4u
cJXcSc4X7mTi/gb8RvuLpWv68rEe4PvIuW6oB3jmuVGcajU6FwK4bvr8juHP
O/HfL/CLQ7bULV1K573A5yZP0OKlTzudjwG8yPp8tXc7nY8B/N7w6T13Xenc
BuBbzkUc924vw/qBR5Lz0lA/8NP1KpuLbtL9FvgmDcuxGeu7sX783Lf2q04e
SectAJcx3bya50Dnq8DneIBq5iRByw/4voCnuJ5dJmD5A98XcI09/obHT9B5
sMC3jCkt5FjSOQnAI3KmHj4xuRbfL3Ajcm4Z3i8+T/m9ng/TuvD9Aj+VmGkq
qtKL7xd4xpIji9WF6dwD4KWz/fYlH6RzD4A3a0Zc3dRI53LA529psdMhlXQ6
LwJ48rNU79HpdF4EcEkmZlLAdTovAvh01b7Bo9PpvFbg64VMWJHCdI4BcMMW
k5Yr1+n8DczryDle8AN8Y/Kw64NK6VwI4B3T9H1X99G5EMDfr4hJWiJJ5xUA
95V8/8IxkM5lBW717mesrwadVwBc40h1dEwM/b4Hn7+SZC4B1A/8OjlfCuvh
82uNcHvTURXaXw98Osnf4HmAs8n5SfAAvIRxTZHLpn/P8Pny85Z82zAh2lcO
vGTRfuthQrSvHHgOyd/gdYG3k/OE8LrA41e8WdhXTedb4no5q5CQGjpvGT5f
jpxkJR4Xpf3XeD7t3JmRx0Vp/zXw2PQLeUmetP8auCvJ36BO4PHkPB7UCfyz
gvDHPYNo3zTwnxpn2t11ad808PKZ4pp+FnTuBOZsvMsRP4bRvmbgz0UjOrOH
0b5mvJ8VxhqdNI72NQPff2NiWPYw2tcMnE/yN3hfwE3I+Td4X8Blt1yMPrJE
EN8X8CxJLbfOC8L4voAHxbwx2J9J5zHi+T3L1VL1gyXw/eL5K8dTR8W5Gfh+
gZ/+vO+DGLcE3y/wE9bqZtKFdI4icMZlx04xLu0vBv4ycf5DCVnaXwx8Dsnf
wAPwn+R8GvbFE37Fsnbvgmu0Xxv4qqM5/gsFaB8xcKXwd7EmO8XRA/Csj49+
mmbQeYnAL9Ze71o0Rwb9QL5Uw/y/+RLw9td3zw52pv3XwPX1PGtUH9H5h8CN
82M1BzvT+YfAd1zXzAm6SOcfAvdZF3BO9RGdfwg8Z0BfMPBEcg4NvAG38A3f
yu+l/dfAKxrWcZM86fxD4K7LFId4DJNEb8Alo782LrhL5x8C/y5isNkjiPYF
Y3/ujBtpv0vo/EP4XreG3Lf9P7J99Ic=
     "], {{
       {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
         GrayLevel[1], 3], 
        StyleBox[GraphicsGroup3DBox[
          TagBox[{Polygon3DBox[CompressedData["
1:eJw1mXngTVX3xu89e59QCiHzTIY0GKIUMqUyhaIXjYQyJ2k0ZMicprdoLg2S
KCIUDSopKiGaNEikwZTQ4P08v+f8/ljW57ude+65Z++91rPWrnLNkC6Dk1wu
dz//BPzL+GL4rflcrh78H7gLfAZ8GdwZrgpfBLeCq8AXwi3hY+EG8CnwiXAT
uAFcHD4HbggfBzeE68K14S7wRXBl+AK4BVwUPguuBxeDz4brw7XgzvCFcCG4
PlwHLgjXg2vD2/UdcBH8j1hhuBj+Bz0ffDz+y7x/6z/YV3DEH8XKcp9W+HMY
242VgBP8Dux4uDj+d/yP2HbsF/4uiY/4nXm/t7+xn/Wb8Tn8Lr0L8F+sDPdv
iW/CWGm4BXw2fDE8GR4D3w2vgVfBk+A34dfgGfD78Ep4IrwSXgLfBa+Cl8IT
4DfgV+Hp8HvwG/Bk+C14GdwPfhx+EJ4Gvwu/Dl8HPwnPgm+BX4bnwv3hJ+CH
4C8wrZW/sFHAUvxLjI2GX4MXwBfCY+Fb4JN4yVfDZ2kdYffAkxnvDE+Bx8KX
wTPhSfAd8BJ4PtwCvhUeBl8JPwTfDY+Fl2udwg8wcefpd/I9Y/DLGF/I+FXw
LHgmfDU8G74HvhleCD8P/6rngwvgt2EF4BR/EdfcAA+A28HD4YFwe/hGeBA8
AL4PngYPhO+Hp8OD4AfgGfBUeBH8IjwbfhteAXeAR8CD4XvhFfCibI70zl+A
p8CvwPPgjvBN8JDs3Q6Dr4c7wSPhoXBX+Hb4RrgLfBs8HL4EvgMeAfeGp8Hj
4T7wdHiC3n/0GriTd9iK8YFwH8ZbwgPg3nBbeCjcH24ND4Kvhc+Hh8D98p6H
/vDVcBt4MNwXnpWtveXwcPgRxRr4RvhR+AHtP7guXEPrC64DV9MehU+Bq8N/
YzXgCnmvJ62r/8BHsGpwuXzu/xZnLVwVeC9WBj4B/w12DBzwea6pDVeFv1cc
gY/D79GehAvjv1NMgQvhv8ZSbWX8Aaw8XAK/DysLF8Xfyj2fgh+G74TnwU9n
+0h7ajZ8A/wwfB88Dn4RngPvx8rBJ+JvY/xp+BF4JvwB/Cb8F1YdLo+/nfE5
8KPwH1gF+CT8IayKYgz+MFZV8Qx/DddPhcfBCvTPwY/BI+EF8HPaF9FzMJ81
MDL6vb8I3xQ9H/PgPXAzuDJ+L9YcroL/DTsXroj/HWsKV8IfiI5r1fH7sQvg
avh90Xu7Kv5X7By4Av4XrAlcHn8Q6w6fjP8L66t1gN+G1YGL4q+MnqcHeLbL
o+f4fviq6Hn9L9w7OgfMUhyKzgEPwrdE54+X4F7Rc3wf3CM6N9wDb4LLcc0x
+J7ReeJexnfDZydZTIuOiTMZPw0bzfv8CP93dJyti/8nOoaeij8SHY/q4Hdg
DeBS+O3Y6XBJPS9WHz5Jz4WdDJ+g34fVhIvoWbAa8PH6TdhpcAm9D6wufKIS
Got2KHyG3gd2KlwcfxQbAp+O/xY7BS6G/zd6fZym/49eW8/wWzbD5RkvgP8J
awiXxh+Kjsu18D9jjeFy+D+jY3pN/OHoWFxb94uO+zXwG7FScIrfhTWCy+pd
YtXg4/CfYxXggvid2JlwGfxWrBJ8rOYKqw4Xxm/BKsKF8DdpbnkFz/Ibhkbv
h2f5LTdE76Xng3/TJVzTPu/PdYM75v2dl8IdlB/gTvD5eedraY8L8n7GXnDX
vN9fb7hn3vNzFdw972fsDnfKW7coXl2W9/z0gXvl/eyXw5fkPT/XwpfD/2KN
4NPwv/CsReFXEq+RfvCVec95X/iKvOd5LvxE3nP7PPw4PAx+AX4y73V0JdwN
/l3PClfKW7cobpRWzOS7NijP4n/i78pwKfxB7HT45CzOSGvVwv+JnQHXzHs9
XgFfmvfcXgy3hUvCHeE2ikXR+uwh7t8nWlfNhvtGa6ZH4X7R2usxuH+0xnoc
vj46Rj8BXxutqx6BB0bH4qfgwdExeg48IDoHPAmPiI77L8CDomPu0/CN0Tlj
LjwsOpc8Bx/H3hnP+DmMnQTfB58Pp/hmfORMrisBd4BbwwXg8+DG8FGsMXy6
cg7jzeFGymvcZwR/14/Wqy2kixg/QfeGm2kN8N2j4A/xRRhvCzdXnM+u0do+
Hm4DN9XaC877H+idMD4Dnsj49fC98NS8dZ101xTlOPxP2A7sN+xn7Puctb60
6xHlHq7fpDiWd+7+VPfXnMGfwGvgGcHj85XDsc3wOuXE7L4/YA8y/jH+fcVo
eB38ruIyvB5+L+/rfsue4WDGSuN/YHuxX7EFXP8t/iX8/pz1925dyzNUVM7F
v6AYCZfkw78Ga3ONP8b45/B6xodHa4hDwffV/XdiB3J+L79ktid7P39m31Uk
+z6x7nsou+Yz7THuvwX/sdYNvA3+XPEle+YteX/PYWxXznv5/9/3nuy7dZ+P
lTP1Dvj/NxPv9/3w+sR78M/g6w9l87c3e0ffaf9H69d9wTpAemCevl/7EC6Y
93s9mM3379lvUw2zMLGen6u5TRwHtL9XJV4Pig1z4K/gjdoz8Jd6ZuUG+Gt4
k/YkvBX+RHEW/gbeDP+DnQmfir+L51sLd45+nn3ZXP+m2ISvmPd72pv9rvcS
P/8fwc+8P5uL66K1+wHGv8v2kfbTHv5erd8XfI9d2fz+ku3ZoO/N9mOUVsn2
rHLQtsRx7B8++23i+KZ7fqN8CP/F+NeJY+Df8I7EezyvvJnlCOXo26Lr23+1
xvBNGU8YKwy3hs/VO8nioXL3X1kMUf76G26fc+4bG12LSnvsyX6j8s+BbO8r
Jx7M4oPy4P7s/srRPybOHblMv3QF2/G9E6LrbWmno1l8lpbYnDgXHAnWVtfA
PRSvgj8rbaBiWblPeWx74jk9ylgIzqHSGzE4b0pjlA6+j7RcbcXunPXejGjd
JP1UmPGeOesc/a265jq+99jg3CpdVDY4t0ofVg7Od9Kf87O4tFY6NzgnSotu
SryWDis2BOdTadHywTlXGvVhrtkIf8hniwbnLOmKEsG5Wxrm9ODnUb11lvRi
zjr2kehaSDo2DdYM0l3StmPgmxXPg3O6NFLj4BpWmqd5cF2sOvjE4FwszdMs
+LPSS8cEawbpwOewbok1sLTw3Yzfxf2/gs/NWav/kLhfsQDemrhPohw3NTjG
XspnpwTH3kvgyfBHcFd4ceIehbTuq4l7HdK3SxL3NKSHX09cmyhfL09cT0lX
TwuO7d24z4rEdZB09RuJ6yPp7aWJ62tp8unBuaM71y9K3A+RZl6ZOF5JA5wf
3AORVlwYnc+k+dsyPilnnXlBcN9A+vmy4Lq+Hrwsce2mWqBD8LuS9r40uG8g
rTs4uPZvDncM7jlIk3eDH8xZ93YP7htIM3cKzpvKn5PgD+EujD/F31/AG/LW
BRp/RzVD4vj2FtwLHg/fkXdfTe98NTw6uBZWXh0V3NtpF117qwZvD1/O/02A
R3F9T3gcfDt8BTwRHg33gO+Eb8t7jajuGJn32tIauxW+NLGWuCnv+ukxzR08
Lrgv1IHvmhDca+okzRzcw2kFTwyuPS+Gbw7ut7SBV0X3LKSFRgb3W1rDdwT3
oC6Cb9R6gs+DRwT3iFrC44P7Vx3h4cF9nhbw7cG9rAvhW7Xm4LaKpcG9rAvg
IcG9EfVIpKHmw8/wW/oH69smXLMhcT9QOv/TLIYrl32WuCcpXbcxce9R+n8d
fGrONc5HifsP0o0lg3saK/HFgnsdr+MLYdfBy/Clgvshq/AFg/ser+GLB/c9
3pB+C+6lrJCeDO6lLNc6StzTkP58N3FPQ/p2N9wOXgTvStxTfVl6IXHPULXq
F4l7qqrHv0zcU1WdvjZxz0Qa+OfEvdlX4C2J+6jSt6sT9xCkq3cm7rUuhN9J
3D+R9l6TuH8ijf1B4j6J9HOl1FpKc1cmi42K2XWCe01rFGuxZ+FGXNMnuM/Q
WOs5uN/YEF4a3feRBu4VvCYbwFcE9xjPhPsG1y9nwYOCexTNovW41sZi5nRg
cH3XlPHXo/sp0ur9guugs+EBwevkXOXB4J7em4q7wT0Z9WbeTtwnUR1RLbjP
thpfJbhH9w6+RnCf7V18heB+4Fv4mtjN8Pva05l2kl6qFNwnfBt/KHHP/FU4
H1wDKofuTZxPldOPYD3gpfz/vsT98MXw4cS99yVw5dRaU/u0bnBPby2+Ymr9
rb28Orquk156O7p+k4ZcGd2L/FkxOLqukG55M7ovuZvxZ6J7hZvgidG9fq3n
ydE9Cq3hSdF9Ca3hu6LPBrQXno7uOX6m9RxdK0rHvhddH0q7rs/qFmmGFdE9
sp1aL9FxarPeTXDP80ft++ge6C6tw+iaSvpkbXQNJj32YXR9JT12fXAfVfd8
K1r7Sg9/HF1fSQt9FF2nSeOtia6xpROuymKL1sO06F6E9v66TLdJy70TrVOl
OR+O7nuqz/NEdD/3E/ip6J7sBq336H7xx1pr0T3cT+FZ0f1Tzd090X0zrZN7
o/tmWm8PRfdhVdPNju6lqh58LLofvR5+NLpPvQ6+O7pvprV9Z/Q5itbbuOiz
Ga2f8dFnNlpjt0efr2jv3xp9ZiP9MD26h6OYdkf0uYviz5zo/vJGeGp0H0bx
bUz0eYbW6ujoMx7FrlHRZz+KP72xxbzbn/DXBPfDd2hfRvclv4JbBvfSt+Bb
B/fPv8B3Du6pbsP3CO6p/oDvEtwj/RbfMDhX6v3XD86Vej8tguvfz/H1gnOl
3lWD4LyseTkzOJ9qXroG91S/w1+i/QB/j784ixXSANKNqgtfTKw/VVuoJq2Q
umZW7lbtqdqrTuoa7/ucayv1VXS9Ptc+uO/9Db4N9l/4S/wZwblbmrNV8JnC
VvxFwX1jvat2wf3zr/GNtA9zXm/nBWsV5f8mwf1e7ccXorWI7rM8unesuXg+
WkPo/bwYrS30DDoL0O8rz/OPDe4FKT6MCdbb0i0vRZ8l6BnmRmsUzd28TLto
7m7Qnsk55gwN1jzK3e9H14SqwRdEn0PoPbwW3UPX3l8UfaaiuTg3+JxCcalp
cH9DseKc4LMMrcnF0ecumq+ewX317fhXo3vuWjPLonvrWnsvR/dHtK6GBZ/L
KM4siT6f0GdfiT7j0RqbGd2jVsyfEt3/lB6olbrmlwa+L7o3rtxRInXvXrqo
eOrzPGmqY1OfXUmrFE59VqfcFFP34pUfj099tqe8Viz1GZ40UrnU/RdpxRNT
nwVKU1VJXXtLpxVNfZ4n3VUk9dmhtO4Jqc8IlUND6t6ocm7J1JpVuu7B6PMe
5fHaqfsX0uo1U9fzqiNqpO4FqHY4OXX9r5qiKvxk4ro+n7rnKE1eMPW5oPJ4
mvrsTfm9euo+grR0gdTniNIJhVKf4Sl3H5P6LFBa4v7oswbl39Kpe0nShKVS
a2tpxQ3RfUbV+GVS95ikJ8um7kNJl34W3c9V7f9pdP9Otfn/ANwZ2Bs=
             "]], Polygon3DBox[CompressedData["
1:eJw1mnfgz1UfxT/33o+RJMloyMompfGkTVMKpaVCGS0aGkakjJKUStEwCiEq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             "]], Polygon3DBox[CompressedData["
1:eJwt13ncjWUaAODvO+dIliRLRpFBGEKTtawjW9nK3tgauylLZclkKWPf96US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             "]]},
           Annotation[#, "Charting`Private`Tag$8309#1"]& ]],
         Lighting->{{"Ambient", 
            RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
           "Directional", 
            RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
            ImageScaled[{0, 2, 2}]}, {"Directional", 
            RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
            ImageScaled[{2, 2, 2}]}, {"Directional", 
            RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
            ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
       {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0rsvpFEYwOGPcRsMK6Jd0RAFpSgoN4pViSjoiGK3WIlsQakQOh1/AS0R
+k3o3MfMuM2ystkIu2Tjfg3PSRS/eU7mO5nznsxX0zvQ8S0niqJR3SqsL/Vb
87lR9IE/WM0NNvKQrTxnO5/Zw9JYFCX01bqew2zmONs4xS7OsJ+L/M5l/ucJ
77Wta/3TioFSXGWaa8xwnTthJu5yk3vcYlL74Xd4wBSzTPMnMzzkDo+4y1+c
dY9TPuhYN+GOmjBbkiNc4iAX2MdpdnKSnzjGJg6xjrX6Yh1nNx+d8Zl/2cIs
G8K9+JEX9v3hncp1FfaqyoxlrGSCFSwNe1jCBItZwng4j0UsYL4KrWMsCP9x
+I6vytNLeKYnGSOa83H2/j68Acy/Svc=
         "]]}, 
       {GrayLevel[0.2], 
        Line3DBox[{690, 1004, 473, 689, 1113, 912, 691, 1114, 913, 692, 1115, 
         914, 693, 1116, 915, 694, 1117, 916, 695, 1118, 1010, 1217, 696, 
         1119, 917, 697, 1120, 918, 698, 1121, 919, 699, 1122, 920, 700, 1123,
          921, 701, 1124, 922, 702, 1322, 1005, 923, 1006}], 
        Line3DBox[{704, 1011, 1218, 703, 488, 705, 1125, 924, 706, 1126, 925, 
         707, 1127, 926, 708, 1128, 927, 709, 1129, 1012, 1219, 710, 1013, 
         1220, 711, 1130, 928, 712, 1131, 929, 713, 1132, 930, 714, 1133, 931,
          715, 1134, 932, 716, 1135, 933, 717}], 
        Line3DBox[{719, 1014, 1221, 718, 1015, 1222, 720, 504, 721, 1136, 934,
          722, 1137, 935, 723, 1138, 936, 724, 1139, 1016, 1223, 725, 1017, 
         1224, 726, 1018, 1225, 727, 1140, 937, 728, 1141, 938, 729, 1142, 
         939, 730, 1143, 940, 731, 1144, 941, 732}], 
        Line3DBox[{734, 1019, 1226, 733, 1020, 1227, 735, 1021, 1228, 736, 
         520, 737, 1145, 942, 738, 1146, 943, 739, 1147, 1022, 1229, 740, 
         1023, 1230, 741, 1024, 1231, 742, 1025, 1232, 743, 1148, 944, 744, 
         1149, 945, 745, 1150, 946, 746, 1151, 947, 747}], 
        Line3DBox[{749, 1026, 1233, 748, 1027, 1234, 750, 1028, 1235, 751, 
         1029, 1236, 752, 536, 753, 1152, 948, 754, 1153, 1030, 1237, 755, 
         1031, 1238, 756, 1032, 1239, 757, 1033, 1240, 758, 1034, 1241, 759, 
         1154, 949, 760, 1155, 950, 761, 1156, 951, 762}], 
        Line3DBox[{764, 1035, 1242, 763, 1036, 1243, 765, 1037, 1244, 766, 
         1038, 1245, 767, 1039, 1246, 768, 552, 769, 1157, 1040, 1247, 770, 
         1041, 1248, 771, 1042, 1249, 772, 1043, 1250, 773, 1044, 1251, 774, 
         1045, 1252, 775, 1158, 952, 776, 1159, 953, 777}], 
        Line3DBox[{781, 1160, 954, 779, 1161, 955, 783, 1162, 956, 785, 1163, 
         957, 787, 1164, 958, 789, 1165, 959, 791, 1166, 569, 793, 1167, 960, 
         795, 1168, 961, 797, 1169, 962, 799, 1170, 963, 801, 1171, 964, 803, 
         1172, 965, 805, 1174, 967, 807}], 
        Line3DBox[{806, 966, 1173, 804, 1265, 1057, 802, 1264, 1056, 800, 
         1263, 1055, 798, 1262, 1054, 796, 1261, 1053, 794, 1260, 1052, 792, 
         1259, 568, 790, 1258, 1051, 788, 1257, 1050, 786, 1256, 1049, 784, 
         1255, 1048, 782, 1254, 1047, 778, 1253, 1046, 780}], 
        Line3DBox[{809, 1058, 1266, 808, 1175, 968, 810, 1176, 969, 811, 1177,
          970, 812, 1178, 971, 813, 1179, 972, 814, 1180, 1059, 1267, 815, 
         585, 816, 1181, 973, 817, 1182, 974, 818, 1183, 975, 819, 1184, 976, 
         820, 1185, 977, 821, 1186, 978, 822}], 
        Line3DBox[{824, 1060, 1268, 823, 1061, 1269, 825, 1187, 979, 826, 
         1188, 980, 827, 1189, 981, 828, 1190, 982, 829, 1191, 1062, 1270, 
         830, 1063, 1271, 831, 601, 832, 1192, 983, 833, 1193, 984, 834, 1194,
          985, 835, 1195, 986, 836, 1196, 987, 837}], 
        Line3DBox[{839, 1064, 1272, 838, 1065, 1273, 840, 1066, 1274, 841, 
         1197, 988, 842, 1198, 989, 843, 1199, 990, 844, 1200, 1067, 1275, 
         845, 1068, 1276, 846, 1069, 1277, 847, 617, 848, 1201, 991, 849, 
         1202, 992, 850, 1203, 993, 851, 1204, 994, 852}], 
        Line3DBox[{854, 1070, 1278, 853, 1071, 1279, 855, 1072, 1280, 856, 
         1073, 1281, 857, 1205, 995, 858, 1206, 996, 859, 1207, 1074, 1282, 
         860, 1075, 1283, 861, 1076, 1284, 862, 1077, 1285, 863, 633, 864, 
         1208, 997, 865, 1209, 998, 866, 1210, 999, 867}], 
        Line3DBox[{869, 1078, 1286, 868, 1079, 1287, 870, 1080, 1288, 871, 
         1081, 1289, 872, 1082, 1290, 873, 1211, 1000, 874, 1212, 1083, 1291, 
         875, 1084, 1292, 876, 1085, 1293, 877, 1086, 1294, 878, 1087, 1295, 
         879, 649, 880, 1213, 1001, 881, 1214, 1002, 882}], 
        Line3DBox[{884, 1088, 1296, 883, 1089, 1297, 885, 1090, 1298, 886, 
         1091, 1299, 887, 1092, 1300, 888, 1093, 1301, 889, 1215, 1094, 1302, 
         890, 1095, 1303, 891, 1096, 1304, 892, 1097, 1305, 893, 1098, 1306, 
         894, 1099, 1307, 895, 665, 896, 1216, 1003, 897}], 
        Line3DBox[{911, 1009, 685, 910, 1321, 1111, 909, 1320, 1110, 908, 
         1319, 1109, 907, 1318, 1108, 906, 1317, 1107, 905, 1316, 1106, 904, 
         1315, 1314, 1105, 903, 1313, 1104, 902, 1312, 1103, 901, 1311, 1102, 
         900, 1310, 1101, 899, 1309, 1100, 898, 1112, 1308, 1007, 1008}]}, 
       {GrayLevel[0.2], 
        Line3DBox[{251, 474, 1113, 252, 488, 280, 1222, 503, 295, 1227, 518, 
         310, 1234, 533, 325, 1243, 548, 340, 1254, 563, 1161, 355, 578, 1175,
          370, 1269, 593, 385, 1273, 608, 400, 1279, 623, 415, 1287, 638, 430,
          1297, 653, 445, 1309, 668, 460}], 
        Line3DBox[{253, 475, 1114, 254, 489, 1125, 281, 504, 296, 1228, 519, 
         311, 1235, 534, 326, 1244, 549, 341, 1255, 564, 1162, 356, 579, 1176,
          371, 594, 1187, 386, 1274, 609, 401, 1280, 624, 416, 1288, 639, 431,
          1298, 654, 446, 1310, 669, 461}], 
        Line3DBox[{255, 476, 1115, 256, 490, 1126, 282, 505, 1136, 297, 520, 
         312, 1236, 535, 327, 1245, 550, 342, 1256, 565, 1163, 357, 580, 1177,
          372, 595, 1188, 387, 610, 1197, 402, 1281, 625, 417, 1289, 640, 432,
          1299, 655, 447, 1311, 670, 462}], 
        Line3DBox[{257, 477, 1116, 258, 491, 1127, 283, 506, 1137, 298, 521, 
         1145, 313, 536, 328, 1246, 551, 343, 1257, 566, 1164, 358, 581, 1178,
          373, 596, 1189, 388, 611, 1198, 403, 626, 1205, 418, 1290, 641, 433,
          1300, 656, 448, 1312, 671, 463}], 
        Line3DBox[{259, 478, 1117, 260, 492, 1128, 284, 507, 1138, 299, 522, 
         1146, 314, 537, 1152, 329, 552, 344, 1258, 567, 1165, 359, 582, 1179,
          374, 597, 1190, 389, 612, 1199, 404, 627, 1206, 419, 642, 1211, 434,
          1301, 657, 449, 1313, 672, 464}], 
        Line3DBox[{261, 479, 1118, 263, 493, 1129, 285, 508, 1139, 300, 523, 
         1147, 315, 538, 1153, 330, 553, 1157, 345, 568, 1166, 360, 583, 1180,
          375, 598, 1191, 390, 613, 1200, 405, 628, 1207, 420, 643, 1212, 435,
          658, 1215, 450, 1314, 673, 465}], 
        Line3DBox[{265, 481, 1119, 266, 1220, 495, 287, 1224, 510, 302, 1230, 
         525, 317, 1238, 540, 332, 1248, 555, 347, 1260, 570, 1167, 362, 585, 
         377, 1271, 600, 392, 1276, 615, 407, 1283, 630, 422, 1292, 645, 437, 
         1303, 660, 452, 1316, 675, 467}], 
        Line3DBox[{267, 482, 1120, 268, 496, 1130, 288, 1225, 511, 303, 1231, 
         526, 318, 1239, 541, 333, 1249, 556, 348, 1261, 571, 1168, 363, 586, 
         1181, 378, 601, 393, 1277, 616, 408, 1284, 631, 423, 1293, 646, 438, 
         1304, 661, 453, 1317, 676, 468}], 
        Line3DBox[{269, 483, 1121, 270, 497, 1131, 289, 512, 1140, 304, 1232, 
         527, 319, 1240, 542, 334, 1250, 557, 349, 1262, 572, 1169, 364, 587, 
         1182, 379, 602, 1192, 394, 617, 409, 1285, 632, 424, 1294, 647, 439, 
         1305, 662, 454, 1318, 677, 469}], 
        Line3DBox[{271, 484, 1122, 272, 498, 1132, 290, 513, 1141, 305, 528, 
         1148, 320, 1241, 543, 335, 1251, 558, 350, 1263, 573, 1170, 365, 588,
          1183, 380, 603, 1193, 395, 618, 1201, 410, 633, 425, 1295, 648, 440,
          1306, 663, 455, 1319, 678, 470}], 
        Line3DBox[{273, 485, 1123, 274, 499, 1133, 291, 514, 1142, 306, 529, 
         1149, 321, 544, 1154, 336, 1252, 559, 351, 1264, 574, 1171, 366, 589,
          1184, 381, 604, 1194, 396, 619, 1202, 411, 634, 1208, 426, 649, 441,
          1307, 664, 456, 1320, 679, 471}], 
        Line3DBox[{275, 486, 1124, 276, 500, 1134, 292, 515, 1143, 307, 530, 
         1150, 322, 545, 1155, 337, 560, 1158, 352, 1265, 575, 1172, 367, 590,
          1185, 382, 605, 1195, 397, 620, 1203, 412, 635, 1209, 427, 650, 
         1213, 442, 665, 457, 1321, 680, 472}], 
        Line3DBox[{277, 682, 1322, 683, 278, 501, 1135, 293, 516, 1144, 308, 
         531, 1151, 323, 546, 1156, 338, 561, 1159, 353, 576, 1173, 1174, 368,
          591, 1186, 383, 606, 1196, 398, 621, 1204, 413, 636, 1210, 428, 651,
          1214, 443, 666, 1216, 458, 685, 686, 687}], 
        Line3DBox[{459, 667, 684, 1308, 444, 652, 1296, 429, 637, 1286, 414, 
         622, 1278, 399, 607, 1272, 384, 592, 1268, 369, 577, 1266, 354, 1160,
          562, 1253, 339, 547, 1242, 324, 532, 1233, 309, 517, 1226, 294, 502,
          1221, 279, 487, 1218, 250, 473, 681, 688}], 
        Line3DBox[{466, 674, 1315, 451, 659, 1302, 436, 644, 1291, 421, 629, 
         1282, 406, 614, 1275, 391, 599, 1270, 376, 584, 1267, 361, 569, 1259,
          346, 554, 1247, 331, 539, 1237, 316, 524, 1229, 301, 509, 1223, 286,
          494, 1219, 264, 480, 1217, 262}]}, {}, {}}},
     VertexNormals->CompressedData["
1:eJxkm3c41mEb92U0aFDJSLIlq5SQuFIkUiRUQkmyaQ8yIjMjhcxoUtk0ECdF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      "]], {}}, {{
     {RGBColor[1, 0, 0], PointSize[
       NCache[
        Rational[7, 360], 0.019444444444444445`]], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGDQAmJmBsJg1kwQOGmPXfwmhriJMQg8xqH+JYY4BHyAi4eC
wVUMPoyGucdAln3ufIFbaOI37W8dO/r98LX7cHGYe154LQzNLXyMpv6l/dcX
Z2a27ntuj2rvB/uekoKdO/69gYo/RXPPU7g4zD2bXFtlpgi8QhO/af/bgtN1
47X3cHGYe3JaW18lF35GU//S/te5sj31+76j2Qtzzx979PBC5X+Au2fy4gs7
o3o+o4nftF8w+/exxw++w8Vh7mFpmub8RfMvmnpgfPXwO189x+iAbk9muEg3
135WB4g7v6KFz1d7GA1zz0I7CSsbgV9o4jft282sjyle+w8Xh7nnwZUZ86UK
mR1Q1b+0n9Fjpx24jx3NXlj48DisAoNfcPfA+DAa5h758DV9FzwZHFDFb9rH
Pe4t8HrKDBeHuWfWr8j153040NS/tA/5evB881peNHs/2F/3eFZsLC8EDTcG
GM2AxneAuad3TcS8u13MaOI37R/s/z2p+R47XBzmng8rBbnT1HnR1L+0f+n2
L+3FWUE0e2HxJeoAAMKrZPU=
       "]]}, {}, {}}, {}}},
  Axes->True,
  AxesLabel->{None, None, None},
  AxesOrigin->{Automatic, Automatic, Automatic},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGrids->None,
  FaceGridsStyle->Automatic,
  ImageSize->{537., 445.1788674615233},
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]], 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "RotationControl" -> 
    "Globe"},
  PlotRange->{{0., 2.}, {0., 1.}, {0., 5.436562880266182}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, Automatic, Automatic},
  ViewPoint->{2.354301128313975, -2.122051291134759, 1.1849744786335468`},
  ViewVertical->{0., 0., 1.}]], "Output",
 CellChangeTimes->{3.4368937335496483`*^9, 3.436893829349648*^9, 
  3.4368941666966476`*^9, 3.437221023608918*^9, 3.437223995754358*^9, 
  3.6981476473169336`*^9, 3.887111584975276*^9},
 CellLabel->"Out[34]=",ExpressionUUID->"810e4583-7317-4ec9-8a14-b15c851ad8a0"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Critiquing the method", "Subsubsection",
 CellChangeTimes->{{3.436892995025648*^9, 3.436893017415648*^9}, {
  3.4373223311586695`*^9, 
  3.4373223372881384`*^9}},ExpressionUUID->"3a050912-0b79-4d00-98b8-\
137006ce17b6"],

Cell[TextData[{
 "Although the steps we followed above are all correct and produce reasonable \
results, the method employed does not scale well to problems with larger \
values of m and n. There are three specific weaknesses that will cause \
trouble when we scale up the system:\n\n1) We leaned pretty heavily on ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s symbolic manipulation capabilities to construct the matrix A for us. \
This takes both time and memory, and may not work too well when the problem \
scales up.\n\n2) When the number of sample points gets large, the size of A \
goes up as the square of the number of sample points. For example, if we used \
m = 100 and n = 50, A would end up being a matrix with roughly 5000 rows and \
5000 columns. Just storing such a large matrix is going to put strain on ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ".\n\n3) When A gets very large, we have to use a more efficient method to \
solve the system A z = B. The method used here is both too slow and takes up \
too much space."
}], "Text",
 CellChangeTimes->{{3.4373223472797976`*^9, 
  3.437322642498253*^9}},ExpressionUUID->"84728402-451b-494c-82da-\
3f0ed477bcc8"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The first alternative: SOR with sparse matrices", "Section",
 CellChangeTimes->{{3.437322681480296*^9, 
  3.437322696679223*^9}},ExpressionUUID->"8830af34-7e6f-4380-b814-\
2fd512ee419b"],

Cell["\<\
The first alternative method I am going to pursue is aimed at bypassing issue \
#1 above completely and moderating the impact of issue #2.\
\>", "Text",
 CellChangeTimes->{{3.437322790501223*^9, 
  3.437322840758541*^9}},ExpressionUUID->"02430430-7d38-441f-8502-\
872a4a4addd3"],

Cell[CellGroupData[{

Cell["Setting up the problem", "Subsubsection",
 CellChangeTimes->{{3.4373237975297003`*^9, 
  3.4373238006277523`*^9}},ExpressionUUID->"0b9213c1-416b-49a8-b8d5-\
751427c4adc7"],

Cell["\<\
For this iteration I am going to use a different problem. The problem for \
this example comes from exercise 3c in section 12.1. The following statements \
set up the problem.\
\>", "Text",
 CellChangeTimes->{{3.437323803756941*^9, 3.437323847581142*^9}, {
  3.4373238814261913`*^9, 
  3.437323897943946*^9}},ExpressionUUID->"a0865b0c-2da8-4bcf-9eac-\
baaf0451e206"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "^", "2"}], " ", "+", " ", 
      RowBox[{"y", "^", "2"}]}], ")"}], " ", 
    RowBox[{"Exp", "[", 
     RowBox[{"x", " ", "y"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a", " ", "=", " ", "0."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"b", "=", "2."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c", " ", "=", " ", "0."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d", " ", "=", " ", "1."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", " ", "70"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m", "=", "40"}], ";"}]}], "Input",
 CellChangeTimes->{{3.4368917657856483`*^9, 3.436891808088648*^9}, {
   3.4368927886486483`*^9, 3.436892792744648*^9}, {3.4368945063476477`*^9, 
   3.436894531033648*^9}, {3.4371487200616407`*^9, 3.4371487254053907`*^9}, {
   3.4371492035303907`*^9, 3.4371492071710153`*^9}, 3.437241717884695*^9, {
   3.4372438466960993`*^9, 3.4372438522135434`*^9}, {3.437244290211315*^9, 
   3.4372442956352434`*^9}, 3.437302776421875*^9, {3.437305748631265*^9, 
   3.437305753521014*^9}, {3.437312956455388*^9, 3.437312962447553*^9}, {
   3.437313171798705*^9, 3.4373131823971853`*^9}, {3.437320335088927*^9, 
   3.437320338122893*^9}, {3.437322739102404*^9, 3.4373227431836615`*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"df90230b-a48e-45a8-bd0b-17ad8f0dd6f8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"h", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"b", "-", "a"}], ")"}], "/", "n"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"k", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"d", "-", "c"}], ")"}], "/", "m"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"x", "[", "i_", "]"}], " ", "=", " ", 
   RowBox[{"a", " ", "+", " ", 
    RowBox[{"i", " ", "h"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"y", "[", "j_", "]"}], " ", "=", " ", 
   RowBox[{"c", " ", "+", " ", 
    RowBox[{"j", " ", "k"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.436891572527648*^9, 3.436891610783648*^9}, {
  3.436891645838648*^9, 3.436891653088648*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"47a1541a-2b6b-4a04-89af-f67c412c2cbe"],

Cell["\<\
Note that this time around we are using larger values of n and m to put \
greater strain on the system.\
\>", "Text",
 CellChangeTimes->{{3.4373239036418705`*^9, 
  3.43732392879992*^9}},ExpressionUUID->"bc1f1b88-7871-4494-bd3f-\
f1b8ad93f1ab"],

Cell["Here are the boundary conditions for this example.", "Text",
 CellChangeTimes->{{3.4373246317706594`*^9, 
  3.4373246409080596`*^9}},ExpressionUUID->"007b7392-d2a5-4b45-aac1-\
e744e79d44b2"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "u", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"0", ",", "j_"}], "]"}], " ", "=", " ", "1."}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"n", ",", "j_"}], "]"}], " ", "=", " ", 
   RowBox[{"Exp", "[", 
    RowBox[{"2.", " ", 
     RowBox[{"y", "[", "j", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"i_", ",", "0"}], "]"}], " ", "=", " ", "1."}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"i_", ",", "m"}], "]"}], " ", "=", " ", 
   RowBox[{"Exp", "[", 
    RowBox[{"x", "[", "i", "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4368923878806477`*^9, 3.436892506631648*^9}, {
  3.436894630327648*^9, 3.436894677521648*^9}, {3.8871117679558153`*^9, 
  3.887111775093338*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"6c75fc10-c8ea-48d1-909a-15821827f2cd"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructing A", "Subsubsection",
 CellChangeTimes->{{3.437322885073799*^9, 
  3.4373228878259115`*^9}},ExpressionUUID->"10fe6ad3-cc2a-4e8b-b1e1-\
bc7a433831bc"],

Cell[TextData[{
 "You may have noticed in the first round above that the matrix A we \
generated has a particularly simple and symmetric form. This suggests that we \
should try to come up with a simple formula to generate the elements of A and \
bypass the symbolic manipulation needed to construct A. The starting point \
for this is the difference equations we have to solve. If we let u(i,j) be \
the value of the estimated solution at sample point (i,j), the associated \
difference equation is\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"u", "(", 
         RowBox[{"i", ",", "j"}], ")"}]}], " ", "-", " ", 
       RowBox[{"u", "(", 
        RowBox[{
         RowBox[{"i", "-", "1"}], ",", "j"}], ")"}], " ", "-", " ", 
       RowBox[{"u", "(", 
        RowBox[{
         RowBox[{"i", "+", "1"}], ",", "j"}], ")"}]}], 
      SuperscriptBox["h", "2"]], " ", "+", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"u", "(", 
         RowBox[{"i", ",", "j"}], ")"}]}], " ", "-", " ", 
       RowBox[{"u", "(", 
        RowBox[{"i", ",", 
         RowBox[{"j", "-", "1"}]}], ")"}], " ", "-", " ", 
       RowBox[{"u", "(", 
        RowBox[{"i", ",", 
         RowBox[{"j", "+", "1"}]}], ")"}]}], 
      SuperscriptBox["k", "2"]]}], " ", "=", " ", 
    RowBox[{"-", 
     RowBox[{"f", "(", 
      RowBox[{
       RowBox[{"x", "(", "i", ")"}], ",", 
       RowBox[{"y", "(", "j", ")"}]}], ")"}]}]}], TraditionalForm]],
  ExpressionUUID->"4ec30407-f4c8-4544-b61f-a7dab65d9729"],
 " \n\n(Note that here I have multiplied both sides of the original PDE by a \
factor of -1. I need to do this to guarantee that the matrix A that results \
is positive-definite. The method in the section after this requires that A be \
positive-definite.)\n\nThe first step of this method is to introduce a linear \
numbering system for the interior grid points. We can do this by introducing \
an index q and using the following formula to translate from (i,j) \
coordinates to the q index:\n\nq = (j-1)*(n-1) + i\n\nNote that the \
difference equation above has terms for exactly five sample points, (i,j) and \
its four immediate neighbors. If we use the formula above to convert indices \
we get the following:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"i", ",", "j"}], ")"}], " ", "\[Rule]", " ", "q"}], 
   TraditionalForm]],ExpressionUUID->"cd7c967f-957d-4bdd-a7ca-1aedf2e86355"],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"i", "-", "1"}], ",", "j"}], ")"}], " ", "\[Rule]", " ", 
    RowBox[{"q", " ", "-", " ", "1"}]}], TraditionalForm]],ExpressionUUID->
  "cbe2dda8-1947-4db2-94e3-1a46f09459e7"],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"i", "+", "1"}], ",", "j"}], ")"}], " ", "\[Rule]", " ", 
    RowBox[{"q", " ", "+", " ", "1"}]}], TraditionalForm]],ExpressionUUID->
  "e68547cd-85c6-4d19-9318-925b545470a2"],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"i", ",", 
      RowBox[{"j", "-", "1"}]}], ")"}], " ", "\[Rule]", " ", 
    RowBox[{"q", " ", "-", " ", "n", " ", "+", " ", "1"}]}], 
   TraditionalForm]],ExpressionUUID->"7bb7843b-d168-4ef3-ba4f-663ce133bb4c"],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"i", ",", 
      RowBox[{"j", "+", "1"}]}], ")"}], " ", "\[Rule]", " ", 
    RowBox[{"q", " ", "+", " ", "n", " ", "-", " ", "1"}]}], 
   TraditionalForm]],ExpressionUUID->"8d7d4549-0350-44fc-8f2d-486511b0a0d4"],
 "\n\nwith these formulas, we can rewrite the difference equations in terms \
of variables ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["u", "q"], " "}], TraditionalForm]],ExpressionUUID->
  "6882cfde-2b0e-4226-8238-d7fd1ee007a8"],
 "that use the linear numbering system:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", 
        SuperscriptBox["k", "2"]]}], " ", 
      SubscriptBox["u", 
       RowBox[{"q", "-", "n", "+", "1"}]]}], " ", "-", " ", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["h", "2"]], " ", 
      SubscriptBox["u", 
       RowBox[{"q", "-", "1"}]]}], " ", "+", " ", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["h", "2"]], " ", "+", " ", 
        FractionBox["1", 
         SuperscriptBox["k", "2"]]}], ")"}], " ", 
      SubscriptBox["u", "q"]}], " ", "-", " ", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["h", "2"]], " ", 
      SubscriptBox["u", 
       RowBox[{"q", "+", "1"}]]}], " ", "-", " ", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["k", "2"]], " ", 
      SubscriptBox["u", 
       RowBox[{"q", " ", "+", " ", "n", " ", "-", " ", "1"}]]}]}], " ", "=", 
    " ", 
    RowBox[{"-", 
     RowBox[{"f", "(", 
      RowBox[{
       RowBox[{"x", "(", 
        RowBox[{"i", "(", "q", ")"}], ")"}], ",", 
       RowBox[{"y", "(", 
        RowBox[{"j", "(", "q", ")"}], ")"}]}], ")"}], " "}]}], 
   TraditionalForm]],ExpressionUUID->"911d855b-744a-43a3-8515-f00a84b51411"],
 "\n\nThis gives us the pattern we need to construct the rows of A. What we \
can read off from this is that each row will have at most five non-zero terms \
which are the coefficients of the five terms on the left. For points close to \
the boundary, some of the terms will not be unknowns, but will be determined \
by the boundary conditions and reduce to numbers. Ultimately, those numerical \
terms will have to be moved over to the right-hand side and incorporated into \
B."
}], "Text",
 CellChangeTimes->{{3.437322848405034*^9, 3.4373233800660906`*^9}, {
  3.4373234265710583`*^9, 3.4373237785210505`*^9}, {3.4373239406005397`*^9, 
  3.437324066010155*^9}, {3.4373295686393137`*^9, 
  3.4373296610662746`*^9}},ExpressionUUID->"ef8fce63-dea0-49ff-b2ea-\
2a8740207d3d"],

Cell[TextData[{
 "One useful way to build the matrix A is to use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s SparseArray function. This function is used to set up matrices where \
most of the elements are expected to be 0. We provide a list of pattern rules \
that specify which entries will be non-zero. Here is the statement we would \
execute to use the pattern we discovered above to build A directly:"
}], "Text",
 CellChangeTimes->{{3.4373240846588163`*^9, 3.437324210400961*^9}, {
  3.4373242665494795`*^9, 
  3.437324268232065*^9}},ExpressionUUID->"8b9740f8-80af-4b97-b523-\
494cace89a00"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", " ", "=", " ", 
   RowBox[{"SparseArray", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"q_", ",", "q_"}], "}"}], "\[Rule]", 
        RowBox[{
         RowBox[{"2", "/", 
          RowBox[{"h", "^", "2"}]}], "+", 
         RowBox[{"2", "/", 
          RowBox[{"k", "^", "2"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"q_", ",", "r_"}], "}"}], "/;", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"r", "\[Equal]", 
            RowBox[{"q", "-", "1"}]}], ",", 
           RowBox[{
            RowBox[{"Mod", "[", 
             RowBox[{"q", ",", 
              RowBox[{"n", "-", "1"}]}], "]"}], "\[NotEqual]", " ", "1"}]}], 
          "]"}]}], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], "/", 
         RowBox[{"h", "^", "2"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"q_", ",", "r_"}], "}"}], "/;", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"r", "\[Equal]", 
            RowBox[{"q", "+", "1"}]}], ",", 
           RowBox[{
            RowBox[{"Mod", "[", 
             RowBox[{"q", ",", 
              RowBox[{"n", "-", "1"}]}], "]"}], ">", "0"}]}], "]"}]}], 
        "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], "/", 
         RowBox[{"h", "^", "2"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"q_", ",", "r_"}], "}"}], "/;", 
         RowBox[{"r", "\[Equal]", 
          RowBox[{"q", "-", "n", "+", "1"}]}]}], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], "/", 
         RowBox[{"k", "^", "2"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"q_", ",", "r_"}], "}"}], "/;", 
         RowBox[{"r", "\[Equal]", 
          RowBox[{"q", "+", "n", "-", "1"}]}]}], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], "/", 
         RowBox[{"k", "^", "2"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", "-", "1"}], ")"}], "*", 
        RowBox[{"(", 
         RowBox[{"m", "-", "1"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", "-", "1"}], ")"}], "*", 
        RowBox[{"(", 
         RowBox[{"m", "-", "1"}], ")"}]}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4373242740743775`*^9, 3.4373243543672633`*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"1f1d8aff-f482-4cca-99eb-c79926d1d38b"],

Cell["\<\
SparseArray offers one further advantage which is very useful here, and that \
is that it is the most efficient way to store matrics with many 0s. Only the \
non-zero entries take up space, and no space is used for the remaining \
entries.\
\>", "Text",
 CellChangeTimes->{{3.437324367317318*^9, 
  3.4373244310390673`*^9}},ExpressionUUID->"ffb3ee03-25fc-45f3-9dee-\
66c539005e8b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructing B", "Subsubsection",
 CellChangeTimes->{{3.4373244521626596`*^9, 
  3.4373244575320597`*^9}},ExpressionUUID->"b79cd7f9-ad1a-4816-b0d9-\
7e79189cd2c6"],

Cell[TextData[{
 "The next step is construct the B for the right-hand side of our system. The \
first thing that goes into B is terms derived from the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", 
    RowBox[{"f", "(", 
     RowBox[{"x", ",", "y"}], ")"}]}], TraditionalForm]],ExpressionUUID->
  "55713bf9-e095-4ca6-b547-3ff381d019a1"],
 " that appears on the right hand side of the differential equation. For this \
step, it is most convenient to use the original (i,j) numbering scheme for \
the interior sample points."
}], "Text",
 CellChangeTimes->{{3.4373244754300594`*^9, 
  3.4373245852201595`*^9}},ExpressionUUID->"89fe55c8-ce20-4e40-b3d8-\
757376a0287d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"B", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"f", "[", 
       RowBox[{
        RowBox[{"x", "[", "i", "]"}], ",", 
        RowBox[{"y", "[", "j", "]"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"m", "-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4372211780508776`*^9, 3.4372211953969455`*^9}, {
   3.4372212610295057`*^9, 3.4372212646080427`*^9}, 3.437235242555233*^9, 
   3.4373036397856884`*^9},
 CellLabel->"In[19]:=",ExpressionUUID->"f1246dd9-2bff-4eb8-ba67-8ba090eb31ec"],

Cell["\<\
For interior points near the boundary, some of the terms in the corresponding \
equations will reduce to numbers determined by the boundary conditions. Those \
numbers have to be moved over to the right hand side of the system and get \
incorporated into B. The best way to handle this is to iterate over the four \
edges of the boundary and add the appropriate terms to B as we go along. The \
following commands do that.\
\>", "Text",
 CellChangeTimes->{{3.43732459900476*^9, 3.4373246042956595`*^9}, {
  3.4373246553834596`*^9, 
  3.437324756794186*^9}},ExpressionUUID->"389c69ff-7d2d-47fe-b26c-\
c63bd527434c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"j", "=", "1"}], ",", 
    RowBox[{"j", "<", "m"}], ",", 
    RowBox[{"j", "++"}], ",", 
    RowBox[{
     RowBox[{"B", "[", 
      RowBox[{"[", 
       RowBox[{"j", ",", "1"}], "]"}], "]"}], "+=", " ", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"0", ",", "j"}], "]"}], "/", 
      RowBox[{"h", "^", "2"}]}]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"j", "=", "1"}], ",", 
    RowBox[{"j", "<", "m"}], ",", 
    RowBox[{"j", "++"}], ",", 
    RowBox[{
     RowBox[{"B", "[", 
      RowBox[{"[", 
       RowBox[{"j", ",", 
        RowBox[{"n", "-", "1"}]}], "]"}], "]"}], " ", "+=", " ", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"n", ",", "j"}], "]"}], "/", 
      RowBox[{"h", "^", "2"}]}]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", " ", "=", " ", "1"}], ",", 
    RowBox[{"i", " ", "<", " ", "n"}], ",", 
    RowBox[{"i", "++"}], ",", 
    RowBox[{
     RowBox[{"B", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "i"}], "]"}], "]"}], " ", "+=", " ", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"i", ",", "0"}], "]"}], "/", 
      RowBox[{"k", "^", "2"}]}]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "<", "n"}], ",", 
    RowBox[{"i", "++"}], ",", 
    RowBox[{
     RowBox[{"B", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"m", "-", "1"}], ",", "i"}], "]"}], "]"}], " ", "+=", " ", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"i", ",", "m"}], "]"}], "/", 
      RowBox[{"k", "^", "2"}]}]}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.4372213240836434`*^9, 3.437221427892476*^9}, {
  3.437221482476888*^9, 3.4372214830863333`*^9}, {3.4372234473765545`*^9, 
  3.4372234645242996`*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"ccdbb5e0-2b79-4984-b04c-763464256a7d"],

Cell[TextData[{
 "Note that B is still in the form of a two-dimensional grid. The last thing \
we need to do with it is to turn into a vector. The ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Flatten command is useful for this."
}], "Text",
 CellChangeTimes->{{3.437324768372078*^9, 
  3.437324806000227*^9}},ExpressionUUID->"2e4f36f5-9a3f-4d72-99e5-\
504715e5976e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"B", " ", "=", " ", 
   RowBox[{"Flatten", "[", "B", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4372216561400175`*^9, 3.4372216603276787`*^9}, 
   3.4372352559656525`*^9},
 CellLabel->"In[24]:=",ExpressionUUID->"8fa95b24-2c5f-4766-ab5b-c5d15d11c7e2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solving the System", "Subsubsection",
 CellChangeTimes->{{3.4373248129626083`*^9, 
  3.4373248177032857`*^9}},ExpressionUUID->"faa6b253-7fc5-4f9c-8e2e-\
b07df8815f86"],

Cell["\<\
Because our matrix A is very large, we have to use a more efficient method to \
solve the very large system A x = B. The method I am going to use is the SOR \
method described in section 7.3 of the text.\
\>", "Text",
 CellChangeTimes->{{3.437324830047822*^9, 3.4373248840258317`*^9}, {
  3.437324938082071*^9, 
  3.4373249437458506`*^9}},ExpressionUUID->"27b52078-5f92-431b-8fe1-\
784e31b1e307"],

Cell["\<\
To apply SOR, we have to decompose A into matrices D, L, and U. Rather than \
decompose A, I will construct these three matrices directly with SparseArray:\
\>", "Text",
 CellChangeTimes->{{3.4373250317221837`*^9, 
  3.4373250818930855`*^9}},ExpressionUUID->"daa8ea20-b2a5-479d-9831-\
4b530a23b062"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"mD", " ", "=", "  ", 
   RowBox[{"SparseArray", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"i_", ",", "i_"}], "}"}], "\[Rule]", 
       RowBox[{
        RowBox[{"2", "/", 
         RowBox[{"h", "^", "2"}]}], "+", 
        RowBox[{"2", "/", 
         RowBox[{"k", "^", "2"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", "-", "1"}], ")"}], "*", 
        RowBox[{"(", 
         RowBox[{"m", "-", "1"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", "-", "1"}], ")"}], "*", 
        RowBox[{"(", 
         RowBox[{"m", "-", "1"}], ")"}]}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mL", " ", "=", "  ", 
   RowBox[{"SparseArray", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"i_", ",", "j_"}], "}"}], "/;", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"j", "\[Equal]", 
            RowBox[{"i", "-", "1"}]}], ",", 
           RowBox[{
            RowBox[{"Mod", "[", 
             RowBox[{"i", ",", 
              RowBox[{"n", "-", "1"}]}], "]"}], "\[NotEqual]", " ", "1"}]}], 
          "]"}]}], "\[Rule]", 
        RowBox[{"1", "/", 
         RowBox[{"h", "^", "2"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"i_", ",", "j_"}], "}"}], "/;", 
         RowBox[{"j", "\[Equal]", 
          RowBox[{"i", "-", "n", "+", "1"}]}]}], "\[Rule]", 
        RowBox[{"1", "/", 
         RowBox[{"k", "^", "2"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", "-", "1"}], ")"}], "*", 
        RowBox[{"(", 
         RowBox[{"m", "-", "1"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", "-", "1"}], ")"}], "*", 
        RowBox[{"(", 
         RowBox[{"m", "-", "1"}], ")"}]}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mU", " ", "=", "  ", 
   RowBox[{"SparseArray", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"i_", ",", "j_"}], "}"}], "/;", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"j", "\[Equal]", 
            RowBox[{"i", "+", "1"}]}], ",", 
           RowBox[{
            RowBox[{"Mod", "[", 
             RowBox[{"i", ",", 
              RowBox[{"n", "-", "1"}]}], "]"}], ">", "0"}]}], "]"}]}], 
        "\[Rule]", 
        RowBox[{"1", "/", 
         RowBox[{"h", "^", "2"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"i_", ",", "j_"}], "}"}], "/;", 
         RowBox[{"j", "\[Equal]", 
          RowBox[{"i", "+", "n", "-", "1"}]}]}], "\[Rule]", 
        RowBox[{"1", "/", 
         RowBox[{"k", "^", "2"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", "-", "1"}], ")"}], "*", 
        RowBox[{"(", 
         RowBox[{"m", "-", "1"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", "-", "1"}], ")"}], "*", 
        RowBox[{"(", 
         RowBox[{"m", "-", "1"}], ")"}]}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.4373109375119524`*^9, 3.4373110334712005`*^9}, {
  3.4373128169287357`*^9, 3.4373128266888447`*^9}},
 CellLabel->"In[25]:=",ExpressionUUID->"13ea2b42-ff54-4530-8114-95a68a69f4e5"],

Cell[TextData[{
 "The SOR method requires us to pick an over-relaxation parameter ",
 Cell[BoxData[
  FormBox["\[Omega]", TraditionalForm]],ExpressionUUID->
  "56a9327d-9208-41d2-962f-4738f7765e91"],
 ". In section 12.1, the textbook recommends that we use the following \
formulas to pick an optimal value for ",
 "\[Omega]:"
}], "Text",
 CellChangeTimes->{{3.437325089237399*^9, 3.4373251261777363`*^9}, {
  3.4373251698529654`*^9, 
  3.437325202199199*^9}},ExpressionUUID->"81e8fa4a-cf0d-4a84-b38a-\
24de19fab4af"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rho", " ", "=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"Pi", "/", "m"}], "]"}], "+", 
     RowBox[{"Cos", "[", 
      RowBox[{"Pi", "/", "n"}], "]"}]}], ")"}], "/", "2."}]}]], "Input",
 CellChangeTimes->{{3.4373110744252367`*^9, 3.437311078833754*^9}, {
  3.437311121283259*^9, 3.4373111512393684`*^9}},
 CellLabel->"In[28]:=",ExpressionUUID->"3b53a829-f5bc-405d-aaf1-cfb743fe6a49"],

Cell[BoxData["0.9979552001372214`"], "Output",
 CellChangeTimes->{
  3.4373111687332377`*^9, 3.4373114155483375`*^9, 3.437313146767589*^9, 
   3.4373132482480354`*^9, 3.4373205458567667`*^9, {3.4373251346940155`*^9, 
   3.4373251507890015`*^9}, 3.4373253549388666`*^9, 3.6981477611820793`*^9, 
   3.887111614937736*^9, 3.887111820609621*^9, 3.887111997586487*^9},
 CellLabel->"Out[28]=",ExpressionUUID->"f905876b-4bc1-4898-8297-c2d8bc88b315"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"omega", " ", "=", " ", 
  RowBox[{"2", "/", 
   RowBox[{"(", 
    RowBox[{"1.", " ", "+", " ", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"1", "-", 
       RowBox[{"rho", "^", "2"}]}], "]"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.437311171770909*^9, 3.437311196679811*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"09c38e7f-4d91-461c-8f3a-d63fd75b064d"],

Cell[BoxData["1.879845397759317`"], "Output",
 CellChangeTimes->{3.437311199935571*^9, 3.4373114179513226`*^9, 
  3.437312339602476*^9, 3.437312663269587*^9, 3.4373131467987614`*^9, 
  3.437313248279207*^9, 3.437320548515176*^9, 3.4373251543517747`*^9, 
  3.4373253549857244`*^9, 3.6981477611977053`*^9, 3.887111614950585*^9, 
  3.887111820625231*^9, 3.8871119975996847`*^9},
 CellLabel->"Out[29]=",ExpressionUUID->"3f126171-9de0-44fa-bb88-67096cc045f6"]
}, Open  ]],

Cell["We are now ready to set up and use the SOR iteration.", "Text",
 CellChangeTimes->{{3.437325213075034*^9, 
  3.4373252234039526`*^9}},ExpressionUUID->"553ec3e4-0f7f-412a-be64-\
9c7c56160a82"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tOmega", " ", "=", " ", 
   RowBox[{
    RowBox[{"Inverse", "[", 
     RowBox[{"mD", "-", 
      RowBox[{"omega", " ", "mL"}]}], "]"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "omega"}], ")"}], "mD"}], " ", "+", " ", 
      RowBox[{"omega", " ", "mU"}]}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.437311255812237*^9, 3.4373112696216*^9}, {
  3.4373114381582437`*^9, 3.4373114409201164`*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"0f45a5df-2584-46e7-8021-de6a1c5fd71b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cOmega", " ", "=", " ", 
   RowBox[{"omega", " ", 
    RowBox[{
     RowBox[{"Inverse", "[", 
      RowBox[{"mD", " ", "-", " ", 
       RowBox[{"omega", " ", "mL"}]}], "]"}], ".", "B"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4373112729764166`*^9, 3.437311284585644*^9}, {
  3.437311446475069*^9, 3.4373114493773756`*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"854aa229-faa1-43a5-b952-0e5175d44963"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fOmega", "[", "x_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"tOmega", ".", "x"}], "+", "cOmega"}]}]], "Input",
 CellChangeTimes->{{3.4373114547294793`*^9, 3.437311458536806*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"85727cf7-aa55-4a48-b4f5-a04305d61069"],

Cell[BoxData[
 RowBox[{
  RowBox[{"startGuess", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{"1.", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "-", "1"}], ")"}], "*", 
       RowBox[{"(", 
        RowBox[{"m", "-", "1"}], ")"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4373113302579665`*^9, 3.4373113691426363`*^9}, {
  3.4373117254920044`*^9, 3.437311725804269*^9}, {3.437312682039027*^9, 
  3.437312684838802*^9}, {3.4373128768472786`*^9, 3.4373128770975204`*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"6fa53dd3-d646-4755-93d8-2be780fd6e0a"],

Cell["\<\
After a moderate number of iterations, this method converges to a reasonable \
result.\
\>", "Text",
 CellChangeTimes->{{3.43732524023337*^9, 
  3.437325261391245*^9}},ExpressionUUID->"79026638-a394-4128-bace-\
3f47ad22d6c3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"z", " ", "=", " ", 
   RowBox[{"Nest", "[", 
    RowBox[{"fOmega", ",", "startGuess", ",", "200"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4373114810686936`*^9, 3.4373115151665874`*^9}, 
   3.437311563224017*^9, 3.437311658277179*^9, 3.437311720136677*^9, 
   3.437325321958396*^9, {3.437325415260603*^9, 3.4373254153855577`*^9}},
 CellLabel->"In[34]:=",ExpressionUUID->"81dca630-88b2-4c0f-8c32-0895f1f99e44"],

Cell[BoxData[
 RowBox[{
  RowBox[{"innerVars", " ", "=", " ", 
   RowBox[{"Flatten", "[", " ", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"i", ",", "j"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", 
        RowBox[{"m", "-", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.437221735252431*^9, 3.4372233009588003`*^9, 
  3.4372443536628666`*^9},
 CellLabel->"In[35]:=",ExpressionUUID->"bda96311-9798-4d54-a2a1-758f076e8c70"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MapThread", "[", 
   RowBox[{"Set", ",", 
    RowBox[{"{", 
     RowBox[{"innerVars", ",", "z"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.437222718773651*^9, 3.4372227219671693`*^9}, 
   3.4372443586805015`*^9},
 CellLabel->"In[36]:=",ExpressionUUID->"e8e853f0-a0e6-434c-ad76-4125281ce0a6"],

Cell["\<\
We can now construct a set of points for this approximate solution and plot \
them.\
\>", "Text",
 CellChangeTimes->{{3.437325481344534*^9, 
  3.4373254984776993`*^9}},ExpressionUUID->"4f6886e7-031f-44f3-88f6-\
b2178ab9c202"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pts", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "i", "]"}], ",", 
       RowBox[{"y", "[", "j", "]"}], ",", 
       RowBox[{"u", "[", 
        RowBox[{"i", ",", "j"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "n"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", "m"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.4372443629016867`*^9},
 CellLabel->"In[37]:=",ExpressionUUID->"df72b452-9970-4770-ace6-4efcd783eef2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPointPlot3D", "[", 
  RowBox[{
   RowBox[{"ArrayFlatten", "[", 
    RowBox[{"pts", ",", "1"}], "]"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.436893252598648*^9, 3.4368932583996477`*^9}, {
   3.436893631566648*^9, 3.436893642415648*^9}, {3.436893701360648*^9, 
   3.436893704654648*^9}, {3.436893814104648*^9, 3.436893818520648*^9}, {
   3.4368938979136477`*^9, 3.436893910232648*^9}, {3.436894110060648*^9, 
   3.436894114816648*^9}, {3.4368941523216476`*^9, 3.436894156808648*^9}, 
   3.4373254698339205`*^9},
 CellLabel->"In[38]:=",ExpressionUUID->"549add33-a170-4506-85a9-37e53d18b38f"],

Cell[BoxData[
 Graphics3DBox[{{
    {RGBColor[1, 0, 0], PointSize[0.006944444444444445], 
     Point3DBox[CompressedData["
1:eJx0nAlYTH37x1uVspd9X0PZZecuS5I9kTX7VoQkexSyk2SJQkJCJVlKqxKF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      "]]}, {}, {}}, {}},
  Axes->True,
  AxesLabel->{None, None, None},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGrids->None,
  FaceGridsStyle->Automatic,
  ImageSize->{558., 447.},
  Lighting->{{"Ambient", 
     GrayLevel[0.5]}, {"Directional", 
     GrayLevel[0.5], 
     ImageScaled[{0, 2, 2}]}, {"Directional", 
     GrayLevel[0.5], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.5], 
     ImageScaled[{2, 0, 2}]}},
  PlotRange->{{0., 2.}, {0., 1.}, Automatic},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic, Automatic},
  ViewPoint->{2.035310885045481, -2.453669273880045, 1.134467582451061},
  ViewVertical->{0.11076227457936064`, -0.28270023410470646`, 
   2.3819796076047104`}]], "Output",
 CellChangeTimes->{
  3.436893260975648*^9, 3.436893644607648*^9, 3.436893705849648*^9, 
   3.4368938199836483`*^9, {3.436893902305648*^9, 3.436893911883648*^9}, 
   3.436894116389648*^9, 3.436894158188648*^9, 3.437221009727791*^9, 
   3.437223549774997*^9, 3.4372416279182625`*^9, 3.4372444774471254`*^9, 
   3.437305727525673*^9, 3.4373064665963326`*^9, 3.4373074883959208`*^9, 
   3.437308553877715*^9, 3.4373115556203885`*^9, 3.4373115917337203`*^9, 
   3.4373116945622554`*^9, 3.437311755828452*^9, 3.4373127173724976`*^9, 
   3.4373129138517556`*^9, 3.4373132768584423`*^9, 3.4373253704019737`*^9, 
   3.4373254283495765`*^9, 3.698147763713456*^9, 3.887111616362204*^9, 
   3.887111821647002*^9, 3.8871119988646584`*^9},
 CellLabel->"Out[38]=",ExpressionUUID->"ecc6e3f5-daa7-46db-828a-06254e25666e"]
}, Open  ]],

Cell["\<\
The problem we are solving has an exact solution, so we can compute and plot \
errors for each of our sample points.\
\>", "Text",
 CellChangeTimes->{{3.4373255051310525`*^9, 
  3.43732552823037*^9}},ExpressionUUID->"8069d7bb-26b1-4623-85d3-\
271dc14ef156"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"soln", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
  RowBox[{"Exp", "[", 
   RowBox[{"x", " ", "y"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.436893654901648*^9, 3.4368936857526484`*^9}, {
  3.436895185881648*^9, 3.4368951890896482`*^9}, {3.4373133369453917`*^9, 
  3.437313338381236*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"8854b7a4-6d95-4892-9e22-2f48debc780a"],

Cell[BoxData[
 SuperscriptBox["\[ExponentialE]", 
  RowBox[{"x", " ", "y"}]]], "Output",
 CellChangeTimes->{3.437313340066792*^9, 3.4373253704332123`*^9, 
  3.698147763713456*^9, 3.887111616399906*^9, 3.887111821680005*^9, 
  3.887111998951625*^9},
 CellLabel->"Out[39]=",ExpressionUUID->"1a8dfdd3-882e-4642-9fb3-147b3ebc5d49"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"errors", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "i", "]"}], ",", 
       RowBox[{"y", "[", "j", "]"}], ",", 
       RowBox[{
        RowBox[{"u", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "-", 
        RowBox[{"soln", "[", 
         RowBox[{
          RowBox[{"x", "[", "i", "]"}], ",", 
          RowBox[{"y", "[", "j", "]"}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "n"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", "m"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4368959153006477`*^9, 3.436895959750648*^9}, {
  3.437313389431733*^9, 3.4373133905242233`*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"5e3c4aee-f6a2-4389-aaba-1eb2f79fca8f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPointPlot3D", "[", 
  RowBox[{"ArrayFlatten", "[", 
   RowBox[{"errors", ",", "1"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.436893252598648*^9, 3.4368932583996477`*^9}, {
   3.436893631566648*^9, 3.436893642415648*^9}, {3.436893701360648*^9, 
   3.436893704654648*^9}, {3.436893814104648*^9, 3.436893818520648*^9}, {
   3.4368938979136477`*^9, 3.436893910232648*^9}, {3.436894110060648*^9, 
   3.436894114816648*^9}, {3.4368941523216476`*^9, 3.436894156808648*^9}, {
   3.436895978369648*^9, 3.436895987463648*^9}, 3.4373133726386013`*^9},
 CellLabel->"In[41]:=",ExpressionUUID->"fb465843-700c-4b95-9e94-9f1e97e8de30"],

Cell[BoxData[
 Graphics3DBox[{{
    {RGBColor[0.3315753, 0.4561011, 0.6388182], PointSize[
     0.006944444444444445], Point3DBox[CompressedData["
1:eJyEnQVUFWv7vmmQEqxji3mso9i9NzZ2HLu7Axsb4yg2FrZio6JiISoqKA0q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      "]]}, {}, {}}, {}},
  Axes->True,
  AxesLabel->{None, None, None},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGrids->None,
  FaceGridsStyle->Automatic,
  ImageSize->{455., Automatic},
  Lighting->{{"Ambient", 
     GrayLevel[0.5]}, {"Directional", 
     GrayLevel[0.5], 
     ImageScaled[{0, 2, 2}]}, {"Directional", 
     GrayLevel[0.5], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.5], 
     ImageScaled[{2, 0, 2}]}},
  PlotRange->{{0., 2.}, {0., 1.}, Automatic},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.437313373559414*^9, 3.437313393942156*^9}, 
   3.4373253706206436`*^9, 3.4373254363622775`*^9, 3.6981477638540883`*^9, 
   3.8871116165493937`*^9, 3.887111821815775*^9, 3.887111999103025*^9},
 CellLabel->"Out[41]=",ExpressionUUID->"d31e4af6-4a19-40bc-8a69-2f1efd88e6a3"]
}, Open  ]],

Cell["This shows that the results are quite reasonable.", "Text",
 CellChangeTimes->{{3.437325535930143*^9, 
  3.4373255448949895`*^9}},ExpressionUUID->"5a8af153-e638-4f41-a3a4-\
fb84323b6584"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problems with this method", "Subsubsection",
 CellChangeTimes->{{3.4373256014328737`*^9, 
  3.437325607242844*^9}},ExpressionUUID->"733571ad-cae0-4887-ac30-\
d74bf96d681c"],

Cell[TextData[{
 "Although this method performs much better than the crude method I used in \
the first section, it still has problems. The main problem is that the matrix \
T used in the SOR method is quite large, and takes up a lot of memory. In \
fact, if we increase the values of m and n a bit more, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " actually runs out of memory in the middle of computing tOmega.\n\nThe next \
alternative attempts to aggressively trade space for time, using less storage \
space while taking slightly more time to do the calculation."
}], "Text",
 CellChangeTimes->{{3.4373256173634377`*^9, 3.437325708058325*^9}, {
  3.437325786084118*^9, 3.437325879985531*^9}, {3.515326241418928*^9, 
  3.515326243072528*^9}},ExpressionUUID->"b6692243-a6c6-44a5-8325-\
4f71a0d31239"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The second alternative: solving exactly via the Cholesky decomposition\
\>", "Section",
 CellChangeTimes->{{3.437325579176938*^9, 3.4373255861426554`*^9}, {
  3.437390157475391*^9, 
  3.4373901964736633`*^9}},ExpressionUUID->"8c46c0f0-1311-4a65-bacf-\
15fb20f7495a"],

Cell["\<\
The central problem we have to solve is the linear system A z = B. As we have \
seen in chapters 6 and 7, there are multiple alternative approaches available \
for solving linear systems of equations. In this iteration, we will use \
another method to solve the system.\
\>", "Text",
 CellChangeTimes->{{3.4373258924630346`*^9, 3.437325911733672*^9}, {
  3.4373259468237233`*^9, 
  3.437325995062783*^9}},ExpressionUUID->"9e4d6628-084c-4e3b-8550-\
5dcf77259cd3"],

Cell[CellGroupData[{

Cell["Setting up the method", "Subsubsection",
 CellChangeTimes->{{3.437326006587686*^9, 
  3.4373260093049393`*^9}},ExpressionUUID->"0f69a916-160c-435b-bd54-\
36b2ef38a9b4"],

Cell[TextData[{
 "The method we are going to use this time takes advantage of a special \
property of A. It turns out that when you use the difference equation method \
to solve an elliptic PDE the matrix A you end up constructing is always a \
symmetric, positive-definite matrix. Such matrices can be factored into lower \
triangular and upper triangular matrices via the Cholesky decomposition. This \
is the approach we are going to use. We will convert the original system\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"A", " ", "z"}], " ", "=", " ", "B"}], TraditionalForm]],
  ExpressionUUID->"9928458d-b2bf-4aaa-b5a0-d42b693be860"],
 "\n\ninto\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"L", " ", 
     SuperscriptBox["L", "T"], " ", "z"}], " ", "=", " ", "B"}], 
   TraditionalForm]],ExpressionUUID->"9a8ba6c2-aa58-483f-a1af-09f595d7a222"],
 "\n\nvia the Cholesky decomposition and hence into a pair of ",
 Cell[BoxData[
  FormBox["equations", TraditionalForm]],ExpressionUUID->
  "e18ff210-905d-4b52-90cf-f3796c60d476"],
 "\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"L", " ", "w"}], " ", "=", " ", "B"}], TraditionalForm]],
  ExpressionUUID->"260d5000-4bce-44dd-b87d-f543b6948570"],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["L", "T"], " ", "z"}], " ", "=", " ", "w"}], 
   TraditionalForm]],ExpressionUUID->"9ef95082-b875-40e8-a320-a8d48ee54a42"],
 "\n\nSince both of the matrices in the latter two systems are triangular, \
both systems can be solved relatively quickly by back-substitution."
}], "Text",
 CellChangeTimes->{{3.4373260118035636`*^9, 3.4373262653267117`*^9}, {
  3.4373263774783726`*^9, 3.4373264046647835`*^9}, {3.4373294343789644`*^9, 
  3.437329459254137*^9}},ExpressionUUID->"4f35ece2-1c57-41ed-ac92-\
e18a23a4cb46"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Running this method", "Subsubsection",
 CellChangeTimes->{{3.4373268751249857`*^9, 
  3.437326880121882*^9}},ExpressionUUID->"0ed8ce78-65e5-4d77-b9ab-\
620c821a9710"],

Cell["Here now is the code to run this method.", "Text",
 CellChangeTimes->{{3.43732688365094*^9, 3.4373269030919886`*^9}, {
  3.4373286798788986`*^9, 
  3.437328683158112*^9}},ExpressionUUID->"93888fd9-0e9f-410d-9f98-\
eba012565e78"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "f", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "^", "2"}], " ", "+", " ", 
      RowBox[{"y", "^", "2"}]}], ")"}], " ", 
    RowBox[{"Exp", "[", 
     RowBox[{"x", " ", "y"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a", " ", "=", " ", "0."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"b", "=", "2."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c", " ", "=", " ", "0."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d", " ", "=", " ", "1."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m", "=", "30"}], ";"}]}], "Input",
 CellChangeTimes->{{3.4368917657856483`*^9, 3.436891808088648*^9}, {
   3.4368927886486483`*^9, 3.436892792744648*^9}, {3.4368945063476477`*^9, 
   3.436894531033648*^9}, {3.4371487200616407`*^9, 3.4371487254053907`*^9}, {
   3.4371492035303907`*^9, 3.4371492071710153`*^9}, 3.437241717884695*^9, {
   3.4372438466960993`*^9, 3.4372438522135434`*^9}, {3.437244290211315*^9, 
   3.4372442956352434`*^9}, 3.437302776421875*^9, {3.437305748631265*^9, 
   3.437305753521014*^9}, {3.4373273010010633`*^9, 3.43732730396797*^9}, {
   3.437327385948295*^9, 3.437327389492968*^9}, {3.437432460145*^9, 
   3.437432465634*^9}, {3.6981500958629313`*^9, 3.6981501303021774`*^9}, {
   3.6981501700385666`*^9, 3.69815017641389*^9}, {3.6981502996076326`*^9, 
   3.698150302404651*^9}, {3.6981504189261827`*^9, 3.6981504227388763`*^9}, {
   3.887113808479733*^9, 3.8871138132989893`*^9}, 3.887113964213799*^9},
 CellLabel->"In[1]:=",ExpressionUUID->"1f448061-bc05-4d05-93df-b4e0dfa14f84"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"h", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"b", "-", "a"}], ")"}], "/", "n"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"k", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"d", "-", "c"}], ")"}], "/", "m"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", "x", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"x", "[", "i_", "]"}], " ", ":=", " ", 
   RowBox[{"a", " ", "+", " ", 
    RowBox[{"i", " ", "h"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", "y", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"y", "[", "j_", "]"}], " ", ":=", " ", 
   RowBox[{"c", " ", "+", " ", 
    RowBox[{"j", " ", "k"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.436891572527648*^9, 3.436891610783648*^9}, {
  3.436891645838648*^9, 3.436891653088648*^9}, {3.887113821782186*^9, 
  3.887113832357253*^9}, {3.887113886495158*^9, 3.887113890187904*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"f8a08508-e1f8-41b5-b8ce-1ac003c69116"],

Cell["\<\
Note that I am using slightly more moderate values for m and n here. This is \
because the method in this section is slower. If you have the time to waste, \
you can try running this section with larger values of n and m.\
\>", "Text",
 CellChangeTimes->{{3.4373272157727556`*^9, 
  3.437327266663018*^9}},ExpressionUUID->"aa5866d5-3a9e-412b-8382-\
2063f0e672c2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", " ", "=", " ", 
   RowBox[{"SparseArray", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"i_", ",", "i_"}], "}"}], "\[Rule]", 
        RowBox[{
         RowBox[{"2", "/", 
          RowBox[{"h", "^", "2"}]}], "+", 
         RowBox[{"2", "/", 
          RowBox[{"k", "^", "2"}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"i_", ",", "j_"}], "}"}], "/;", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"j", "\[Equal]", 
            RowBox[{"i", "-", "1"}]}], ",", 
           RowBox[{
            RowBox[{"Mod", "[", 
             RowBox[{"i", ",", 
              RowBox[{"n", "-", "1"}]}], "]"}], "\[NotEqual]", " ", "1"}]}], 
          "]"}]}], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], "/", 
         RowBox[{"h", "^", "2"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"i_", ",", "j_"}], "}"}], "/;", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"j", "\[Equal]", 
            RowBox[{"i", "+", "1"}]}], ",", 
           RowBox[{
            RowBox[{"Mod", "[", 
             RowBox[{"i", ",", 
              RowBox[{"n", "-", "1"}]}], "]"}], "\[NotEqual]", " ", "0"}]}], 
          "]"}]}], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], "/", 
         RowBox[{"h", "^", "2"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"i_", ",", "j_"}], "}"}], "/;", 
         RowBox[{"j", "\[Equal]", 
          RowBox[{"i", "-", "n", "+", "1"}]}]}], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], "/", 
         RowBox[{"k", "^", "2"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"i_", ",", "j_"}], "}"}], "/;", 
         RowBox[{"j", "\[Equal]", 
          RowBox[{"i", "+", "n", "-", "1"}]}]}], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], "/", 
         RowBox[{"k", "^", "2"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", "-", "1"}], ")"}], "*", 
        RowBox[{"(", 
         RowBox[{"m", "-", "1"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", "-", "1"}], ")"}], "*", 
        RowBox[{"(", 
         RowBox[{"m", "-", "1"}], ")"}]}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.437302785109375*^9, 3.437302862859375*^9}, {
   3.43730292134375*^9, 3.437302925421875*^9}, {3.4373034985625*^9, 
   3.437303601685933*^9}, 3.4373055586647253`*^9, {3.4373056200134974`*^9, 
   3.4373056291837873`*^9}, 3.437306583216056*^9, {3.437328708673512*^9, 
   3.437328713592332*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"b1723e54-1482-4fd6-8d7e-e19c4a47af30"],

Cell[BoxData[
 RowBox[{
  RowBox[{"B", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"f", "[", 
       RowBox[{
        RowBox[{"x", "[", "i", "]"}], ",", 
        RowBox[{"y", "[", "j", "]"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"m", "-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4372211780508776`*^9, 3.4372211953969455`*^9}, {
   3.4372212610295057`*^9, 3.4372212646080427`*^9}, 3.437235242555233*^9, 
   3.4373036397856884`*^9},
 CellLabel->"In[16]:=",ExpressionUUID->"81c8c3d9-86b2-4d91-8598-5e1de36d6a3a"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "u", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"0", ",", "j_"}], "]"}], " ", "=", " ", "1."}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"n", ",", "j_"}], "]"}], " ", "=", " ", 
   RowBox[{"Exp", "[", 
    RowBox[{"2.", " ", 
     RowBox[{"y", "[", "j", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"i_", ",", "0"}], "]"}], " ", "=", " ", "1."}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"i_", ",", "m"}], "]"}], " ", "=", " ", 
   RowBox[{"Exp", "[", 
    RowBox[{"x", "[", "i", "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4368923878806477`*^9, 3.436892506631648*^9}, {
  3.436894630327648*^9, 3.436894677521648*^9}, {3.887112016135005*^9, 
  3.8871120215014887`*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"97ae3e15-c0e5-4f95-bb86-52af15792404"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"j", "=", "1"}], ",", 
    RowBox[{"j", "<", "m"}], ",", 
    RowBox[{"j", "++"}], ",", 
    RowBox[{
     RowBox[{"B", "[", 
      RowBox[{"[", 
       RowBox[{"j", ",", "1"}], "]"}], "]"}], "+=", " ", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"0", ",", "j"}], "]"}], "/", 
      RowBox[{"h", "^", "2"}]}]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"j", "=", "1"}], ",", 
    RowBox[{"j", "<", "m"}], ",", 
    RowBox[{"j", "++"}], ",", 
    RowBox[{
     RowBox[{"B", "[", 
      RowBox[{"[", 
       RowBox[{"j", ",", 
        RowBox[{"n", "-", "1"}]}], "]"}], "]"}], " ", "+=", " ", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"n", ",", "j"}], "]"}], "/", 
      RowBox[{"h", "^", "2"}]}]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", " ", "=", " ", "1"}], ",", 
    RowBox[{"i", " ", "<", " ", "n"}], ",", 
    RowBox[{"i", "++"}], ",", 
    RowBox[{
     RowBox[{"B", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "i"}], "]"}], "]"}], " ", "+=", " ", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"i", ",", "0"}], "]"}], "/", 
      RowBox[{"k", "^", "2"}]}]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "<", "n"}], ",", 
    RowBox[{"i", "++"}], ",", 
    RowBox[{
     RowBox[{"B", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"m", "-", "1"}], ",", "i"}], "]"}], "]"}], " ", "+=", " ", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"i", ",", "m"}], "]"}], "/", 
      RowBox[{"k", "^", "2"}]}]}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.4372213240836434`*^9, 3.437221427892476*^9}, {
  3.437221482476888*^9, 3.4372214830863333`*^9}, {3.4372234473765545`*^9, 
  3.4372234645242996`*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"e57137b9-ee18-4dd7-91b9-cbf399771b84"],

Cell[BoxData[
 RowBox[{
  RowBox[{"B", " ", "=", " ", 
   RowBox[{"Flatten", "[", "B", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4372216561400175`*^9, 3.4372216603276787`*^9}, 
   3.4372352559656525`*^9},
 CellLabel->"In[26]:=",ExpressionUUID->"57424d12-9dff-4ce5-9034-8ca01244fa1e"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s built-in method for computing the Cholesky decomposition is fairly \
efficient."
}], "Text",
 CellChangeTimes->{{3.437328549350606*^9, 
  3.437328577926605*^9}},ExpressionUUID->"15c56dc4-bf34-4148-8563-\
54d756770c2f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"mL", " ", "=", " ", 
   RowBox[{"CholeskyDecomposition", "[", "A", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.4373287409191065`*^9, {3.4373902128964787`*^9, 3.4373902150577908`*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"043cfe90-61a4-44ff-b1e4-af25180f69d0"],

Cell[TextData[{
 "The next step is to do the back-substitutions. These functions carry out \
those steps. USolve is designed to solve a system U x = c where U is an upper \
triangular matrix, while LSolve solves L x = b for a lower triangular L. Note \
that USolve assumes that the parameter u is an upper triangular matrix. The \
matrix mL returned by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s CholeskyDecomposition function is upper triangular, so I will pass mL \
directly to USolve. Since I don't want to have to actually compute the \
transpose of mL to pass to LSolve, LSolve also assumes that its parameter l \
is an upper triangular matrix. It compensates for that by switching indices \
when it actually uses that parameter."
}], "Text",
 CellChangeTimes->{{3.4373285858591776`*^9, 3.4373286187449994`*^9}, {
   3.4373902513899193`*^9, 3.4373902991827526`*^9}, {3.4373903451390743`*^9, 
   3.437390521767515*^9}, 
   3.6981502017276683`*^9},ExpressionUUID->"4cff15af-60bd-4f9f-8273-\
77d3e6ddab70"],

Cell[BoxData[
 RowBox[{
  RowBox[{"USolve", "[", 
   RowBox[{"u_", ",", "c_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"y", ",", "n"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"n", "=", 
      RowBox[{"Length", "[", "c", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"y", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{"0.", ",", 
        RowBox[{"{", "n", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "n"}], ",", 
       RowBox[{"i", ">", "0"}], ",", 
       RowBox[{"i", "--"}], ",", 
       RowBox[{
        RowBox[{"y", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "-", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"u", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "j"}], "]"}], "]"}], " ", 
              RowBox[{"y", "[", 
               RowBox[{"[", "j", "]"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", 
               RowBox[{"i", "+", "1"}], ",", "n"}], "}"}]}], "]"}]}], ")"}], 
         "/", 
         RowBox[{"u", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "i"}], "]"}], "]"}]}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", "y"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.43722221378693*^9, 3.4372222579652004`*^9}, {
  3.4372223674007745`*^9, 3.437222495738572*^9}, {3.437241580067094*^9, 
  3.4372415849769044`*^9}, {3.437390223750367*^9, 3.4373902281518707`*^9}},
 CellLabel->"In[28]:=",ExpressionUUID->"54d3ae81-43bb-4b13-becd-ed10cf3a1873"],

Cell[BoxData[
 RowBox[{
  RowBox[{"LSolve", "[", 
   RowBox[{"l_", ",", "b_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "n"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"n", "=", 
      RowBox[{"Length", "[", "b", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"x", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{"0.", ",", 
        RowBox[{"{", "n", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "\[LessEqual]", "n"}], ",", 
       RowBox[{"i", "++"}], ",", 
       RowBox[{
        RowBox[{"x", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"b", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "-", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"l", "[", 
               RowBox[{"[", 
                RowBox[{"j", ",", "i"}], "]"}], "]"}], " ", 
              RowBox[{"x", "[", 
               RowBox[{"[", "j", "]"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "1", ",", 
               RowBox[{"i", "-", "1"}]}], "}"}]}], "]"}]}], ")"}], "/", 
         RowBox[{"l", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "i"}], "]"}], "]"}]}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", "x"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.437221987773864*^9, 3.4372221969327*^9}, {
  3.437222430763157*^9, 3.4372224340988436`*^9}, {3.4372225792294383`*^9, 
  3.4372225795738373`*^9}, {3.437390233847007*^9, 3.437390237680575*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"b0d62d72-5a62-4430-98ad-4381de0b43db"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Timing", "[", 
   RowBox[{"w", " ", "=", " ", 
    RowBox[{"LSolve", "[", 
     RowBox[{"mL", ",", "B"}], "]"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.4372225152338424`*^9, 3.4372225499242144`*^9}, 
   3.437223381277528*^9, 3.437244340632944*^9, {3.437303736026111*^9, 
   3.437303736560955*^9}, {3.4373058604237285`*^9, 3.437305865594677*^9}, {
   3.4373066424554386`*^9, 3.437306643892681*^9}, {3.437329367857786*^9, 
   3.4373293701063895`*^9}, {3.437432518752*^9, 3.437432523698*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"91005c17-56ce-4de8-b212-1d3e8c11bf9c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.437432527344*^9, 3.4374325293599997`*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"93347fb0-d83d-499e-883e-ae201e643c3e"],

Cell[BoxData["309.417104`"], "Output",
 CellChangeTimes->{3.437437200469*^9, 3.69815010581656*^9, 
  3.698150150584451*^9, 3.698150219134802*^9, 3.6981503560636215`*^9, 
  3.6981508763251553`*^9, 3.887112325680271*^9, 3.887114287193069*^9},
 CellLabel->"Out[31]=",ExpressionUUID->"8e515c5b-38e3-4c60-9f40-b52c9436da39"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Timing", "[", 
   RowBox[{"z", " ", "=", " ", 
    RowBox[{"USolve", "[", 
     RowBox[{"mL", ",", "w"}], "]"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.437222588528211*^9, 3.437222601912809*^9}, {
   3.4372233856072946`*^9, 3.437223386230283*^9}, {3.437241605566935*^9, 
   3.437241609401263*^9}, 3.437244344949703*^9, {3.4373037624694176`*^9, 
   3.437303763255953*^9}, {3.437305868609761*^9, 3.4373058736713543`*^9}, {
   3.4373066464703436`*^9, 3.4373066477201195`*^9}, {3.4373293778828087`*^9, 
   3.4373293793662624`*^9}, {3.437432532112*^9, 3.437432537*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"0037e552-1efa-4098-b5d3-3516afd01fed"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.437432540447*^9, 3.4374325420699997`*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"87293d15-05b1-472a-b226-af725d62138a"],

Cell[BoxData["308.097211`"], "Output",
 CellChangeTimes->{3.437441864505*^9, 3.69815010581656*^9, 
  3.6981501506157036`*^9, 3.6981502522146044`*^9, 3.698150385174469*^9, 
  3.6981513081567745`*^9, 3.887112616356185*^9, 3.887114578060268*^9},
 CellLabel->"Out[33]=",ExpressionUUID->"471ddf36-e159-4fdf-9582-ed2121b0950f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"innerVars", " ", "=", " ", 
   RowBox[{"Flatten", "[", " ", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"i", ",", "j"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", 
        RowBox[{"m", "-", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.437221735252431*^9, 3.4372233009588003`*^9, 
  3.4372443536628666`*^9},
 CellLabel->"In[34]:=",ExpressionUUID->"711a888b-d0ba-482c-a3f7-68f357e6fee8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MapThread", "[", 
   RowBox[{"Set", ",", 
    RowBox[{"{", 
     RowBox[{"innerVars", ",", "z"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.437222718773651*^9, 3.4372227219671693`*^9}, 
   3.4372443586805015`*^9},
 CellLabel->"In[35]:=",ExpressionUUID->"2c7a5828-2d57-4d72-bdda-62a04fc7bfbf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pts", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "i", "]"}], ",", 
       RowBox[{"y", "[", "j", "]"}], ",", 
       RowBox[{"u", "[", 
        RowBox[{"i", ",", "j"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "n"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", "m"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.4372443629016867`*^9},
 CellLabel->"In[36]:=",ExpressionUUID->"ca285dca-23e7-4233-946f-4a44a7e693aa"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPointPlot3D", "[", 
  RowBox[{
   RowBox[{"ArrayFlatten", "[", 
    RowBox[{"pts", ",", "1"}], "]"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.436893252598648*^9, 3.4368932583996477`*^9}, {
   3.436893631566648*^9, 3.436893642415648*^9}, {3.436893701360648*^9, 
   3.436893704654648*^9}, {3.436893814104648*^9, 3.436893818520648*^9}, {
   3.4368938979136477`*^9, 3.436893910232648*^9}, {3.436894110060648*^9, 
   3.436894114816648*^9}, {3.4368941523216476`*^9, 3.436894156808648*^9}, 
   3.4373270007500744`*^9},
 CellLabel->"In[37]:=",ExpressionUUID->"45bfc1e3-9159-4b5e-b497-151b537b473d"],

Cell[BoxData[
 Graphics3DBox[{{
    {RGBColor[1, 0, 0], PointSize[0.009722222222222222], 
     Point3DBox[CompressedData["
1:eJx1nXdcE9v2tymCgIigYMMGdkXsehR1jR17772hqNh77wUV7BV7F1FRbChg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      "]]}, {}, {}}, {}},
  Axes->True,
  AxesLabel->{None, None, None},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGrids->None,
  FaceGridsStyle->Automatic,
  ImageSize->{468., Automatic},
  Lighting->{{"Ambient", 
     GrayLevel[0.5]}, {"Directional", 
     GrayLevel[0.5], 
     ImageScaled[{0, 2, 2}]}, {"Directional", 
     GrayLevel[0.5], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.5], 
     ImageScaled[{2, 0, 2}]}},
  PlotRange->{{0., 2.}, {0., 1.}, Automatic},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.436893260975648*^9, 3.436893644607648*^9, 3.436893705849648*^9, 
   3.4368938199836483`*^9, {3.436893902305648*^9, 3.436893911883648*^9}, 
   3.436894116389648*^9, 3.436894158188648*^9, 3.437221009727791*^9, 
   3.437223549774997*^9, 3.4372416279182625`*^9, 3.4372444774471254`*^9, 
   3.437305727525673*^9, 3.4373064665963326`*^9, 3.437327335417184*^9, 
   3.4373292711366177`*^9, 3.4373908446426487`*^9, 3.437441866132*^9, 
   3.6981501059259377`*^9, 3.6981501507250834`*^9, 3.698150252339611*^9, 
   3.6981503852838483`*^9, 3.6981513083188825`*^9, 3.8871126165292263`*^9, 
   3.887113913817007*^9, 3.887114578470777*^9},
 CellLabel->"Out[37]=",ExpressionUUID->"d77e5792-a7ac-4f3f-af1d-08d3d97011f2"]
}, Open  ]],

Cell["Here are the errors for this method.", "Text",
 CellChangeTimes->{{3.4373255051310525`*^9, 3.43732552823037*^9}, {
  3.437327029919455*^9, 3.437327036634034*^9}, {3.437327437322632*^9, 
  3.437327448721801*^9}},ExpressionUUID->"b7881462-3cc2-46d6-ad1e-\
0b600027855f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"soln", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
  RowBox[{"Exp", "[", 
   RowBox[{"x", " ", "y"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.436893654901648*^9, 3.4368936857526484`*^9}, {
  3.436895185881648*^9, 3.4368951890896482`*^9}, {3.4373133369453917`*^9, 
  3.437313338381236*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"8a3f0a67-e79a-4bb2-bcca-2ac9d0566559"],

Cell[BoxData[
 SuperscriptBox["\[ExponentialE]", 
  RowBox[{"x", " ", "y"}]]], "Output",
 CellChangeTimes->{3.437313340066792*^9, 3.4373253704332123`*^9, 
  3.437327338805704*^9, 3.437329271152233*^9, 3.437390844689582*^9, 
  3.437441866217*^9, 3.6981501059259377`*^9, 3.6981501507250834`*^9, 
  3.698150252339611*^9, 3.6981503852994747`*^9, 3.6981513083298903`*^9, 
  3.887112616563518*^9, 3.887113920842778*^9, 3.887114578506727*^9},
 CellLabel->"Out[38]=",ExpressionUUID->"57b04024-174b-4803-b3db-4dbcd216e74a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"errors", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "i", "]"}], ",", 
       RowBox[{"y", "[", "j", "]"}], ",", 
       RowBox[{
        RowBox[{"u", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "-", 
        RowBox[{"soln", "[", 
         RowBox[{
          RowBox[{"x", "[", "i", "]"}], ",", 
          RowBox[{"y", "[", "j", "]"}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "n"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", "m"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4368959153006477`*^9, 3.436895959750648*^9}, {
  3.437313389431733*^9, 3.4373133905242233`*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"3a5076f0-0cc7-446c-bf12-69c1a18f84eb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPointPlot3D", "[", 
  RowBox[{"ArrayFlatten", "[", 
   RowBox[{"errors", ",", "1"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.436893252598648*^9, 3.4368932583996477`*^9}, {
   3.436893631566648*^9, 3.436893642415648*^9}, {3.436893701360648*^9, 
   3.436893704654648*^9}, {3.436893814104648*^9, 3.436893818520648*^9}, {
   3.4368938979136477`*^9, 3.436893910232648*^9}, {3.436894110060648*^9, 
   3.436894114816648*^9}, {3.4368941523216476`*^9, 3.436894156808648*^9}, {
   3.436895978369648*^9, 3.436895987463648*^9}, 3.4373133726386013`*^9},
 CellLabel->"In[40]:=",ExpressionUUID->"0ca4b67a-82af-46cd-8008-ec7705dfa0fe"],

Cell[BoxData[
 Graphics3DBox[{{
    {RGBColor[0.3315753, 0.4561011, 0.6388182], PointSize[
     0.009722222222222222], Point3DBox[CompressedData["
1:eJyFnXdUVOfWh+m9DL0j9oaIJbboHGzYa6zY0KBir7FHUbE3jA2NCiIoKBIQ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      "]]}, {}, {}}, {}},
  Axes->True,
  AxesLabel->{None, None, None},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGrids->None,
  FaceGridsStyle->Automatic,
  Lighting->{{"Ambient", 
     GrayLevel[0.5]}, {"Directional", 
     GrayLevel[0.5], 
     ImageScaled[{0, 2, 2}]}, {"Directional", 
     GrayLevel[0.5], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.5], 
     ImageScaled[{2, 0, 2}]}},
  PlotRange->{{0., 2.}, {0., 1.}, Automatic},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.437313373559414*^9, 3.437313393942156*^9}, 
   3.4373253706206436`*^9, 3.4373254363622775`*^9, 3.4373273440212145`*^9, 
   3.4373292712146945`*^9, 3.437390844799094*^9, 3.4374418664849997`*^9, 
   3.6981501059571915`*^9, 3.698150150771961*^9, 3.6981502524021125`*^9, 
   3.698150385361978*^9, 3.6981513084109445`*^9, 3.887112616707288*^9, 
   3.887113925674447*^9, 3.8871145786511593`*^9},
 CellLabel->"Out[40]=",ExpressionUUID->"e4764dc7-4f18-4430-adc0-3cfdd66a4342"]
}, Open  ]],

Cell[BoxData["  "], "Input",
 CellChangeTimes->{{3.887114711770628*^9, 
  3.887114712276984*^9}},ExpressionUUID->"b15eab6f-6dc9-494a-849a-\
aa24ef0063b4"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{912, 1003},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
TaggingRules-><|"TryRealOnly" -> False|>,
FrontEndVersion->"13.1 for Mac OS X ARM (64-bit) (June 16, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"523e49be-ef46-4101-9687-acc9b836a9e0"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 245, 6, 53, "Subtitle",ExpressionUUID->"cfd44fc4-5473-440b-b4d1-bf8fb2e9bdd6"],
Cell[815, 30, 1310, 36, 150, "Text",ExpressionUUID->"7f2cf978-c2db-4aec-9fae-de1b202f8fd9"],
Cell[CellGroupData[{
Cell[2150, 70, 258, 8, 45, "Subsubsection",ExpressionUUID->"24c99261-41d7-46cc-82b3-adbab2ec2bd9"],
Cell[2411, 80, 558, 10, 104, "Text",ExpressionUUID->"f9a4a037-d135-4c17-a766-e333493e18eb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3006, 95, 223, 4, 67, "Section",ExpressionUUID->"1f22566d-313e-4d80-a65d-b6c58c4ec79d"],
Cell[3232, 101, 415, 8, 58, "Text",ExpressionUUID->"df58755b-b90a-4368-8af9-f0d1e7783709"],
Cell[3650, 111, 278, 6, 35, "Text",ExpressionUUID->"ca8eba02-810b-4a83-95f8-26ff01e71861"],
Cell[CellGroupData[{
Cell[3953, 121, 188, 3, 45, "Subsubsection",ExpressionUUID->"9623d71c-2001-4861-9ac1-6e6fce578b8a"],
Cell[4144, 126, 751, 12, 104, "Text",ExpressionUUID->"ae339142-39c5-4701-88d8-99d83df2f516"],
Cell[4898, 140, 562, 12, 81, "Text",ExpressionUUID->"71b99190-7679-45fb-96d0-f38269a4d612"],
Cell[CellGroupData[{
Cell[5485, 156, 1351, 39, 52, "Input",ExpressionUUID->"42cd25d8-e0fe-4c10-ac76-2b59d2945d1e"],
Cell[6839, 197, 1256, 37, 52, "Output",ExpressionUUID->"3ac9b3b2-7b8c-4d56-86c1-a10e1bbb0c3a"]
}, Open  ]],
Cell[8110, 237, 314, 7, 35, "Text",ExpressionUUID->"51fdbabe-7331-41dc-9d3d-1b3b4502e7bf"],
Cell[8427, 246, 830, 21, 157, "Input",ExpressionUUID->"cded0a30-2376-452f-9b8e-52ac619da642"],
Cell[9260, 269, 840, 25, 94, "Input",ExpressionUUID->"45a17f6c-4d54-45f0-8b18-07be456b1740"],
Cell[10103, 296, 351, 7, 58, "Text",ExpressionUUID->"fa71dcdf-4d39-4d97-a18b-637f263b6eab"],
Cell[10457, 305, 517, 10, 81, "Text",ExpressionUUID->"0cb219a2-1069-4228-a402-6b8f1506dbef"],
Cell[CellGroupData[{
Cell[10999, 319, 665, 16, 30, "Input",ExpressionUUID->"6c1304fc-76a2-441c-bbb6-c6cf90aa484e"],
Cell[11667, 337, 1653, 47, 56, "Output",ExpressionUUID->"af048a41-8257-4c5e-96cc-23ceb70b9e02"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13357, 389, 1525, 46, 115, "Input",ExpressionUUID->"ffb0656c-9eb2-4dd6-a42f-4241505b23f3"],
Cell[14885, 437, 1750, 50, 56, "Output",ExpressionUUID->"8cc5435f-58c0-427c-8a9f-566c95c37823"]
}, Open  ]],
Cell[16650, 490, 372, 7, 58, "Text",ExpressionUUID->"1550220f-5404-4571-af29-07a426b6d245"],
Cell[CellGroupData[{
Cell[17047, 501, 694, 17, 30, "Input",ExpressionUUID->"a68c9c59-f41f-49fd-bffa-fdf788172405"],
Cell[17744, 520, 12213, 368, 434, "Output",ExpressionUUID->"ac296a9d-c380-4518-9f94-f13d8dc15149"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[30006, 894, 187, 3, 45, "Subsubsection",ExpressionUUID->"5d254b8c-749c-4664-8f61-4c8229031bb3"],
Cell[30196, 899, 382, 9, 81, "Text",ExpressionUUID->"dc2e939e-69c1-49f2-bcdb-d1d30bbcf4ac"],
Cell[30581, 910, 360, 7, 58, "Text",ExpressionUUID->"7bb4b568-b7de-4c35-b09b-f68ee4a33af6"],
Cell[30944, 919, 745, 20, 52, "Input",ExpressionUUID->"7c465d99-2338-4302-a5c0-29324584dbb3"],
Cell[CellGroupData[{
Cell[31714, 943, 210, 3, 30, "Input",ExpressionUUID->"900c92f6-08a7-4f76-91c3-696c552010d0"],
Cell[31927, 948, 4173, 82, 369, "Output",ExpressionUUID->"26bdabf5-0a0d-4df1-adb6-1b6948dbc17b"]
}, Open  ]],
Cell[36115, 1033, 528, 9, 81, "Text",ExpressionUUID->"737cf6e4-e619-4a24-b6d4-5e15e49b63da"],
Cell[CellGroupData[{
Cell[36668, 1046, 1067, 28, 73, "Input",ExpressionUUID->"c07fd730-b785-4b0f-bb92-99fd8fbf5a47"],
Cell[37738, 1076, 3267, 77, 119, "Output",ExpressionUUID->"3506e5c5-4180-4cd7-8003-b6e945b3a05b"]
}, Open  ]],
Cell[41020, 1156, 318, 7, 58, "Text",ExpressionUUID->"9def6ef1-a5de-4c61-b870-155d78bb9d08"],
Cell[41341, 1165, 853, 25, 94, "Input",ExpressionUUID->"9e1e0cdf-66ae-4c35-ab6b-ca0b8f16acd7"],
Cell[42197, 1192, 280, 6, 58, "Text",ExpressionUUID->"653febfe-8139-4dd4-b319-6de8c6bea24e"],
Cell[CellGroupData[{
Cell[42502, 1202, 148, 2, 30, "Input",ExpressionUUID->"1a80dcd8-687b-4fd9-b89e-1dc59bac7cf9"],
Cell[42653, 1206, 1063, 21, 56, "Output",ExpressionUUID->"0f2a578b-2e34-4a66-9b94-30b38c328c0b"]
}, Open  ]],
Cell[43731, 1230, 235, 6, 35, "Text",ExpressionUUID->"d39e6ff5-d76b-4b12-b7f2-f779d05111d6"],
Cell[CellGroupData[{
Cell[43991, 1240, 317, 6, 30, "Input",ExpressionUUID->"62e4217a-5bc7-40d0-b569-b6ac56d7a0a0"],
Cell[44311, 1248, 881, 16, 56, "Output",ExpressionUUID->"f97b73bc-c404-4ca8-b073-d6f302ac83e6"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[45241, 1270, 176, 3, 45, "Subsubsection",ExpressionUUID->"b745e42a-7dcd-41c7-9e0d-80fd56fe1450"],
Cell[45420, 1275, 453, 10, 81, "Text",ExpressionUUID->"b183ceff-b8d5-48fc-97b1-2383f1fa1193"],
Cell[CellGroupData[{
Cell[45898, 1289, 340, 7, 30, "Input",ExpressionUUID->"e61583de-8f83-45a7-a7a8-f78935ad224a"],
Cell[46241, 1298, 882, 16, 56, "Output",ExpressionUUID->"9ae6bca5-2870-4f54-8380-804d5bff9acd"]
}, Open  ]],
Cell[47138, 1317, 321, 7, 58, "Text",ExpressionUUID->"21f2185e-d8a2-460f-ab17-1a3c6db1c66a"],
Cell[CellGroupData[{
Cell[47484, 1328, 630, 16, 30, "Input",ExpressionUUID->"6d28c828-c349-4de8-898b-90f68fd9fad3"],
Cell[48117, 1346, 5180, 143, 245, "Output",ExpressionUUID->"3ab35d81-9f95-43cc-877c-307f99029123"]
}, Open  ]],
Cell[53312, 1492, 182, 3, 35, "Text",ExpressionUUID->"6ee13c61-7029-439e-939d-57f8f7a1ca71"],
Cell[CellGroupData[{
Cell[53519, 1499, 678, 12, 30, "Input",ExpressionUUID->"9e59e552-fa3b-4ed0-a2f5-b0a8b4702d79"],
Cell[54200, 1513, 11316, 200, 314, 1382, 36, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"d2bd05c6-6a9a-4ace-bb15-c31b6e9aed8a"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[65565, 1719, 186, 3, 45, "Subsubsection",ExpressionUUID->"8aad6dc8-ce1e-4918-95ec-f8c1b065c96f"],
Cell[65754, 1724, 228, 5, 35, "Text",ExpressionUUID->"9a1bb71e-4fa5-452a-9683-07acea783837"],
Cell[CellGroupData[{
Cell[66007, 1733, 314, 7, 30, "Input",ExpressionUUID->"06eb8fda-ee41-4952-9ef6-5d5051df81a3"],
Cell[66324, 1742, 302, 5, 34, "Output",ExpressionUUID->"7039f7f6-0a1a-4300-8928-7639d1983b61"]
}, Open  ]],
Cell[66641, 1750, 181, 3, 35, "Text",ExpressionUUID->"80a2a318-9934-4497-bfdd-45b85349cf16"],
Cell[CellGroupData[{
Cell[66847, 1757, 453, 11, 30, "Input",ExpressionUUID->"f3c2b958-1e63-4258-a23b-737deed0b4a4"],
Cell[67303, 1770, 84841, 1390, 314, "Output",ExpressionUUID->"4c4083a7-61b3-40c2-b25b-f663f8e5a360"]
}, Open  ]],
Cell[152159, 3163, 314, 7, 58, "Text",ExpressionUUID->"b9c81518-007c-47ba-b8ca-d8f931d62937"],
Cell[CellGroupData[{
Cell[152498, 3174, 233, 4, 30, "Input",ExpressionUUID->"8e49c870-ff7a-4b90-83ca-e05d95664849"],
Cell[152734, 3180, 85915, 1408, 462, "Output",ExpressionUUID->"810e4583-7317-4ec9-8a14-b15c851ad8a0"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[238698, 4594, 225, 4, 45, "Subsubsection",ExpressionUUID->"3a050912-0b79-4d00-98b8-137006ce17b6"],
Cell[238926, 4600, 1196, 21, 311, "Text",ExpressionUUID->"84728402-451b-494c-82da-3f0ed477bcc8"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[240171, 4627, 192, 3, 67, "Section",ExpressionUUID->"8830af34-7e6f-4380-b814-2fd512ee419b"],
Cell[240366, 4632, 288, 6, 58, "Text",ExpressionUUID->"02430430-7d38-441f-8502-872a4a4addd3"],
Cell[CellGroupData[{
Cell[240679, 4642, 177, 3, 45, "Subsubsection",ExpressionUUID->"0b9213c1-416b-49a8-b8d5-751427c4adc7"],
Cell[240859, 4647, 376, 8, 58, "Text",ExpressionUUID->"a0865b0c-2da8-4bcf-9eac-baaf0451e206"],
Cell[241238, 4657, 1531, 33, 157, "Input",ExpressionUUID->"df90230b-a48e-45a8-bd0b-17ad8f0dd6f8"],
Cell[242772, 4692, 840, 25, 94, "Input",ExpressionUUID->"47a1541a-2b6b-4a04-89af-f67c412c2cbe"],
Cell[243615, 4719, 254, 6, 35, "Text",ExpressionUUID->"bc1f1b88-7871-4494-bd3f-f1b8ad93f1ab"],
Cell[243872, 4727, 196, 3, 35, "Text",ExpressionUUID->"007b7392-d2a5-4b45-aac1-e744e79d44b2"],
Cell[244071, 4732, 996, 28, 115, "Input",ExpressionUUID->"6c75fc10-c8ea-48d1-909a-15821827f2cd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[245104, 4765, 167, 3, 45, "Subsubsection",ExpressionUUID->"10fe6ad3-cc2a-4e8b-b1e1-bc7a433831bc"],
Cell[245274, 4770, 6001, 156, 746, "Text",ExpressionUUID->"ef8fce63-dea0-49ff-b2ea-2a8740207d3d"],
Cell[251278, 4928, 610, 12, 81, "Text",ExpressionUUID->"8b9740f8-80af-4b97-b523-494cace89a00"],
Cell[251891, 4942, 2561, 78, 73, "Input",ExpressionUUID->"1f1d8aff-f482-4cca-99eb-c79926d1d38b"],
Cell[254455, 5022, 391, 8, 58, "Text",ExpressionUUID->"ffb3ee03-25fc-45f3-9dee-66c539005e8b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[254883, 5035, 169, 3, 45, "Subsubsection",ExpressionUUID->"b79cd7f9-ad1a-4816-b0d9-7e79189cd2c6"],
Cell[255055, 5040, 664, 15, 81, "Text",ExpressionUUID->"89fe55c8-ce20-4e40-b3d8-757376a0287d"],
Cell[255722, 5057, 729, 19, 30, "Input",ExpressionUUID->"f1246dd9-2bff-4eb8-ba67-8ba090eb31ec"],
Cell[256454, 5078, 624, 11, 104, "Text",ExpressionUUID->"389c69ff-7d2d-47fe-b26c-c63bd527434c"],
Cell[257081, 5091, 2025, 62, 94, "Input",ExpressionUUID->"ccdbb5e0-2b79-4984-b04c-763464256a7d"],
Cell[259109, 5155, 376, 9, 58, "Text",ExpressionUUID->"2e4f36f5-9a3f-4d72-99e5-504715e5976e"],
Cell[259488, 5166, 289, 6, 30, "Input",ExpressionUUID->"8fa95b24-2c5f-4766-ab5b-c5d15d11c7e2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[259814, 5177, 173, 3, 45, "Subsubsection",ExpressionUUID->"faa6b253-7fc5-4f9c-8e2e-b07df8815f86"],
Cell[259990, 5182, 406, 8, 58, "Text",ExpressionUUID->"27b52078-5f92-431b-8fe1-784e31b1e307"],
Cell[260399, 5192, 309, 6, 58, "Text",ExpressionUUID->"daa8ea20-b2a5-479d-9831-4b530a23b062"],
Cell[260711, 5200, 3546, 113, 115, "Input",ExpressionUUID->"13ea2b42-ff54-4530-8114-95a68a69f4e5"],
Cell[264260, 5315, 517, 12, 58, "Text",ExpressionUUID->"81e8fa4a-cf0d-4a84-b38a-24de19fab4af"],
Cell[CellGroupData[{
Cell[264802, 5331, 454, 11, 30, "Input",ExpressionUUID->"3b53a829-f5bc-405d-aaf1-cfb743fe6a49"],
Cell[265259, 5344, 442, 6, 34, "Output",ExpressionUUID->"f905876b-4bc1-4898-8297-c2d8bc88b315"]
}, Open  ]],
Cell[CellGroupData[{
Cell[265738, 5355, 382, 9, 30, "Input",ExpressionUUID->"09c38e7f-4d91-461c-8f3a-d63fd75b064d"],
Cell[266123, 5366, 454, 6, 34, "Output",ExpressionUUID->"3f126171-9de0-44fa-bb88-67096cc045f6"]
}, Open  ]],
Cell[266592, 5375, 197, 3, 35, "Text",ExpressionUUID->"553ec3e4-0f7f-412a-be64-9c7c56160a82"],
Cell[266792, 5380, 574, 15, 30, "Input",ExpressionUUID->"0f45a5df-2584-46e7-8021-de6a1c5fd71b"],
Cell[267369, 5397, 441, 10, 30, "Input",ExpressionUUID->"854aa229-faa1-43a5-b952-0e5175d44963"],
Cell[267813, 5409, 298, 6, 30, "Input",ExpressionUUID->"85727cf7-aa55-4a48-b4f5-a04305d61069"],
Cell[268114, 5417, 611, 14, 30, "Input",ExpressionUUID->"6fa53dd3-d646-4755-93d8-2be780fd6e0a"],
Cell[268728, 5433, 235, 6, 35, "Text",ExpressionUUID->"79026638-a394-4128-bace-3f47ad22d6c3"],
Cell[268966, 5441, 456, 9, 30, "Input",ExpressionUUID->"81dca630-88b2-4c0f-8c32-0895f1f99e44"],
Cell[269425, 5452, 615, 16, 30, "Input",ExpressionUUID->"bda96311-9798-4d54-a2a1-758f076e8c70"],
Cell[270043, 5470, 340, 8, 30, "Input",ExpressionUUID->"e8e853f0-a0e6-434c-ad76-4125281ce0a6"],
Cell[270386, 5480, 235, 6, 35, "Text",ExpressionUUID->"4f6886e7-031f-44f3-88f6-b2178ab9c202"],
Cell[270624, 5488, 587, 16, 30, "Input",ExpressionUUID->"df72b452-9970-4770-ace6-4efcd783eef2"],
Cell[CellGroupData[{
Cell[271236, 5508, 669, 12, 30, "Input",ExpressionUUID->"549add33-a170-4506-85a9-37e53d18b38f"],
Cell[271908, 5522, 41982, 701, 464, "Output",ExpressionUUID->"ecc6e3f5-daa7-46db-828a-06254e25666e"]
}, Open  ]],
Cell[313905, 6226, 267, 6, 35, "Text",ExpressionUUID->"8069d7bb-26b1-4623-85d3-271dc14ef156"],
Cell[CellGroupData[{
Cell[314197, 6236, 419, 9, 30, "Input",ExpressionUUID->"8854b7a4-6d95-4892-9e22-2f48debc780a"],
Cell[314619, 6247, 327, 6, 34, "Output",ExpressionUUID->"1a8dfdd3-882e-4642-9fb3-147b3ebc5d49"]
}, Open  ]],
Cell[314961, 6256, 834, 22, 30, "Input",ExpressionUUID->"5e3c4aee-f6a2-4389-aaba-1eb2f79fca8f"],
Cell[CellGroupData[{
Cell[315820, 6282, 653, 10, 30, "Input",ExpressionUUID->"fb465843-700c-4b95-9e94-9f1e97e8de30"],
Cell[316476, 6294, 33870, 567, 366, "Output",ExpressionUUID->"d31e4af6-4a19-40bc-8a69-2f1efd88e6a3"]
}, Open  ]],
Cell[350361, 6864, 193, 3, 35, "Text",ExpressionUUID->"5a8af153-e638-4f41-a3a4-fb84323b6584"]
}, Open  ]],
Cell[CellGroupData[{
Cell[350591, 6872, 178, 3, 45, "Subsubsection",ExpressionUUID->"733571ad-cae0-4887-ac30-d74bf96d681c"],
Cell[350772, 6877, 813, 14, 150, "Text",ExpressionUUID->"b6692243-a6c6-44a5-8325-4f71a0d31239"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[351634, 6897, 276, 6, 67, "Section",ExpressionUUID->"8c46c0f0-1311-4a65-bacf-15fb20f7495a"],
Cell[351913, 6905, 472, 9, 81, "Text",ExpressionUUID->"9e4d6628-084c-4e3b-8550-5dcf77259cd3"],
Cell[CellGroupData[{
Cell[352410, 6918, 174, 3, 45, "Subsubsection",ExpressionUUID->"0f69a916-160c-435b-bd54-36b2ef38a9b4"],
Cell[352587, 6923, 1820, 42, 410, "Text",ExpressionUUID->"4f35ece2-1c57-41ed-ac92-e18a23a4cb46"]
}, Open  ]],
Cell[CellGroupData[{
Cell[354444, 6970, 172, 3, 45, "Subsubsection",ExpressionUUID->"0ed8ce78-65e5-4d77-b9ab-620c821a9710"],
Cell[354619, 6975, 234, 4, 35, "Text",ExpressionUUID->"93888fd9-0e9f-410d-9f98-eba012565e78"],
Cell[354856, 6981, 1808, 37, 178, "Input",ExpressionUUID->"1f448061-bc05-4d05-93df-b4e0dfa14f84"],
Cell[356667, 7020, 1055, 28, 136, "Input",ExpressionUUID->"f8a08508-e1f8-41b5-b8ce-1ac003c69116"],
Cell[357725, 7050, 373, 7, 58, "Text",ExpressionUUID->"aa5866d5-3a9e-412b-8382-2063f0e672c2"],
Cell[358101, 7059, 2821, 82, 73, "Input",ExpressionUUID->"b1723e54-1482-4fd6-8d7e-e19c4a47af30"],
Cell[360925, 7143, 729, 19, 30, "Input",ExpressionUUID->"81c8c3d9-86b2-4d91-8598-5e1de36d6a3a"],
Cell[361657, 7164, 996, 28, 115, "Input",ExpressionUUID->"97ae3e15-c0e5-4f95-bb86-52af15792404"],
Cell[362656, 7194, 2025, 62, 94, "Input",ExpressionUUID->"e57137b9-ee18-4dd7-91b9-cbf399771b84"],
Cell[364684, 7258, 289, 6, 30, "Input",ExpressionUUID->"57424d12-9dff-4ce5-9034-8ca01244fa1e"],
Cell[364976, 7266, 288, 8, 35, "Text",ExpressionUUID->"15c56dc4-bf34-4148-8563-54d756770c2f"],
Cell[365267, 7276, 303, 6, 30, "Input",ExpressionUUID->"043cfe90-61a4-44ff-b1e4-af25180f69d0"],
Cell[365573, 7284, 1022, 18, 150, "Text",ExpressionUUID->"4cff15af-60bd-4f9f-8273-77d3e6ddab70"],
Cell[366598, 7304, 1789, 47, 115, "Input",ExpressionUUID->"54d3ae81-43bb-4b13-becd-ed10cf3a1873"],
Cell[368390, 7353, 1787, 46, 115, "Input",ExpressionUUID->"b0d62d72-5a62-4430-98ad-4381de0b43db"],
Cell[370180, 7401, 612, 11, 30, "Input",ExpressionUUID->"91005c17-56ce-4de8-b212-1d3e8c11bf9c"],
Cell[CellGroupData[{
Cell[370817, 7416, 221, 4, 30, "Input",ExpressionUUID->"93347fb0-d83d-499e-883e-ae201e643c3e"],
Cell[371041, 7422, 319, 4, 34, "Output",ExpressionUUID->"8e515c5b-38e3-4c60-9f40-b52c9436da39"]
}, Open  ]],
Cell[371375, 7429, 687, 12, 30, "Input",ExpressionUUID->"0037e552-1efa-4098-b5d3-3516afd01fed"],
Cell[CellGroupData[{
Cell[372087, 7445, 221, 4, 30, "Input",ExpressionUUID->"87293d15-05b1-472a-b226-af725d62138a"],
Cell[372311, 7451, 321, 4, 34, "Output",ExpressionUUID->"471ddf36-e159-4fdf-9582-ed2121b0950f"]
}, Open  ]],
Cell[372647, 7458, 615, 16, 30, "Input",ExpressionUUID->"711a888b-d0ba-482c-a3f7-68f357e6fee8"],
Cell[373265, 7476, 340, 8, 30, "Input",ExpressionUUID->"2c7a5828-2d57-4d72-bdda-62a04fc7bfbf"],
Cell[373608, 7486, 587, 16, 30, "Input",ExpressionUUID->"ca285dca-23e7-4233-946f-4a44a7e693aa"],
Cell[CellGroupData[{
Cell[374220, 7506, 669, 12, 30, "Input",ExpressionUUID->"45bfc1e3-9159-4b5e-b497-151b537b473d"],
Cell[374892, 7520, 23605, 399, 403, "Output",ExpressionUUID->"d77e5792-a7ac-4f3f-af1d-08d3d97011f2"]
}, Open  ]],
Cell[398512, 7922, 274, 4, 35, "Text",ExpressionUUID->"b7881462-3cc2-46d6-ad1e-0b600027855f"],
Cell[CellGroupData[{
Cell[398811, 7930, 419, 9, 30, "Input",ExpressionUUID->"8a3f0a67-e79a-4bb2-bcca-2ac9d0566559"],
Cell[399233, 7941, 514, 8, 34, "Output",ExpressionUUID->"57b04024-174b-4803-b3db-4dbcd216e74a"]
}, Open  ]],
Cell[399762, 7952, 834, 22, 30, "Input",ExpressionUUID->"3a5076f0-0cc7-446c-bf12-69c1a18f84eb"],
Cell[CellGroupData[{
Cell[400621, 7978, 653, 10, 30, "Input",ExpressionUUID->"0ca4b67a-82af-46cd-8008-ec7705dfa0fe"],
Cell[401277, 7990, 19209, 326, 288, "Output",ExpressionUUID->"e4764dc7-4f18-4430-adc0-3cfdd66a4342"]
}, Open  ]],
Cell[420501, 8319, 154, 3, 30, "Input",ExpressionUUID->"b15eab6f-6dc9-494a-849a-aa24ef0063b4"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

